/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 					A V   A  C  C  E  P  T  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to gather AV request data for a specific id and set it
 * 			up in a nice format for reading.  Calls are made to the AVRequest table
 * 			to retrieve request data.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: April 21, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
package edu.cmu.radar.vendor;

import java.sql.ResultSet;
import java.sql.SQLException;
/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  - - - - - - - - - - - - - public class AVAcceptQuote  - - - - - - - - - - - - - -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
public class AVAcceptQuote {
	public String messageBody = null;
	private String vendorName = null;
	public String contactEmail = null;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public AVAcceptQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the AVAcceptQuote.java class.  Initializes the messageBody by calling
	 * 				setupMessageBody.  The class variable messageBody is used by the QuoteAcceptedServlet to
	 * 				construct a confirmation email to the user
	 * Input:		String <requestID - the unique number in the AVRequest table>
	 * 				String <vendorID - could be AV1, 2, or 3, passed in through the http stream>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public AVAcceptQuote(String requestID, String vendorID, String baseURL){
		DatabaseConnectivity db = new DatabaseConnectivity();
		ResultSet rs = db.submitQuery("SELECT * FROM audioVisualRequests WHERE uniqueID ='" + requestID + "'");
		try {
			boolean crap = rs.next();
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		contactEmail = assignContactEmail(rs);
		messageBody = setupMessageBody(rs, requestID, vendorID, baseURL);
	} // end constructor

	public String assignContactEmail(ResultSet rs) {
		try {
			return (rs.getString("contactEmail"));
		} catch (SQLException e) {

		}
		return "Error";
	}

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public setupMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method constructs the message body by querying the AVRequest table and placing
	 * 				the variables in a very long String.  This method is called by the Constructor to initialize
	 * 				the messageBody class variable.  This method calls submitQuery (from DatabaseConnectivity.java),
	 * 				determineQuoteNumber, and assembleMessageBody.
	 * Input:		String <requestID - the unique number in the AVRequest table>
	 * 				String <vendorID - could be AV1, 2, or 3, passed in through the http stream>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupMessageBody(ResultSet rs, String requestID, String vendorID, String baseURL) {
		String quoteNumber = determineQuoteNumber(vendorID);
		String link = baseURL + determineAVVendor(vendorID, requestID);
		if (quoteNumber.equals("error")) {
			System.err.println("EXCEPTION: AVAcceptQuote.setupMessageBody:\n\tThere was an error determining the quoteNumber");
			System.out.println("EXCEPTION: AVAcceptQuote.setupMessageBody:\n\tThere was an error determining the quoteNumber");
		}
		return (assembleMessageBody(rs, quoteNumber, link));
	} // end setupMessageBody

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public assembleMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for pulling data from the ResultSet and formatting it in a clean
	 * 				manner so it's easily readable.
	 * Input:		ResultSet <rs>
	 * 				String <quoteNumber - identifies which quote to pull, either quote1, 2, or 3>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String assembleMessageBody(ResultSet rs, String quoteNumber, String link) {
		String s = null;
		String quoteId = null;
		int uniqueId = -1;
		String quotedesc = "";
		try {
			//boolean crap = rs.next();
			    quoteId = rs.getString("quoteid").substring(11); //number tagged to audioVisual
			    uniqueId = rs.getInt("uniqueid");
			    if(quoteId.equals(new Integer(uniqueId).toString()))
			    	quotedesc = "detailed ";
			    else
			    	quotedesc = "modified ";
			    
			    s = "Request for Audio Visual Service.  \n" + 
		    	"Your "+quotedesc+"quote from " + vendorName +
		    	" can be found below.\n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Order Id:\t" + quoteId + "\n" +
				"Event Title:\t" + rs.getString("eventTitle") + "\n" +
				"Event Location:\t" + rs.getString("eventLocation") + "\n" +
				getDate(rs) +
				"Contact First Name:\t" + rs.getString("contactFirstName") + "\n" +
				"Contact Last Name:\t" + rs.getString("contactLastName") + "\n" +
				"Contact Email:\t" + rs.getString("contactEmail") + "\n" +
				"Setup Complete Time:\t\t\t" + rs.getString("setupComplete") + "\n" +
				"Breakdown Start Time:\t\t" + rs.getString("breakdownStart") + "\n" +
				getCDRequest(rs) +
				getWirelessMicRequest(rs) +
				getLavalierMicRequest(rs) +
				getPodiumMicRequest(rs) +
				getPanelMicRequest(rs) +
				getPodLaptopConRequest(rs) +
				getExternalSpeakersRequest(rs) +
				getVideoProjRequest(rs) +
				getCompProjRequest(rs) +
				getTVVCRDVDRequest(rs) +
				getTVRequest(rs) +
				getSlideProjRequest(rs) +
				getOverheadProjRequest(rs) +
				getEaselRequest(rs) +
				getPCLaptopRequest(rs) +
				getAppleLaptopRequest(rs) +
				getFlipChartRequest(rs) +
				getPhoneRequest(rs) +
				getFaxRequest(rs) +
				getComputerConRequest(rs) +
				getPodiumRequest(rs) +
				getLecturnRequest(rs) +
				getVideotapingRequest(rs) +
				getLaserPointerRequest(rs) +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Quote Total:\t$" + rs.getString(quoteNumber) + "\n\n" +
				"Click the link below to review, modify, or cancel your Audio Visual Request:\n\n" +
				link;

		} // end try
		catch(Exception e){
			System.out.println("EXCEPTION: AVAcceptQuote:assembleMessageBody\n\t An error occurred while assembling message body.\n Here it is: " + e);
		}
		return s;
	} // end printAVRequestData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineQuoteNumber()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying which quote number in the request table corresponds
	 * 				to the vendorID.
	 * Input:		String <vendorID>
	 * Output:		String <quoteNumber - either quote1, 2, or 3>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineQuoteNumber(String vendorID){
		if (vendorID.equals("AV1")) {
			vendorName = "CMU AV SERVICES";
			return "quote1" ;
		}
		if (vendorID.equals("AV2")) {
			vendorName = "CONFER.NET SERVICES";
			return "quote2";
		}
		if (vendorID.equals("AV3")) {
			vendorName = "FLAGSTAFF HOTEL";
			return "quote3";
		}
		else {
			System.out.println("EXCEPTION: AVAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return "error";
		}
	} // end determineQuoteNumber

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineAVVendor()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying the AV vendor and returning the appropriate
	 * 				link to quote page.
	 * Input:		String <vendorID> , String <requestID>
	 * Output:		String <link>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineAVVendor(String vendorID, String requestID){
		if (vendorID.equals("AV1"))
			return ("/myapp/webForms/AV/CMUAVReviewQuote.jsp?uniqueID=" + requestID);
		if (vendorID.equals("AV2"))
			return ("/myapp/webForms/AV/ConferReviewQuote.jsp?uniqueID=" + requestID);
		if (vendorID.equals("AV3"))
			return ("/myapp/webForms/AV/FlagstaffAVReviewQuote.jsp?uniqueID=" + requestID);
		else {
			System.out.println("EXCEPTION: AVAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return "error";
		}
	} // end determineQuoteNumber


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public get*Request() Methods      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		The following methods are used to determine if the user requested a specific item.  If so
	 * 				the method will return a string of the format <ITEM>:\tYES\tQuantity:\t<QUANTITY>.  These
	 * 				methods are called by assembleMessageBody.
	 * Input:		ResultSet <rs>
	 * Output:		String
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String getDate(ResultSet rs) {
		try {
			String date = "Event Date:\t" + rs.getString("eventMonth") + " " + rs.getString("eventDayOfMonth") + ", " +
				rs.getString("eventYear")+ "\n";
				return date;
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getDate - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getCDRequest(ResultSet rs) {
		try {
			if (rs.getString("cdPlayer").equals("Yes")) {
				String line = "CD Player:\t" + rs.getString("quantCDPlayer") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getCDRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getWirelessMicRequest(ResultSet rs) {
		try {
			if (rs.getString("wirelessMic").equals("Yes")) {
				String line = "Wireless Microphone:\t" + rs.getString("quantWirelessMic") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getWirelessRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getLavalierMicRequest(ResultSet rs) {
		try {
			if (rs.getString("lavalierMic").equals("Yes")) {
				String line = "Lavalier Microphone:\t" + rs.getString("quantLavalierMic") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getLavalierRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getPodiumMicRequest(ResultSet rs) {
		try {
			if (rs.getString("podiumMic").equals("Yes")) {
				String line = "Podium Microphone:\t" + rs.getString("quantPodMic") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getPodiumMicRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getPanelMicRequest(ResultSet rs) {
		try {
			if (rs.getString("panelMic").equals("Yes")) {
				String line = "Panel Microphone:\t" + rs.getString("quantPanelMic") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getPanelMicRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getPodLaptopConRequest(ResultSet rs) {
		try {
			if (rs.getString("podLaptopCon").equals("Yes")) {
				String line = "Podium Laptop Connection:\t" + rs.getString("quantPodLaptopCon") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getPodLaptopConRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getExternalSpeakersRequest(ResultSet rs) {
		try {
			if (rs.getString("externalSpeakers").equals("Yes")) {
				String line = "External Computer Speakers:\t" + rs.getString("quantExternalSpeakers") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getExternalSpeakersRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getVideoProjRequest(ResultSet rs) {
		try {
			if (rs.getString("videoProj").equals("Yes")) {
				String line = "Projection - Video:\t" + rs.getString("quantVideoProj") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getVideoProjRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getCompProjRequest(ResultSet rs) {
		try {
			if (rs.getString("compProj").equals("Yes")) {
				String line = "Projection - Computer:\t" + rs.getString("quantCompProj") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getCompProjRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getTVVCRDVDRequest(ResultSet rs) {
		try {
			if (rs.getString("tvVCRDVD").equals("Yes")) {
				String line = "TV/VCR/DVD:\t" + rs.getString("quantTVVCR") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getTVVCRDVDRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getTVRequest(ResultSet rs) {
		try {
			if (rs.getString("TV").equals("Yes")) {
				String line = "TV:\t" + rs.getString("quantTV") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getTVRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getSlideProjRequest(ResultSet rs) {
		try {
			if (rs.getString("slideProj").equals("Yes")) {
				String line = "Slide Projector:\t" + rs.getString("quantSlideProj") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getSlideProjRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getOverheadProjRequest(ResultSet rs) {
		try {
			if (rs.getString("overheadProj").equals("Yes")) {
				String line = "Overhead Projector:\t" + rs.getString("quantOverheadProj") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getOverheadProjRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getEaselRequest(ResultSet rs) {
		try {
			if (rs.getString("easel").equals("Yes")) {
				String line = "Easel:\t" + rs.getString("quantEasel") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getEaselRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getPCLaptopRequest(ResultSet rs) {
		try {
			if (rs.getString("pcLaptop").equals("Yes")) {
				String line = "Laptop - PC:\t" + rs.getString("quantPCLaptop") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getPCLaptopRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getAppleLaptopRequest(ResultSet rs) {
		try {
			if (rs.getString("appleLaptop").equals("Yes")) {
				String line = "Laptop - Apple:\t" + rs.getString("quantAppleLaptop") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getAppleLaptopRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getFlipChartRequest(ResultSet rs) {
		try {
			if (rs.getString("flipCharts").equals("Yes")) {
				String line = "Flip Charts:\t" + rs.getString("quantFlipCharts") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getFlipChartsRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getPhoneRequest(ResultSet rs) {
		try {
			if (rs.getString("phones").equals("Yes")) {
				String line = "Phones:\t" + rs.getString("quantPhones") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getPhonesRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getFaxRequest(ResultSet rs) {
		try {
			if (rs.getString("faxMachine").equals("Yes")) {
				String line = "Fax Machine:\t" + rs.getString("quantFax") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getFaxRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getComputerConRequest(ResultSet rs) {
		try {
			if (rs.getString("computerCon").equals("Yes")) {
				String line = "Computer Network Connection:\t" + rs.getString("quantComputerCon") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getComputerConRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getPodiumRequest(ResultSet rs) {
		try {
			if (rs.getString("podium").equals("Yes")) {
				String line = "Podium:\t" + rs.getString("quantPodium") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getPodiumRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getLecturnRequest(ResultSet rs) {
		try {
			if (rs.getString("lecturn").equals("Yes")) {
				String line = "Lecturn:\t" + rs.getString("quantLecturn") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getLecturnRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getVideotapingRequest(ResultSet rs) {
		try {
			if (rs.getString("videotaping").equals("Yes")) {
				String line = "Videotaping:\t" + rs.getString("quantVideotaping") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getVideotapingRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getLaserPointerRequest(ResultSet rs) {
		try {
			if (rs.getString("laserPointer").equals("Yes")) {
				String line = "Laser Pointer:\t" + rs.getString("quantLaserPointer") + "\n";
				return line;
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getLaserPointerRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end AVAcceptQuote.java
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
