package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 							A  V  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to calculate audio visual quotes for requests made by the
 * 			participants.  This class utilizes JDBC calls to get pricing from a MySQL table.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: April 21, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Vector;

public class AVQuote {
	Vector request;
	DatabaseConnectivity db;
	String cdPlayer = null, wirelessMic = null, lavalierMic = null, podiumMic = null, panelMic = null;
	String videoProj = null, compProj = null, tvVCRDVD = null, TV = null, slideProj = null, overheadProj = null;
	String easel = null, pcLaptop = null, appleLaptop = null, flipCharts = null, screen = null, phones = null, faxMachine = null;
	String computerCon = null, podLaptopCon = null, podium = null, lecturn = null, videotaping = null, laserPointer = null;
	String externalSpeakers = null;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public AVQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the AVQuote.java class.  Initializes the request vector for use
	 * 				by class methods.  The AVRequestVector will be passed in.
	 * Input:		Vector
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public AVQuote(Vector v){
		request = new Vector(v);
		db = new DatabaseConnectivity();
	} // end Constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int[] calculateQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method calls the AVCostStructure table and gathers necessary data to calculate
	 * 				and return the quote.  Quotes for all AV service vendors are calculated and placed in an int
	 * 				array.  Currently system is setup for 3 AV vendors.  Additions/deletions will require changes
	 * 				in the costStructure table as well as calculateQuote method.
	 * Input:		none
	 * Output:		int[] <quotes for all towncar providers - caller can use what is needed>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int[] calculateQuote() {
		int[] quoteList = {0,0,0};
		int quoteTotal = 0;
		String[] splitTimes = ((String) request.get(5)).split(":");
		int startHour = Integer.valueOf(splitTimes[0]).intValue();
		int startMinutes = Integer.valueOf(splitTimes[1]).intValue();
		splitTimes = ((String) request.get(6)).split(":");
		int endHour = Integer.valueOf(splitTimes[0]).intValue();
		int endMinutes = Integer.valueOf(splitTimes[1]).intValue();
		int length = (endHour - startHour);

		getAVRequests();

		int id = 1;
		while (id <= 3){
			ResultSet rs = db.submitQuery("SELECT * FROM avCostStructure WHERE uniqueID = '" + id + "'");
			try {
				while (rs.next()){
					quoteTotal = 0;
					if (cdPlayer.equals("Yes"))
						quoteTotal += calcCDPlayerCost(rs);
					if (wirelessMic.equals("Yes"))
						quoteTotal += calcWirelessMicCost(rs);
					if (lavalierMic.equals("Yes"))
						quoteTotal += calcLavalierMicCost(rs);
					if (podiumMic.equals("Yes"))
						quoteTotal += calcPodiumMicCost(rs);
					if (panelMic.equals("Yes"))
						quoteTotal += calcPanelMicCost(rs);
					if (podLaptopCon.equals("Yes"))
						quoteTotal += calcPodLaptopConCost(rs);
					if (videoProj.equals("Yes"))
						quoteTotal += calcVideoProjCost(rs);
					if (compProj.equals("Yes"))
						quoteTotal += calcCompProjCost(rs);
					if (tvVCRDVD.equals("Yes"))
						quoteTotal += calctvVCRDVDCost(rs);
					if (TV.equals("Yes"))
						quoteTotal += calcTVCost(rs);
					if (slideProj.equals("Yes"))
						quoteTotal += calcSlideProjCost(rs);
					if (overheadProj.equals("Yes"))
						quoteTotal += calcOverheadProjCost(rs);
					if (easel.equals("Yes"))
						quoteTotal += calcEaselCost(rs);
					if (pcLaptop.equals("Yes"))
						quoteTotal += calcPCLaptopCost(rs);
					if (appleLaptop.equals("Yes"))
						quoteTotal += calcAppleLaptopCost(rs);
					if (flipCharts.equals("Yes"))
						quoteTotal += calcFlipChartsCost(rs);
					if (screen.equals("Yes"))
						quoteTotal += calcScreenCost(rs);
					if (phones.equals("Yes"))
						quoteTotal += calcPhonesCost(rs);
					if (faxMachine.equals("Yes"))
						quoteTotal += calcFaxMachineCost(rs);
					if (computerCon.equals("Yes"))
						quoteTotal += calcComputerConCost(rs);
					if (podium.equals("Yes"))
						quoteTotal += calcPodiumCost(rs);
					if (lecturn.equals("Yes"))
						quoteTotal += calcLecturnCost(rs);
					if (videotaping.equals("Yes"))
						quoteTotal += calcVideotapingCost(rs);
					if (laserPointer.equals("Yes"))
						quoteTotal += calcLaserPointerCost(rs);
					if (externalSpeakers.equals("Yes"))
						quoteTotal += calcExternalSpeakersCost(rs);
				}
				quoteList[id-1] = (quoteTotal * length);
				rs.close();
			} // end try
			catch (SQLException e) {
				System.out.println("EXCEPTION: AVQuote.calculateQuote: \n\tHere's the error: " + e);
			} // end catch
				id++;
		} // end while (id)
		return(quoteList);
	} // end calculateQuote()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public getAVRequests()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method checks the request vector to determine what items the user has requested.  The
	 * 				string values are assigned to each particular item and used in CalculateQuote to determine
	 * 				if that items calculateCost method should be called.
	 * Input:		none
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void getAVRequests(){
		cdPlayer = (String)request.get(13);
		wirelessMic = (String)request.get(14);
		lavalierMic = (String)request.get(15);
		podiumMic = (String)request.get(16);
		panelMic = (String)request.get(17);
		podLaptopCon = (String)request.get(18);
		videoProj = (String)request.get(19);
		compProj = (String)request.get(20);
		tvVCRDVD = (String)request.get(21);
		TV = (String)request.get(22);
		slideProj = (String)request.get(23);
		overheadProj = (String) request.get(24);
		easel = (String)request.get(25);
		pcLaptop = (String)request.get(26);
		appleLaptop = (String)request.get(27);
		flipCharts = (String)request.get(28);
		screen = (String)request.get(29);
		phones = (String)request.get(30);
		faxMachine = (String)request.get(31);
		computerCon = (String)request.get(32);
		podium = (String)request.get(33);
		lecturn = (String)request.get(34);
		videotaping = (String)request.get(35);
		laserPointer = (String)request.get(36);
		externalSpeakers = (String)request.get(61);
	} // end getAVRequests()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcCDPlayerCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the cdPlayer(s) requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <cdPlayerCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcCDPlayerCost(ResultSet rs){
		int total = 0, quant = 0, price = 0;
		// location of cdPlayer data in vector is as follows: quant@37
		try {
			quant = Integer.valueOf((String) request.get(37)).intValue();
			price = rs.getInt("cdPlayerCost");
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcCDPlayerCost:\n\t cdPlayer total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcCDPlayerCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcWirelessMicCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the wirelessMic(s) requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <wirelessMicCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcWirelessMicCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of chair data in vector is as follows: quant@38
		try {
			price = rs.getInt("wirelessMicCost");
			quant = Integer.valueOf((String) request.get(38)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcWirelessMicCost:\n\t wirelessMic total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calWirelessMicCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcLavalierMicCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the lavalierMic requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <cdPlayerCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcLavalierMicCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of lavalierMic data in vector is as follows: quant@39
		try {
			price = rs.getInt("lavalierMicCost");
			quant = Integer.valueOf((String) request.get(39)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calclavalierMicCost:\n\t lavalierMic total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end callavalierMicCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcPodiumMicCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the PodiumMic tables requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <podiumMicCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcPodiumMicCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of PodiumMictable data in vector is as follows: quant@40
		try {
			price = rs.getInt("podiumMicCost");
			quant = Integer.valueOf((String) request.get(40)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcPodiumMicCost:\n\t PodiumMic total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calPodiumMicCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcPanelMicCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the pipe drapes requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <panelMicCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcPanelMicCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of PanelMic data in vector is as follows: quant@41
		try {
			price = rs.getInt("panelMicCost");
			quant = Integer.valueOf((String) request.get(41)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcPanelMicCost:\n\t PanelMic total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calPanelMicCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcPodLaptopConCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for podLaptopCon requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <podLaptopConCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcPodLaptopConCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of podLaptopCon data in vector is as follows: quant@42
		try {
			price = rs.getInt("podLaptopConCost");
			quant = Integer.valueOf((String) request.get(42)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcPodLaptopConCost:\n\t podLaptopCon total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calPanelMicCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcVideoProjCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the VideoProj tables requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <cdPlayerCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcVideoProjCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of VideoProj data in vector is as follows: quant@43
		try {
			price = rs.getInt("videoProjCost");
			quant = Integer.valueOf((String) request.get(43)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcVideoProjCost:\n\t VideoProj total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calVideoProjCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcCompProjCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the CompProj tables requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <cdPlayerCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcCompProjCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of CompProj table data in vector is as follows: quant@44
		try {
			price = rs.getInt("compProjCost");
			quant = Integer.valueOf((String) request.get(44)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcCompProjCost:\n\t CompProj Table total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calCompProjCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calctvVCRDVDCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the tvVCRDVD requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calctvVCRDVDCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of privacy screen data in vector is as follows: quant@45
		try {
			price = rs.getInt("tvVCRDVDCost");
			quant = Integer.valueOf((String) request.get(45)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calctvVCRDVDCost:\n\t Privacy Screen total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calctvVCRDVDCost()


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcTVCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the TVs requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcTVCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of TV data in vector is as follows: quant@46
		try {
			price = rs.getInt("TVCost");
			quant = Integer.valueOf((String) request.get(46)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcTVCost:\n\t TV total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcTVCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcslideProjCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the SlideProjs requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcSlideProjCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of slideProj data in vector is as follows: quant@47
		try {
			price = rs.getInt("slideProjCost");
			quant = Integer.valueOf((String) request.get(47)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcSlideProjCost:\n\t slideProj total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcSlideProjCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcOverheadProjCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the OverheadProjs requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcOverheadProjCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of overheadProj data in vector is as follows: quant@48
		try {
			price = rs.getInt("overheadProjCost");
			quant = Integer.valueOf((String) request.get(48)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcOverheadProjCost:\n\t overheadProj total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcOverheadProjCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcEaselCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the Easels requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcEaselCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of easel data in vector is as follows: quant@49
		try {
			price = rs.getInt("easelCost");
			quant = Integer.valueOf((String) request.get(49)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcEaselCost:\n\t easel total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcEaselCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcPCLaptopCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the PCLaptops requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcPCLaptopCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of pcLaptop data in vector is as follows: quant@50
		try {
			price = rs.getInt("pcLaptopCost");
			quant = Integer.valueOf((String) request.get(50)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcPCLaptopCost(ResultSet):\n\t laptop total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcPCLaptopCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcAppleLaptopCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the appleLaptops requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcAppleLaptopCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of appleLaptop data in vector is as follows: quant@51
		try {
			price = rs.getInt("appleLaptopCost");
			quant = Integer.valueOf((String) request.get(51)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcAppleLaptopCost:\n\t laptop total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcAppleLaptopCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcFlipChartsCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the FlipCharts requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcFlipChartsCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of flipCharts data in vector is as follows: quant@52
		try {
			price = rs.getInt("flipChartsCost");
			quant = Integer.valueOf((String) request.get(52)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcFlipChartsCost:\n\t Flip Charts total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcFlipChartsCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcScreenCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the Screens requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcScreenCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of screen data in vector is as follows: quant@53
		try {
			price = rs.getInt("screenCost");
			quant = Integer.valueOf((String) request.get(53)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcScreenCost:\n\t Screen total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcScreenCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcPhonesCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the Phoness requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcPhonesCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of phones data in vector is as follows: quant@54
		try {
			price = rs.getInt("phonesCost");
			quant = Integer.valueOf((String) request.get(54)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcPhonesCost:\n\t Phones total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcPhonesCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcFaxMachineCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the FaxMachines requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcFaxMachineCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of faxMachine data in vector is as follows: quant@55
		try {
			price = rs.getInt("faxMachineCost");
			quant = Integer.valueOf((String) request.get(55)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcFaxMachineCost:\n\t FaxMachine total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcFaxMachineCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcComputerConCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the computerCon requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcComputerConCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of computerCon data in vector is as follows: quant@56
		try {
			price = rs.getInt("computerConCost");
			quant = Integer.valueOf((String) request.get(56)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcComputerConCost:\n\t computerCon total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcComputerConCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcPodiumCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the Podiums requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcPodiumCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of podium data in vector is as follows: quant@57
		try {
			price = rs.getInt("podiumCost");
			quant = Integer.valueOf((String) request.get(57)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcPodiumCost:\n\t Podium total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcPodiumCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcLecturnCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the Lecturns requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcLecturnCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of lecturn data in vector is as follows: quant@58
		try {
			price = rs.getInt("lecturnCost");
			quant = Integer.valueOf((String) request.get(58)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcLecturnCost:\n\t Lecturn total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcLecturnCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcVideotapingCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the Videotapings requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcVideotapingCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of videotaping data in vector is as follows: quant@59
		try {
			price = rs.getInt("videotapingCost");
			quant = Integer.valueOf((String) request.get(59)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcVideotapingCost:\n\t Videotaping total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcVideotapingCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcLaserPointerCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the laserPointers requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcLaserPointerCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of laserPointer data in vector is as follows: quant@60
		try {
			price = rs.getInt("laserPointerCost");
			quant = Integer.valueOf((String) request.get(60)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcLaserPointerCost:\n\t laserPointer total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcLaserPointerCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcExternalSpeakersCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the externalSpeakers requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcExternalSpeakersCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of laserPointer data in vector is as follows: quant@62
		try {
			price = rs.getInt("externalSpeakersCost");
			quant = Integer.valueOf((String) request.get(62)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: AVQuote.calcExternalSpeakersCost:\n\t externalSpeakers total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcExternalSpeakersCost()
//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 									// end AVQuote.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

