package edu.cmu.radar.vendor;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Properties;
import java.util.ResourceBundle;

import org.apache.log4j.Logger;


public class CancelQuote {

	private static Properties props = null;
    private static Logger logger = Logger.getLogger(CancelQuote.class);
    
  private sendEmail pushEmail;
  private String[] data;

    public CancelQuote() {
      sendEmail pushEmail = new sendEmail();
      data = new String[3];
    }

    public void sendCancellationEmail(String quoteID, String type, String contactEmail, String from) {
      data = getIMAPData();
      String subject = type + "Quote Cancellation";
      String messageBody = "Order Id: " + quoteID + "has been cancelled.";
      pushEmail.sendMail(data[0], data[1], data[2], contactEmail, from, subject, messageBody);
    } // end sendCancellationEmail


    public String[] getIMAPData(){
      ResourceBundle rb = null;
      try {
    	  rb = ResourceBundle.getBundle("properties/vendorDB");
      } catch(Exception e) {} // getBundle throws an exception if the properties file doesnt exist
      String[] data = new String[3];
      data[0] = getValueForKey(rb, "", "radar.vendor.imap.user");
      data[1] = getValueForKey(rb, "", "radar.vendor.imap.password");
      data[2] = getValueForKey(rb, "", "radar.vendor.imap.host");
      return data;
    }

    // Helper function to search for key in System properties or vendorDB.properties
    // Same function present in DatabaseConnectivity.java. 
    // Parameter list is slightly different.
    public String getValueForKey(ResourceBundle rb, String defaultValue, String key) {
    	String result = null;
    	if (props == null) {
    		props = new Properties(System.getProperties());
    		addProps(props, "radar.properties");
    		addProps(props, "user.properties");
    	}
    	
    	result = props.getProperty(key);
    	if (result == null)
    	{
    		try {
    			result = rb.getString(key);
    		}
    		catch(Exception e) {
    			//To catch MissingResourceException primarily
    			result = null;
    		}
    	}
    	if(result == null)
    		return defaultValue;
    	else
    		return result;
    }



    /**
     * add properties from a file to the set of System properties
     * @param ret Properties to which will be added the contents of the file specified
     * @param filename the file which contains the properties to be added to the System
     */
    // here's where we'd make radar.properties load from c:/radar/run
    // (for tomcat, e.g.)
    private void addProps(Properties ret, String filename) {
    	String home = System.getProperty("user.home");
    	logger.debug("user.home is '" + home + "'");
    	InputStream is;
    	if (null != home) {
    		File f = new File(home + File.separator + filename);
    		if (f.exists()) {
    			logger.debug("reading " + f + " first");
    			try {
    				is = new FileInputStream(f);
    				ret.load(is);
    			} catch (Exception e) {
    			logger.error(f + ": " + e);
    		}
	    } else
	    	logger.debug(f + ": is not a file");
    	}
    	File f = new File(filename);
    	if (f.exists()) {
    		logger.debug("now reading " + f);
    		try {
    			is = new FileInputStream(f);
    			ret.load(is);
    		} catch (Exception e) {
    			logger.error(filename + ": " + e);
    		}
    	} else
    		logger.debug(f + ": doesn't exist, moving on");
    }

} // end CancelQuote
