package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 					C A T E R I N G A C C E P T Q U O T E . J A V A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to gather Catering request data for a specific id and set it
 * 			up in a nice format for reading.  Calls are made to the CateringRequest table
 * 			to retrieve request data.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: May 23, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  - - - - - - - - - - - - - public class CateringAcceptQuote  - - - - - - - - - - - - - -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
public class CateringAcceptQuote {
	public String messageBody = null;
	private String vendorName = null;
	public String contactEmail = null;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public CateringAcceptQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the CateringAcceptQuote.java class.  Initializes the messageBody by calling
	 * 				setupMessageBody.  The class variable messageBody is used by the QuoteAcceptedServlet to
	 * 				construct a confirmation email to the user
	 * Input:		String <requestID - the unique number in the CateringRequest table>
	 * 				String <vendorID - could be catering1, 2, or 3, passed in through the http stream>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public CateringAcceptQuote(String requestID, String vendorID, String baseURL){
		DatabaseConnectivity db = new DatabaseConnectivity();
		ResultSet rs = db.submitQuery("SELECT * FROM cateringRequests WHERE uniqueID ='" + requestID + "'");
		ResultSet descrip = db.submitQuery("SELECT * FROM cateringItemDescription where uniqueID = '1'");
		try {
			boolean crap = rs.next();
			crap = descrip.next();
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		contactEmail = assignContactEmail(rs);
		messageBody = setupMessageBody(requestID, vendorID, rs, descrip, baseURL);
	} // end constructor

	public String assignContactEmail(ResultSet rs) {
		try {
			return (rs.getString("contactEmail"));
		} catch (SQLException e) {

		}
		return "Error";
	}

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public setupMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method constructs the message body by querying the CateringRequest table and placing
	 * 				the variables in a very long String.  This method is called by the Constructor to initialize
	 * 				the messageBody class variable.  This method calls submitQuery (from DatabaseConnectivity.java),
	 * 				determineQuoteNumber, and assembleMessageBody.
	 * Input:		String <requestID - the unique number in the CateringRequest table>
	 * 				String <vendorID - could be Catering1, 2, or 3, passed in through the http stream>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupMessageBody(String requestID, String vendorID, ResultSet rs, ResultSet descrip, String baseURL) {
		String quoteNumber = determineQuoteNumber(vendorID);
		String link = baseURL + determineCateringVendor(vendorID, requestID);
		if (quoteNumber.equals("error")) {
			System.err.println("EXCEPTION: CateringAcceptQuote.setupMessageBody:\n\tThere was an error determining the quoteNumber");
			System.out.println("EXCEPTION: CateringAcceptQuote.setupMessageBody:\n\tThere was an error determining the quoteNumber");
		}
		return (assembleMessageBody(rs, descrip, quoteNumber, link));
	} // end setupMessageBody

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public assembleMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for pulling data from the ResultSet and formatting it in a clean
	 * 				manner so it's easily readable.
	 * Input:		ResultSet <rs>
	 * 				ResultSet <descrip>
	 * 				String <quoteNumber - identifies which quote to pull, either quote1, 2, or 3>
	 * 				String <link - web address user can click to view this request>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String assembleMessageBody(ResultSet rs, ResultSet descrip, String quoteNumber, String link) {
		String s = null;
		String quoteId = null;
		int uniqueId = -1;
		String quotedesc = "";
		try {
		    quoteId = rs.getString("quoteid").substring(8); //number tagged to catering
		    uniqueId = rs.getInt("uniqueid");
		    if(quoteId.equals(new Integer(uniqueId).toString()))
		    	quotedesc = "detailed ";
		    else
		    	quotedesc = "modified ";

		    s = "Request for Catering Service.  \n" + 
				"Your "+ quotedesc +"quote from " + vendorName +
		        " can be found below.\n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Order Id:\t" + quoteId + "\n" +
				"Event Title:\t\t" + rs.getString("eventTitle") + "\n" +
				"Event Location:\t\t" + rs.getString("eventLocation") + "\n" +
				getDate(rs) +
				"Contact First Name:\t" + rs.getString("contactFirstName") + "\n" +
				"Contact Last Name:\t" + rs.getString("contactLastName") + "\n" +
				"Contact Email:\t\t" + rs.getString("contactEmail") + "\n" +
				"Setup Complete Time:\t\t\t" + rs.getString("setupComplete") + "\n" +
				"Breakdown Start Time:\t\t" + rs.getString("breakdownStart") + "\n" +
				getSelection(rs, descrip) +
				getVeganRequest(rs) +
				getVegetarianRequest(rs) +
				getAtkinsRequest(rs) +
				getKosherRequest(rs) +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Quote Total:\t$" + rs.getString(quoteNumber) + "\n\n" +
				"Click the link below to review, modify, or cancel your Catering Request:\n\n" +
				link;

		} // end try
		catch(Exception e){
			System.out.println("EXCEPTION: CateringAcceptQuote:assembleMessageBody\n\t An error occurred while assembling message body.\n Here it is: " + e);
		}
		return s;
	} // end printCateringRequestData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineQuoteNumber()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying which quote number in the request table corresponds
	 * 				to the vendorID.
	 * Input:		String <vendorID>
	 * Output:		String <quoteNumber - either quote1, 2, or 3>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineQuoteNumber(String vendorID){
		if (vendorID.equals("catering1")) {
			vendorName = "MAXIMAL FOODS";
			return "quote1" ;
		}
		if (vendorID.equals("catering2")) {
			vendorName = "PITTSBURGH CATERING";
			return "quote2";
		}
		if (vendorID.equals("catering3")) {
			vendorName = "BREAKFAST BREAK";
			return "quote3";
		}
		else {
			System.out.println("EXCEPTION: CateringAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return "error";
		}
	} // end determineQuoteNumber

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineCateringVendor()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying the Catering vendor and returning the appropriate
	 * 				link to quote page.
	 * Input:		String <vendorID> , String <requestID>
	 * Output:		String <link>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineCateringVendor(String vendorID, String requestID){
		if (vendorID.equals("catering1"))
			return ("/myapp/webForms/Catering/MaximalReviewQuote.jsp?uniqueID=" + requestID);
		if (vendorID.equals("catering2"))
			return ("/myapp/webForms/Catering/PghReviewQuote.jsp?uniqueID=" + requestID);
		if (vendorID.equals("catering3"))
			return ("/myapp/webForms/Catering/BBreakReviewQuote.jsp?uniqueID=" + requestID);
		else {
			System.out.println("EXCEPTION: CateringAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return ("/myapp/webForms/Error.htm");
		}
	} // end determineQuoteNumber


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public getSelection()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for gathering the catering option selected as well as the
	 * 				number of meals requested.
	 * Input:		ResultSet <rs>
	 * 				ResultSet <descrip>
	 * Output:		String
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String getSelection(ResultSet rs, ResultSet descrip) {
		try {
			String selection = rs.getString("selection");
			String selectionName = descrip.getString(selection);
			return("Catering Selection:\t" + selection + "\n\tNumber of Meals:\t" + rs.getString("quantMeals") + "\n");
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: CateringAcceptQuote:getSelection - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public get*Request() Methods      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		The following methods are used to determine if the user requested a specific item.  If so
	 * 				the method will return a string of the format <ITEM>:\t<QUANTITY>.  These
	 * 				methods are called by assembleMessageBody.
	 * Input:		ResultSet <rs>
	 * Output:		String
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String getDate(ResultSet rs) {
		try {
			String date = "Event Date:\t" + rs.getString("eventMonth") + " " + rs.getString("eventDayOfMonth") + ", " +
				rs.getString("eventYear")+ "\n";
				return date;
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: CateringAcceptQuote:getDate - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getVeganRequest(ResultSet rs) {
		try {
			if (rs.getString("vegan").equals("Yes")) {
				return ("Vegan Meals:\t\t" + rs.getString("quantVegan") + "\n");
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: CateringAcceptQuote:getVeganRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getVegetarianRequest(ResultSet rs) {
		try {
			if (rs.getString("vegetarian").equals("Yes")) {
				 return ("Vegetarian Meals:\t\t" + rs.getString("quantVegetarian") + "\n");
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: CateringAcceptQuote:getVegetarianRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getAtkinsRequest(ResultSet rs) {
		try {
			if (rs.getString("atkins").equals("Yes")) {
				return ("Atkins-approved Meals:\t" + rs.getString("quantAtkins") + "\n");
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: CateringAcceptQuote:getAtkinsRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getKosherRequest(ResultSet rs) {
		try {
			if (rs.getString("kosher").equals("Yes")) {
				return("Kosher Meals:\t\t" + rs.getString("quantKosher") + "\n");
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: CateringAcceptQuote:getKosherRequest - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end CateringAcceptQuote.java
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -