package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 					C  A  T  E  R  I  N  G  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to calculate catering quotes for requests made by the
 * 			participants.  This class utilizes JDBC calls to get pricing from a MySQL table.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: May 23, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Vector;

public class CateringQuote {
	Vector request;
	DatabaseConnectivity db;
	String selection = null, vegan = null, vegetarian = null, atkins = null, kosher = null;
	int quantMeals = 0;
	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public CateringQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the CateringQuote.java class.  Initializes the request vector for use
	 * 				by class methods.  The CateringRequestVector will be passed in.
	 * Input:		Vector
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public CateringQuote(Vector v){
		request = new Vector(v);
		db = new DatabaseConnectivity();
	} // end Constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int[] calculateQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method calls the CateringCostStructure table and gathers necessary data to calculate
	 * 				and return the quote.  Quotes for all Catering service vendors are calculated and placed in an int
	 * 				array.  Currently system is setup for 3 Catering vendors.  Additions/deletions will require changes
	 * 				in the costStructure table as well as calculateQuote method.
	 * Input:		none
	 * Output:		int[] <quotes for all catering providers - caller can use what is needed>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int[] calculateQuote() {
		int[] quoteList = {0,0,0};
		int quoteTotal = 0;
		getCateringRequests();

		int id = 1;
		while (id <= 3){
			ResultSet rs = db.submitQuery("SELECT * FROM cateringCostStructure WHERE uniqueID = '" + id + "'");
			try {
				while (rs.next()){
					quoteTotal = 0;
					quoteTotal += calcSelectionCost(rs);
					if (vegan.equals("Yes"))
						quoteTotal += calcVeganCost(rs);
					if (vegetarian.equals("Yes"))
						quoteTotal += calcVegetarianCost(rs);
					if (atkins.equals("Yes"))
						quoteTotal += calcAtkinsCost(rs);
					if (kosher.equals("Yes"))
						quoteTotal += calcKosherCost(rs);

				}
				quoteList[id-1] = quoteTotal;
				rs.close();
			} // end try
			catch (SQLException e) {
				System.out.println("EXCEPTION: CateringQuote.calculateQuote: \n\tHere's the error: " + e);
			} // end catch
				id++;
		} // end while (id)
		return(quoteList);
	} // end calculateQuote()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public getCateringRequests()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method checks the request vector to determine what items the user has requested.  The
	 * 				string values are assigned to each particular item and used in CalculateQuote to determine
	 * 				if that items calculateCost method should be called.
	 * Input:		none
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void getCateringRequests(){
		selection = (String)request.get(14);
		quantMeals = Integer.valueOf((String) request.get(13)).intValue();
		vegan = (String)request.get(15);
		vegetarian = (String) request.get(17);
		atkins = (String)request.get(19);
		kosher = (String)request.get(21);

		//System.out.println("DEBUG: CateringQuote.getCateringRequests:\n\t Here are the request values:\n\tselection: " + selection +
		//				"\n\tquantMeals: " + quantMeals + "\n\tvegan: " + vegan + "\n\tvegetarian: " + vegetarian +
		//				"\n\tatkins: " + atkins + "\n\tkosher: " + kosher);
	} // end getCateringRequests()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcVeganCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the vegan meals requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <veganCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcVeganCost(ResultSet rs){
		int total = 0, quant = 0, price = 0;
		// location of vegan data in vector is as follows: quant@16
		try {
			quant = Integer.valueOf((String) request.get(16)).intValue();
			price = rs.getInt("veganCost");
			total = (quant * price);
		} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: CateringQuote.calcVeganCost:\n\t vegan total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcVeganCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcVegetarianCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for number of vegetarian meals requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <vegetarianCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcVegetarianCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of vegetarian data in vector is as follows: quant@18
		try {
			price = rs.getInt("vegetarianCost");
			quant = Integer.valueOf((String) request.get(18)).intValue();
			total = (quant * price);
		} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: CateringQuote.calcVegetarianCost:\n\t vegetarian total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcVegetarianCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcAtkinsCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the atkins requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <cdPlayerCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcAtkinsCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of atkins data in vector is as follows: quant@20
		try {
			price = rs.getInt("atkinsCost");
			quant = Integer.valueOf((String) request.get(20)).intValue();
			total = (quant * price);
		} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: CateringQuote.calcAtkinsCost:\n\t atkins total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcAtkinsCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcKosherCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the number kosher meals requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <kosherCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcKosherCost(ResultSet rs){
		int total = 0, price = 0, quant = 0;
		// location of kosher data in vector is as follows: quant@22
		try {
			price = rs.getInt("kosherCost");
			quant = Integer.valueOf((String) request.get(22)).intValue();
			total = (quant * price);
		}	 // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: CateringQuote.calcKosherCost:\n\t Kosher total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcKosherCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcSelectionCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the type of meal requested.
	 * 				This method uses the <selection> value to query into the DB to retrieve the cost for that
	 * 				specific meal type. This method uses <quantMeals> as well (no need to peek into the request
	 * 				vector).
	 * Input:		ResultSet <rs>
	 * Output:		int <selectionCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcSelectionCost(ResultSet rs){
		int total = 0, price = 0;
		String selectionCost = selection + "Cost";
		try {
			price = rs.getInt(selectionCost);
			total = (quantMeals * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: CateringQuote.calcSelectionCost:\n\t selection cost total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcSelectionCost()

//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 									// end CateringQuote.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

