package edu.cmu.radar.vendor;
/*************************************************************************************************************
 *				 	D  A  T  A  B  A  S  E  C  O  N  N  E  C  T  I  V  I  T  Y  .  J  A  V  A		  		 *
 *************************************************************************************************************
 * Purpose: 	This Java program provides database connectivity and querying methods for use by the test
 * 				harness servlet (TestHarnessServlet.java, TestHarnessTimer.java)
 * Functionality:  Implements connections to MySQL DB and provides querying methods specific to each class that
 * 					uses DatabaseConnectivity.java
 * Input: 	none
 * Output: 	none
 * Dependencies:	none
 * Author: 		Kyle A Cunningham <kcunning@cs.cmu.edu>
 ************************************************************************************************************/

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Properties;
import java.util.ResourceBundle;
import java.util.StringTokenizer;
import java.util.Vector;

import org.apache.log4j.Logger;


public class DatabaseConnectivity {

	public Connection con;
	static Statement st = null;
    static ResultSet rs = null;
    sendEmail pushEmail;
    ResourceBundle rb = null;
    
    String driverClass ="org.postgresql.Driver";
    String driver = "jdbc:postgresql";
    String host = "vendors.self.radar.cs.cmu.edu";
    String port = "5432";
    String database = "vendor";
    String username = "postgres";
    String password = "f22f22"; //Clear-text password
    String dbURL = "";
    
    /**
     * log4j logger
     */
    private static Logger logger = Logger.getLogger(DatabaseConnectivity.class);
    
    private static Properties props = null;
    
    /*
     * Constructor for initializing database properties. For each value required,
     * 1. First check from System properties
     * 2. If empty, get values from vendorDB.properties.
     * 3. If values are not found in the properties file,
     *    then default to the initialized values
     */
    public DatabaseConnectivity() {
    	try {
    		rb = ResourceBundle.getBundle("properties/vendorDB");
    	} catch (Exception e) {System.out.println("properties resource bundle not found, hopefully the system properties are, lulz!");}  // getBundle throws an exception if the properties file doesnt exist
    	
    	driverClass = getValueForKey(driverClass, "radar.vendor.jdbc.driver_class");
    	driver = getValueForKey(driver, "radar.vendor.jdbc.driver");
    	host = getValueForKey(host, "radar.vendor.jdbc.host");
    	port = getValueForKey(port, "radar.vendor.jdbc.port");
    	database = getValueForKey(database, "radar.vendor.jdbc.database");
    	username = getValueForKey(username, "radar.vendor.jdbc.username");
    	password = getValueForKey(password, "radar.vendor.jdbc.password");
    	
    	//Create database URL with driver, host, port and database
    	dbURL = driver+"://"+host+":"+port+"/"+database+"?compatible=7.4";
    	System.out.println("connecting to db using: " + dbURL);
    }
    
    /**
     * add properties from a file to the set of System properties
     * @param ret Properties to which will be added the contents of the file specified
     * @param filename the file which contains the properties to be added to the System
     */
    // here's where we'd make radar.properties load from c:/radar/run
    // (for tomcat, e.g.)
    private void addProps(Properties ret, String filename) {
    	String home = System.getProperty("user.home");
    	logger.debug("user.home is '" + home + "'");
    	InputStream is;
    	if (null != home) {
    		File f = new File(home + File.separator + filename);
    		if (f.exists()) {
    			logger.debug("reading " + f + " first");
    			try {
    				is = new FileInputStream(f);
    				ret.load(is);
    			} catch (Exception e) {
    			logger.error(f + ": " + e);
    		}
	    } else
	    	logger.debug(f + ": is not a file");
    	}
    	File f = new File(filename);
    	if (f.exists()) {
    		logger.debug("now reading " + f);
    		try {
    			is = new FileInputStream(f);
    			ret.load(is);
    		} catch (Exception e) {
    			logger.error(filename + ": " + e);
    		}
    	} else
    		logger.debug(f + ": doesn't exist, moving on");
    }
    
    // Helper function to search for key in System properties or vendorDB.properties
    private String getValueForKey(String defaultValue, String key) {
    	String result = null;

    	if (props == null) {
    		props = new Properties(System.getProperties());
    		addProps(props, "radar.properties");
    		addProps(props, "user.properties");
    	}
    	
    	result = props.getProperty(key);
    	if (result == null)
    	{
    		try {
    			result = rb.getString(key);
    		}
    		catch(Exception e) {
    			//To catch MissingResourceException primarily
    			result = null;
    		}
    	}
    	if(result == null)
    		return defaultValue;
    	else
    		return result;
    }

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public Connection setupDBConnection()         													   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		loads database driver and gets a connection to DB
	 * Input:		none
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public Connection setupDBConnection() {
		closeDBConnection();
		con = null;
		try {
		      Class.forName(driverClass).newInstance();
		      con = DriverManager.getConnection(dbURL, username, password);
		}
		catch (Exception e) {
		      System.out.println("DatabaseConnectivity.java EXCEPTION: " + e);
		}
		return con;
	} // end setupDBConnection()

	public void closeDBConnection() {
		try {
		    if(con != null)
		    	if(con.isClosed() == false)
		    		con.close();
			con = null;
		}
		catch (Exception e) {
		      System.out.println("DatabaseConnectivity.java EXCEPTION: " + e);
		}
	} // end closeDBConnection()
	
	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String setupQuery()         																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		setupQuery takes arguments and sets up the query
	 * Input:		String <requestType>
	 * Output:		String - query setup for execution
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupQuery(String vendorTypeID){
		String query = "SELECT vendorName, vendorEmail, stockMessageBody, responsivity FROM vendorInformation WHERE vendorTypeID = '" +
						vendorTypeID + "'";
	// -- DEBUG --
		System.out.println("DEBUG: DatabaseConnectivity.setupQuery(String):\n\there's the query that was setup: " + query);
		return query;
	} // end setupQuery(String)

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String setupQuery()         																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		setupQuery takes arguments and sets up the query
	 * 				- this method is used by TestHarnessTimer.java
	 * Input:		int <minutes>, int <seconds>
	 * Output:		String - query setup for execution
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupQuery(int minutes, int seconds, String type) {
		String query = null;
		if (type.equals("select")){
			query = "SELECT * FROM messageInjection WHERE (minutes = " + minutes + " AND seconds = " + seconds + ")";
			System.out.println("DEBUG: DatabaseConnectivity.setupQuery(int): \n\tHere's the query that was setup: " + query);
		}
		if (type.equals("update")){
			query = "UPDATE sessionTime SET minutes = \"" + minutes + "\", seconds = \"" + seconds + "\" WHERE id='1'";
			System.out.println("DEBUG: DatabaseConnectivity.setupQuery(int): \n\tHere's the query that was setup: " + query);
		}
		return query;

	} // end setupQuery(int)

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String setupQuery()         																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		setupQuery takes arguments and sets up the query
	 * 				- this method is used by PlanAMeetingServlet.java
	 * Input:		Object <person_id>, String <date>
	 * Output:		String - query setup for execution
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupQuery(int person_id, String date) {
		String query = "SELECT * FROM schedule WHERE (person_id = '" + person_id + "' AND date = '" + date + "')";
		System.out.println("DEBUG: DatabaseConnectivity.setupQuery(String, date): \n\tHere's the query that was setup: " + query);
		return query;

	} // end setupQuery(int)

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String setupLogUpdate()         																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		setupLogUpdate takes arguments and sets up the update query for the log table
	 * 				this method is used by PlanAMeetingServlet.java
	 * Input:		String <eventSource>, String <pageLoad>, String <pageSubmit>, String <description>
	 * Output:		String - query setup for execution
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupLogUpdate(String source, String pageLoad, String pageSubmit, String descrip) {
		String query = "INSERT INTO log (eventSource, pageLoaded, pageSubmitted, description) VALUES ('" + source +
						"','" + pageLoad + "','" + pageSubmit + "','" + descrip + "')";
		System.out.println("DEBUG: DatabaseConnectivity.setupLogUpdate\n\t Here's the query: " + query);
		return query;
	} // end setupLogUpdate
	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String submitQuery()         																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		setupQuery takes arguments and sets up the query
	 * Input:		String query
	 * Output:		Vector - containing info from the result set.
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	protected Vector submitQuery(String query, int flag){
		Vector v = new Vector();
		con = setupDBConnection();
		Statement st = null;
	    ResultSet rs = null;
		try {
			switch (flag) {
				// call from TestHarnessServlet.java
				case 1: {	st = con.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
							rs = st.executeQuery(query);
							while(rs.next()) {
								v.add(rs.getString("vendorName")); 	// vendorName
								v.add(rs.getString("vendorEmail")); 	// vendorAddress
								v.add(rs.getString("stockMessageBody"));
								v.add(rs.getString("responsivity"));//messageBody

								//System.out.println(v.get(0) + ", " + v.get(1) + ", " + v.get(2));
							} // end while
						break;
				} // case 1

				// call from TestHarnessTimer.java
				case 2: {	st = con.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
							rs = st.executeQuery(query);
							while(rs.next()) {
								v.add(rs.getString("sender")); 	// vendorName
								v.add(rs.getString("senderEmail")); 	// vendorAddress
								v.add(rs.getString("contactEmail"));
								v.add(rs.getString("message"));//messageBody
							} // end while
						break;
				} // case 2

				// just an insert, don't need any data back
				case 3: {	System.out.println("DEBUG: DatabaseConnectivity.submitQuery:\n\t In case 3");
							st = con.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
							int crap = st.executeUpdate(query);
						break;}
			} //end switch
			con.close();
		} // end try
	      catch (SQLException e) {
			System.out.println("EXCEPTION: DatabaseConnectivity.submitQuery:\n\t" + e);
		} // end catch
	      catch (Exception e1)
	      {
	    	  System.out.println("GENEXCEPTION: DatabaseConnectivity.submitQuery:\n\t" + e1);
	      }

	    return v;
	} // end submitQuery()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * protected ResultSet submitQuery()         																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		setupQuery takes arguments and sets up the query - called by PlanAMeetingServlet.java
	 * Input:		String query
	 * Output:		ResultSet
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public ResultSet submitQuery(String query) {
		con = setupDBConnection();
		Statement st = null;
	    ResultSet rs = null;
		System.out.println("DEBUG: DatabaseConnectivity:\n\tHere's the query: " + query);
	    try {
			st = con.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
			rs = st.executeQuery(query);
			//con.close();
	    }
		catch (SQLException e) {
			System.out.println("EXCEPTION: DatabaseConnectivity.submitQuery:\n\t" + e);
		}
		return rs;
	} // end submitQuery()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * protected String submitQuery()         																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		setupQuery takes arguments and sets up the query - called by QuoteAcceptedServlet.java
	 * Input:		String query
	 * Output:		String <quoteAccepted field value>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	protected String submitQASQuery(String query) {
		con = setupDBConnection();
		Statement st = null;
	    ResultSet rs = null;
		System.out.println("DEBUG: DatabaseConnectivity:\n\tHere's the QASquery: " + query);
	    String value = new String();
		try {
			st = con.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
			rs = st.executeQuery(query);
			rs.next();
			value = rs.getString("quoteAccepted");
			con.close();
	    }
		catch (SQLException e) {
			System.err.println("EXCEPTION: DatabaseConnectivity.submitQASQuery:\n\t" + e);
			System.out.println("EXECPTION: DatabaseConnectivity.submitQASQuery:\n\t" + e);
		}
		return value;
	} // end submitQuery()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * void submitInsertQuery()         																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		setupQuery takes arguments and sets up the query - called by PlanAMeetingServlet.java
	 * Input:		String query
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int submitInsertQuery(String query){
		con = setupDBConnection();
		Statement st = null;
	    System.out.println("DEBUG: DatabaseConnectivity.submitInsertQuery:\n\tHere's the query: " + query);
	    try {
			st = con.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
			int temp = st.executeUpdate(query);
			con.close();
			return temp;
	    }
		catch (SQLException e) {
			System.out.println("EXECPTION: DatabaseConnectivity.submitInsertQuery:\n\t" + e);
		}
		return -1;
	} // end submitInsertQuery()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * 							     I n s e r t    M e t h o d s
	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertAudioVisualData  																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts data from AV form into the audioVisualRequests Table
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertAudioVisualData(Vector v) {
		String query = "INSERT INTO audioVisualRequests "+
		   "(eventTitle, eventLocation, eventMonth, eventDayOfMonth, "+
		   "eventYear, setupComplete, breakdownStart, contactFirstName, contactLastName, " +
		   "contactEmail, AV1, AV2, AV3, cdPlayer,"+
		   "wirelessMic, lavalierMic, podiumMic, panelMic, podLaptopCon, "+
		   "videoProj, compProj, tvVCRDVD, TV, slideProj, "+
		   "overheadProj, easel, pcLaptop, appleLaptop, flipCharts, "+
		   "screen, phones, faxMachine, computerCon, podium, "+
		   "lecturn, videotaping, laserPointer, quantCDPlayer, quantWirelessMic, " +
		   "quantLavalierMic, quantPodMic, quantPanelMic, quantPodLaptopCon, quantVideoProj, "+
		   "quantCompProj, quantTVVCR, quantTV, quantSlideProj, quantOverheadProj, "+
		   "quantEasel, quantPCLaptop, quantAppleLaptop, quantFlipCharts, quantScreen, "+
		   "quantPhones, quantFax, quantComputerCon, quantPodium, quantLecturn, "+
		   "quantVideotaping, quantLaserPointer, externalSpeakers, quantExternalSpeakers, pageLoaded, "+
		   "pageSubmitted, quote1, quote2, quote3) VALUES " +
		   "('" + v.get(0) + "','" + v.get(1) + "','"+ v.get(2) + "','" + v.get(3) + "','" +
		   v.get(4) + "','" + v.get(5) + "','" + v.get(6) + "','" + v.get(7) + "','" + v.get(8) +
		   "','" + v.get(9) + "','" + v.get(10) + "','" + v.get(11) + "','" + v.get(12) + "','" + v.get(13) +
		   "','" + v.get(14) + "','" + v.get(15) + "','" + v.get(16) + "','" + v.get(17) + "','" + v.get(18) +
		   "','" + v.get(19) + "','" + v.get(20) + "','" + v.get(21) + "','" + v.get(22) + "','" + v.get(23) +
		   "','" + v.get(24) + "','" + v.get(25) + "','" + v.get(26) + "','" + v.get(27) + "','" + v.get(28) +
		   "','" + v.get(29) + "','" + v.get(30) + "','" + v.get(31) + "','" + v.get(32) + "','" + v.get(33) +
		   "','" + v.get(34) + "','" + v.get(35) + "','" + v.get(36) + "'," + v.get(37) + "," + v.get(38) +
		   "," + v.get(39) + "," + v.get(40) + "," + v.get(41) + "," + v.get(42) + "," + v.get(43) +
		   "," + v.get(44) + "," + v.get(45) + "," + v.get(46) + "," + v.get(47) + "," + v.get(48) +
		   "," + v.get(49) + "," + v.get(50) + "," + v.get(51) + "," + v.get(52) + "," + v.get(53) +
		   "," + v.get(54) + "," + v.get(55) + "," + v.get(56) + "," + v.get(57) + "," + v.get(58) +
		   "," + v.get(59) + "," + v.get(60) + ",'" + v.get(61) + "'," + v.get(62) + ",'" + v.get(63) +
		   "','" + v.get(64) + "'," + v.get(65) + "," + v.get(66) + "," + v.get(67) + ")";
		System.out.println("DEBUG: DatabaseConnectivity.insertAudioVisualData:\n\t Here's the query: " + query);
		submitQuery(query, 3);
	} // end insertAudioVisualData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertParkingData       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts data from parking form into the parkingRequests Table
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertParkingData(Vector v) {
		String query = "INSERT INTO parkingRequests (pageLoaded, pageSubmitted, eventTitle, eventLocation, " +
			"eventDate, contactFirstName, contactLastName, contactPhone, contactEmail, " +
			"numParkingSpaces, parkingLocation, validationPasses, numValidationPasses, trafficGuard, calculatedQuote) VALUES " +
			"(\"" + v.get(12) + "\",\"" + v.get(13) + "\",\"" + v.get(0) + "\",\"" + v.get(1) + "\",\"" +
			v.get(2) + "\",\"" + v.get(3) + "\",\"" + v.get(4) + "\",\"" + v.get(5) + "\",\"" + v.get(6) +
			"\",\"" + v.get(7) + "\",\"" + v.get(8) + "\",\"" + v.get(9) + "\",\"" + v.get(10) + "\",\"" + v.get(11) +
			"\",\"" + v.get(14) + "\")";
		System.out.println("DEBUG: DatabaseConnectivity.insertParkingRequest:\n\t Here's the query: " + query);
		submitQuery(query, 3);

	} // end insertParkingData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertRentalData       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts data from rental form into the rentalRequests Table
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertRentalData(Vector v) {
		String query = "INSERT INTO rentalRequests (eventTitle, eventLocation, " +
		   "rentalType, singleMonth, singleDay, singleYear, multStartMonth, "+
		   "multStartDay, multStartYear, multEndMonth, multEndDay, multEndYear, "+
		   "numberOfDays, setupComplete, breakdownStart, contactFirstName, contactLastName, " +
		   "contactEmail, rental1, rental2, rental3, tent, "+
		   "tentSize, tentType, tentQuantity, chairs, chairQuantity, "+
		   "chairType, chairColor, staging, stagingSize, stagingQuantity, "+
		   "cocktailTables, cocktailTableSize, cocktailTableQuantity, pipeDrape, pipeDrapeColor, "+
		   "pipeDrapeLength, pipeDrapeQuantity, banquetTables, banquetTableLength, banquetTableQuantity, " +
		   "roundTables, roundTableSize, roundTableQuantity, privacyScreens, privacyScreensQuantity, "+
		   "coatRack, coatRackQuantity, pageLoaded, pageSubmitted, quote1, "+
		   "quote2, quote3) VALUES " +
		   "('" + v.get(0) + "','" + v.get(1) + 
		   "','" + v.get(2) + "','" + v.get(3) + "','" + v.get(4) + "','" + v.get(5) + "','" + v.get(6) +
		   "','" + v.get(7) + "','" + v.get(8) + "','" + v.get(9) + "','" + v.get(10) + "','" + v.get(11) +
		   "'," + v.get(12) + ",'" + v.get(13) + "','" + v.get(14) + "','" + v.get(15) + "','" + v.get(16) +
		   "','" + v.get(17) + "','" + v.get(18) + "','" + v.get(19) + "','" + v.get(20) + "','" + v.get(21) +
		   "','" + v.get(22) + "','" + v.get(23) + "'," + v.get(24) + ",'" + v.get(25) + "'," + v.get(26) +
		   ",'" + v.get(27) + "','" + v.get(28) + "','" + v.get(29) + "','" + v.get(30) + "'," + v.get(31) +
		   ",'" + v.get(32) + "','" + v.get(33) + "'," + v.get(34) + ",'" + v.get(35) + "','" + v.get(36) +
		   "','" + v.get(37) + "'," + v.get(38) + ",'" + v.get(39) + "','" + v.get(40) + "'," + v.get(41) +
		   ",'" + v.get(42) + "','" + v.get(43) + "'," + v.get(44) + ",'" + v.get(47) + "'," + v.get(46) +
		   ",'" + v.get(47) + "'," + v.get(48) + ",'" + v.get(49) + "','" + v.get(50) + "','" + v.get(51) +
		   "','" + v.get(52) + "','" + v.get(53) + "')";
		System.out.println("DEBUG: DatabaseConnectivity.insertRentalRequest:\n\t Here's the query: " + query);
		submitQuery(query, 3);
	} // end insertRentalData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertTowncarData       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts data from towncar form into the towncarRequests Table
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertTowncarData(Vector v) {
		String query = "INSERT INTO towncarRequests (pageLoaded, pageSubmitted, eventTitle, eventLocation, " +
		   "eventDate, contactFirstName, contactLastName, contactPhone, contactEmail, " +
		   "towncarService1, towncarService2, towncarService3, passengerFirstName, passengerLastName, pickupStreet, pickupCity, pickupState, " +
		   "pickupPhone, dropoffStreet, dropoffCity, dropoffState, dropoffPhone, pickupTime, arrivalTime, " +
		   "airportPickup, airline, flightNumber, flightArrivalTime, flightDepartureCity, quote1, quote2, quote3) VALUES " +
		   "(\"" + v.get(27) + "\",\"" + v.get(28) + "\",\"" + v.get(0) + "\",\"" + v.get(1) + "\",\"" +
		   v.get(2) + "\",\"" + v.get(3) + "\",\"" + v.get(4) + "\",\"" + v.get(5) + "\",\"" + v.get(6) +
		   "\",\"" + v.get(7) + "\",\"" + v.get(8) + "\",\"" + v.get(9) + "\",\"" + v.get(10) + "\",\"" + v.get(11) +
		   "\",\"" + v.get(12) + "\",\"" + v.get(13) + "\",\"" + v.get(14) + "\",\"" + v.get(15) + "\",\"" + v.get(16) +
		   "\",\"" + v.get(17) + "\",\"" + v.get(18) + "\",\"" + v.get(19) + "\",\"" + v.get(20) + "\",\"" + v.get(21) +
		   "\",\"" + v.get(22) + "\",\"" + v.get(23) + "\",\"" + v.get(24) + "\",\"" + v.get(25) + "\",\"" + v.get(26) +
		   "\",\"" + v.get(29) + "\",\"" + v.get(30) + "\",\"" + v.get(31) + "\")";
		System.out.println("DEBUG: DatabaseConnectivity.insertTowncarRequest:\n\t Here's the query: " + query);
		submitQuery(query, 3);

	} // end insertTowncarData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertSecurityData       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts data from security form into the securityRequests Table
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * JS: Postgresql is not accepting " as value delimiter. Changing to '.
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertSecurityData(Vector v) {
		String query = "INSERT INTO securityRequests (eventTitle, eventLocation, " +
		   "eventMonth, eventDayOfMonth, eventYear, contactFirstName, contactLastName, contactEmail, " +
		   "crowdControl, trafficControl, parkingAssistance, vip, alcohol, numberSecurityStaff, securityClothing, " +
		   "startTime, endTime, location, funcServeAlcohol, funcGuardValuables, funcMaintainPerimeter, " +
		   "funcMonitorTraffic, funcOpenGarage, funcMaintainPresence, pageLoaded, pageSubmitted, calculatedQuote) VALUES " +
		   "('" + v.get(0) + "','" + v.get(1) + "','" +
		   v.get(2) + "','" + v.get(3) + "','" + v.get(4) + "','" + v.get(5) + "','" + v.get(6) +
		   "','" + v.get(7) + "','" + v.get(8) + "','" + v.get(9) + "','" + v.get(10) + "','" + v.get(11) +
		   "','" + v.get(12) + "','" + v.get(13) + "','" + v.get(14) + "','" + v.get(15) + "','" + v.get(16) +
		   "','" + v.get(17) + "','" + v.get(18) + "','" + v.get(19) + "','" + v.get(20) + "','" + v.get(21) +
		   "','" + v.get(22) + "','" + v.get(23) + "','" + v.get(24) + "','" + v.get(25) + "','" + v.get(26) +"')";
		System.out.println("DEBUG: DatabaseConnectivity.insertSecurityRequest:\n\t Here's the query: " + query);
		submitQuery(query, 3);

	} // end insertSecurityData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertCateringData       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts data from catering form into the cateringRequests Table
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * JS: Data here especially null gets stored as the string null in the database because of the quotes preceding and succeeding it
	 * JS: Does it matter?
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertCateringData(Vector v) {
		String query = "INSERT INTO cateringRequests (contactFirstName, contactLastName, contactEmail, eventTitle, eventLocation, " +
			"eventMonth, eventDayOfMonth, eventYear, setupComplete, breakdownStart, catering1, catering2, catering3, quantMeals, selection, vegan, quantVegan, vegetarian, " +
			"quantVegetarian, atkins, quantAtkins, kosher, quantKosher, pageLoad, pageSubmit, quote1, quote2, quote3) VALUES " +
			"('" + v.get(0) + "','" + v.get(1) + "','" + v.get(2) + "','" + v.get(3) + "','" +
			v.get(4) + "','" + v.get(5) + "','" + v.get(6) + "','" + v.get(7) + "','" + v.get(8) +
			"','" + v.get(9) + "','" + v.get(10) + "','" + v.get(11) + "','" + v.get(12) + "','" + v.get(13) +
			"','" + v.get(14) + "','" + v.get(15) + "','" + v.get(16) + "','" + v.get(17) + "','" + v.get(18) +
			"','" + v.get(19) + "','" + v.get(20) + "','" + v.get(21) + "','" + v.get(22) + "','" + v.get(23) +
			"','" + v.get(24) + "','" + v.get(25) + "','" + v.get(26) + "','" + v.get(27) +"')";
		System.out.println("DEBUG: DatabaseConnectivity.insertCateringRequest:\n\t Here's the query: " + query);
		submitQuery(query, 3);

	} // end insertCateringData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertFloralData       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts data from catering form into the floralRequests Table
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertFloralData(Vector v) {
		String query = "INSERT INTO floralRequests (contactFirstName, contactLastName, contactEmail, eventTitle, eventLocation, " +
			"eventMonth, eventDayOfMonth, eventYear, setupComplete, breakdownStart, item1, quantItem1, sizeItem1, flowerTypeItem1, item2, quantItem2, sizeItem2, flowerTypeItem2, item3, quantItem3, " +
			"sizeItem3, flowerTypeItem3, item4, quantItem4, sizeItem4, flowerTypeItem4, userComments, pageLoad, pageSubmit, vendorID, quote) VALUES " +
			"('" + v.get(0) + "','" + v.get(1) + "','" + v.get(2) + "','" + v.get(3) + "','" +
			v.get(4) + "','" + v.get(5) + "','" + v.get(6) + "','" + v.get(7) + "','" + v.get(8) +
			"','" + v.get(9) + "','" + v.get(10) + "','" + v.get(11) + "','" + v.get(12) + "','" + v.get(13) +
			"','" + v.get(14) + "','" + v.get(15) + "','" + v.get(16) + "','" + v.get(17) + "','" + v.get(18) +
			"','" + v.get(19) + "','" + v.get(20) + "','" + v.get(21) + "','" + v.get(22) + "','" + v.get(23) +
			"','" + v.get(24) + "','" + v.get(25) + "','" + v.get(26) + "','" + v.get(27) + "','" + v.get(28) +
			"','" + v.get(29) + "','" + v.get(30) + "')";
		System.out.println("DEBUG: DatabaseConnectivity.insertFloralRequest:\n\t Here's the query: " + query);
		submitQuery(query, 3);

	} // end insertFloralData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertNewMeeting       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts a new meeting into the schedule table (used by PlanAMeetingServlet)
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertNewMeeting(String person_id, String date, String time, String length, String status) {
		//Integer person_id = Integer.valueOf(person);
		String query = "INSERT INTO schedule (person_id, date, time, length, status) VALUES " +
		   "('" + person_id + "','" + date + "','" + time + "','" + length + "','" +
		   status + "')";
		System.out.println("DEBUG: DatabaseConnectivity.insertNewMeeting:\n\t Here's the query: " + query);
		submitQuery(query, 3);

	} // end insertNewMeeting()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void updateMeeting       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		updates a moveable meeting in the schedule table (used by PlanAMeetingServlet)
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void updateMeeting(String person_id, String date, String time, String length, String status) {
		String query = "UPDATE schedule SET length = '" + length + "' WHERE (person_id = '" + person_id + "'AND date = '" +
						date +"' AND time = '" + time +"')";
		System.out.println("DEBUG: DatabaseConnectivity.updateMeeting:\n\t Here's the query: " + query);
		submitQuery(query, 3);

	} // end updateMeeting()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertNewMessage       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		inserts a new message into the message table (used by PlanAMeetingServlet)
	 * Input:		Vector <containing form data>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertNewMessage(String sender, String senderEmail, String message, int minutes, int seconds) {
		String query = "INSERT INTO messageInjection (sender, senderEmail, message, minutes, seconds) VALUES " +
		   "('" + parseQuotes(sender) + "','" + senderEmail + "','" + parseQuotes(message) + "','" + minutes + "','" +
		   seconds + "')";
		System.out.println("DEBUG: DatabaseConnectivity.insertNewMssage:\n\t Here's the query: " + query);
		submitQuery(query, 3);

	} // end insertNewMeeting()

	public ResultSet submitRoomQuery()
	{
		// return submitQuery(rb.getString("roomQuery"));
		return submitQuery("SELECT room, building  FROM conferenceRooms");
	}

	public ResultSet submitMonthQuery()
	{
		// return submitQuery(rb.getString("monthQuery"));
		return submitQuery("SELECT monthName FROM month ORDER BY monthNum");
	}
	
	public ResultSet submitRentalMonthQuery()
	{
		// return submitQuery(rb.getString("rentalMonthQuery"));
		return submitQuery("SELECT monthNum, monthName FROM month ORDER BY monthNum");
	}
	
	//Helper function to convert ' to '' before being inserted into database
	private String parseQuotes(String message)
	{
		StringTokenizer strTemp = new StringTokenizer(message, "'");
		String result = "";
		while(strTemp.hasMoreTokens())
		{
			result += strTemp.nextToken();
			if(strTemp.hasMoreTokens())
				result += "''";
		}
		//System.out.println("result : "+result);
		return result;
	}

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end DatabaseConnectivity
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
