package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 					F L O R A L  A C C E P T Q U O T E . J A V A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to gather Floral request data for a specific id and set it
 * 			up in a nice format for reading.  Calls are made to the FloralRequest table
 * 			to retrieve request data.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: May 23, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  - - - - - - - - - - - - - public class FloralAcceptQuote  - - - - - - - - - - - - - -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
public class FloralAcceptQuote {
	public String messageBody = null;
	public String vendorName = null;
	public int vendor = 0;
	public String contactEmail;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public FloralAcceptQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the FloralAcceptQuote.java class.  Initializes the messageBody by calling
	 * 				setupMessageBody.  The class variable messageBody is used by the QuoteAcceptedServlet to
	 * 				construct a confirmation email to the user
	 * Input:		String <requestID - the unique number in the FloralRequest table>
	 * 				String <vendorID - could be floral1, 2, or 3, passed in through the http stream>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public FloralAcceptQuote(String requestID, String vendorID, String baseURL){
		vendor = determineVendor(vendorID);
		DatabaseConnectivity db = new DatabaseConnectivity();
		ResultSet rs = db.submitQuery("SELECT * FROM floralRequests WHERE uniqueID ='" + requestID + "'");
		ResultSet descrip = db.submitQuery("SELECT * FROM floralItemDescription where uniqueID = '" + vendor + "'");
		try {
			boolean crap = rs.next();
			crap = descrip.next();
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		contactEmail = assignContactEmail(rs);
		vendorName = determineVendorName(vendorID);
		messageBody = setupMessageBody(requestID, vendorID, rs, descrip, baseURL);
	} // end constructor

	public String assignContactEmail(ResultSet rs) {
		try {
			return (rs.getString("contactEmail"));
		} catch (SQLException e) {

		}
		return "Error";
	}

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public setupMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method constructs the message body by querying the FloralRequest table and placing
	 * 				the variables in a very long String.  This method is called by the Constructor to initialize
	 * 				the messageBody class variable.  This method calls submitQuery (from DatabaseConnectivity.java),
	 * 				determineQuoteNumber, and assembleMessageBody.
	 * Input:		String <requestID - the unique number in the FloralRequest table>
	 * 				String <vendorID - could be floral1, 2, or 3, passed in through the http stream>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupMessageBody(String requestID, String vendorID, ResultSet rs, ResultSet descrip, String baseURL) {
		String link = baseURL + determineFloralVendor(vendorID, requestID);
		return (assembleMessageBody(rs, descrip, link));
	} // end setupMessageBody

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public assembleMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for pulling data from the ResultSet and formatting it in a clean
	 * 				manner so it's easily readable.
	 * Input:		ResultSet <rs>
	 * 				ResultSet <descrip>
	 * 				String <quoteNumber - identifies which quote to pull, either quote1, 2, or 3>
	 * 				String <link - web address user can click to view this request>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String assembleMessageBody(ResultSet rs, ResultSet descrip, String link) {
		String s = null;
		String quoteId = null;
		int uniqueId = -1;
		String quotedesc = "";
		try {
		    quoteId = rs.getString("quoteid").substring(6); //number tagged to floral
		    uniqueId = rs.getInt("uniqueid");
		    if(quoteId.equals(new Integer(uniqueId).toString()))
		    	quotedesc = "detailed ";
		    else
		    	quotedesc = "modified ";

		    s = "Request for Floral Service.  \n" + 
		    	"Your "+quotedesc+"quote from " + vendorName +
                " can be found below.\n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Order Id:\t" + quoteId + "\n" +
				"Event Title:\t\t" + rs.getString("eventTitle") + "\n" +
				getDate(rs) +
				"Setup Complete Time:\t" + rs.getString("setupComplete") + "\n" +
				"Breakdown Start Time:\t" + rs.getString("breakdownStart") + "\n" +
				"Event Location:\t\t" + rs.getString("eventLocation") + "\n" +
				"Contact First Name:\t" + rs.getString("contactFirstName") + "\n" +
				"Contact Last Name:\t" + rs.getString("contactLastName") + "\n" +
				"Contact Email:\t\t" + rs.getString("contactEmail") + "\n" +
				"---------------------------------------------\n" +
				"Floral Selection(s):\n" +
				"---------------------------------------------\n" +
				getItem1(rs, descrip) +
				getItem2(rs, descrip) +
				getItem3(rs, descrip) +
				getItem4(rs, descrip) +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Quote Total:\t$" + rs.getString("quote") + "\n\n" +
				"Click the link below to review, modify, or cancel your Floral Request:\n\n" +
				link;

		} // end try
		catch(Exception e){
			System.out.println("EXCEPTION: FloralAcceptQuote:assembleMessageBody\n\t An error occurred while assembling message body.\n Here it is: " + e);
		}
		return s;
	} // end printFloralRequestData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineQuoteNumber()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying which quote number in the request table corresponds
	 * 				to the vendorID.
	 * Input:		String <vendorID>
	 * Output:		String <quoteNumber - either quote1, 2, or 3>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineVendorName(String vendorID){
		if (vendorID.equals("floral1")) {
			return "ADAMS HOUSE OF FLOWERS";
		}
		if (vendorID.equals("floral2")) {
			return "CANAL STREET, LTD.";
		}
		if (vendorID.equals("floral3")) {
			return "LILLI FESTIVALE";
		}
		else {
			System.out.println("EXCEPTION: FloralAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return "error";
		}
	} // end determineQuoteNumber

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineQuoteNumber()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying which quote number in the request table corresponds
	 * 				to the vendorID.
	 * Input:		String <vendorID>
	 * Output:		String <quoteNumber - either quote1, 2, or 3>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int determineVendor(String vendorID){
		if (vendorID.equals("floral1")) {
			return 1;
		}
		if (vendorID.equals("floral2")) {
			return 2;
		}
		if (vendorID.equals("floral3")) {
			return 3;
		}
		else {
			System.out.println("EXCEPTION: FloralAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return 0;
		}
	} // end determineQuoteNumber

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineFloralVendor()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying the Floral vendor and returning the appropriate
	 * 				link to quote page.
	 * Input:		String <vendorID> , String <requestID>
	 * Output:		String <link>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineFloralVendor(String vendorID, String requestID){
		if (vendorID.equals("floral1"))
			return ("/myapp/webForms/Floral/AdamsReviewQuote.jsp?uniqueID=" + requestID);
		if (vendorID.equals("floral2"))
			return ("/myapp/webForms/Floral/CanalReviewQuote.jsp?uniqueID=" + requestID);
		if (vendorID.equals("floral3"))
			return ("/myapp/webForms/Floral/LilliReviewQuote.jsp?uniqueID=" + requestID);
		else {
			System.out.println("EXCEPTION: FloralAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return ("/myapp/webForms/Error.htm");
		}
	} // end determineQuoteNumber


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public get*Request() Methods      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		The following methods are used to determine if the user requested a specific item.  If so
	 * 				the method will return a string of the format <ITEM>:\t<QUANTITY>:\t<SIZE>:\<FLOWERTYPE>.  These
	 * 				methods are called by assembleMessageBody.
	 * Input:		ResultSet <rs> ResultSet <descrip>
	 * Output:		String
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String getDate(ResultSet rs) {
		try {
			String date = "Event Date:\t" + rs.getString("eventMonth") + " " + rs.getString("eventDayOfMonth") + ", " +
				rs.getString("eventYear")+ "\n";
				return date;
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: CateringAcceptQuote:getDate - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getItem1(ResultSet rs, ResultSet descrip) {
		try {
			if (rs.getString("item1").equals("Yes")) {
				return (descrip.getString("item1Name") + ":\t\t" + rs.getString("quantItem1") + "\t" + rs.getString("sizeItem1") +
						"\t" + rs.getString("flowerTypeItem1") + "\n");
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: FloralAcceptQuote:getItem1 - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getItem2(ResultSet rs, ResultSet descrip) {
		try {
			if (rs.getString("item2").equals("Yes")) {
				return (descrip.getString("item2Name") + ":\t\t" + rs.getString("quantItem2") + "\t" + rs.getString("sizeItem2") +
						"\t" + rs.getString("flowerTypeItem2") + "\n");
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: FloralAcceptQuote:getItem2 - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getItem3(ResultSet rs, ResultSet descrip) {
		try {
			if (rs.getString("item3").equals("Yes")) {
				return (descrip.getString("item3Name") + ":\t\t" + rs.getString("quantItem3") + "\t" + rs.getString("sizeItem3") +
						"\t" + rs.getString("flowerTypeItem3") + "\n");
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: FloralAcceptQuote:getItem3 - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

	public String getItem4(ResultSet rs, ResultSet descrip) {
		try {
			if (rs.getString("item4").equals("Yes")) {
				return (descrip.getString("item4Name") + ":\t\t" + rs.getString("quantItem4") + "\t" + rs.getString("sizeItem4") +
						"\t" + rs.getString("flowerTypeItem4") + "\n");
			} // end if
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: FloralAcceptQuote:getItem4 - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end FloralAcceptQuote.java
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -