package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 					F  L  O  R  A  L  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to calculate floral quotes for requests made by the
 * 			participants.  This class utilizes JDBC calls to get pricing from a MySQL table.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: May 25, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Vector;

public class FloralQuote {
	Vector request;
	DatabaseConnectivity db;
	String vendorID = null, item1 = null, item2 = null, item3 = null, item4 = null;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public FloralQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the FloralQuote.java class.  Initializes the request vector for use
	 * 				by class methods.  The FloralRequestVector will be passed in.
	 * Input:		Vector
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public FloralQuote(Vector v){
		request = new Vector(v);
		db = new DatabaseConnectivity();
	} // end Constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int[] calculateQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method calls the FloralCostStructure table and gathers necessary data to calculate
	 * 				and return the quote.  Quotes for all Floral service vendors are calculated and placed in an int
	 * 				array.  Currently system is setup for 3 Floral vendors.  Additions/deletions will require changes
	 * 				in the costStructure table as well as calculateQuote method.
	 * Input:		none
	 * Output:		int[] <quotes for all catering providers - caller can use what is needed>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calculateQuote() {
		int quoteTotal = 0, id = 0;
		getFloralRequests();
		if (vendorID.equals("floral1"))
			id = 1;
		if (vendorID.equals("floral2"))
			id = 2;
		if (vendorID.equals("floral3"))
			id = 3;

		ResultSet rs = db.submitQuery("SELECT * FROM floralCostStructure WHERE uniqueID = '" + id + "'");
		try {
			while (rs.next()){
				quoteTotal = 0;
				if (item1.equals("Yes"))
					quoteTotal += calcItem1Cost(rs);
				if (item2.equals("Yes"))
					quoteTotal += calcItem2Cost(rs);
				if (item3.equals("Yes"))
					quoteTotal += calcItem3Cost(rs);
				if (item4.equals("Yes"))
					quoteTotal += calcItem4Cost(rs);
				} // end while
				rs.close();
		} // end try
		catch (SQLException e) {
			System.out.println("EXCEPTION: FloralQuote.calculateQuote: \n\tHere's the error: " + e);
		} // end catch

		return(quoteTotal);
	} // end calculateQuote()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public getFloralRequests()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method checks the request vector to determine what items the user has requested.  The
	 * 				string values are assigned to each particular item and used in CalculateQuote to determine
	 * 				if that items calculateCost method should be called.
	 * Input:		none
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void getFloralRequests(){
		vendorID = (String)request.get(29);
		item1 = (String)request.get(10);
		item2 = (String)request.get(14);
		item3 = (String)request.get(18);
		item4 = (String)request.get(22);

		} // end getFloralRequests()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcItem1Cost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for item1 (differs depending on
	 * 				floral vendor
	 * Input:		ResultSet <rs>
	 * Output:		int <item1Cost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcItem1Cost(ResultSet rs){
		int total = 0, quant = 0, price=0;
		String size;
		// location of item1 data in vector is as follows: quant@11, size@12
		try {
			quant = Integer.valueOf((String) request.get(11)).intValue();
			size = (String)request.get(12);
			price = rs.getInt("item1" + size);
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: FloralQuote.calcItem1Cost:\n\t vegan total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcItem1Cost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcItem2Cost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for item2 (differs depending on
	 * 				floral vendor)
	 * Input:		ResultSet <rs>
	 * Output:		int <item2Cost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcItem2Cost(ResultSet rs){
		int total = 0, quant = 0, price=0;
		String size;
		// location of item2 data in vector is as follows: quant@15, size@16
		try {
			size = (String)request.get(16);
			price = rs.getInt("item2" + size);
			quant = Integer.valueOf((String) request.get(15)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: FloralQuote.calcItem2nCost:\n\t item2 total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcItem2Cost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcItem3Cost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for item3.
	 * Input:		ResultSet <rs>
	 * Output:		int <item3Cost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcItem3Cost(ResultSet rs){
		int total = 0, quant = 0, price=0;
		String size;
		// location of item3 data in vector is as follows: quant@19 size@20
		try {
			size = (String)request.get(20);
			price = rs.getInt("item3" + size);
			quant = Integer.valueOf((String) request.get(19)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: FloralQuote.calcItem3Cost:\n\t item3 total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcItem3Cost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcItem4Cost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the number item4 meals requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <item4Cost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcItem4Cost(ResultSet rs){
		int total = 0, quant = 0, price=0;
		String size;
		// location of item4 data in vector is as follows: quant@23 size@24
		try {
			size = (String)request.get(24);
			price = rs.getInt("item4" + size);
			quant = Integer.valueOf((String) request.get(23)).intValue();
			total = (quant * price);
			} // end try

		catch(SQLException e){
			System.out.println("EXCEPTION: FloralQuote.calcItem4Cost:\n\t Item4 total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcItem4Cost()

//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 									// end FloralQuote.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

