package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 				P  A  R  K  I  N  G  A  C  C  E  P  T  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to gather parking request data for a specific id and set it
 * 			up in a nice format for reading.  Calls are made to the parkingRequest table
 * 			to retrieve request data.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Mar 11, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  - - - - - - - - - - - - - public class TowncarAcceptQuote  - - - - - - - - - - - - - -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
public class ParkingAcceptQuote {
	public String messageBody = null;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public TowncarAcceptQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the ParkingAcceptQuote.java class.  Initializes the messageBody by calling
	 * 				setupMessageBody.  The class variable messageBody is used by the QuoteAcceptedServlet to
	 * 				construct a confirmation email to the user
	 * Input:		String <requestID - the unique number in the parkingRequest table>
	 * 				String <vendorID - could be towncar1, 2, or 3, passed in through the http stream>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public ParkingAcceptQuote(String requestID, String vendorID){
		messageBody = setupMessageBody(requestID, vendorID);
	} // end constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public setupMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method constructs the message body by querying the parkingRequest table and placing
	 * 				the variables in a very long String.  This method is called by the Constructor to initialize
	 * 				the messageBody class variable.  This method calls submitQuery (from DatabaseConnectivity.java),
	 * 				determineQuoteNumber, and assembleMessageBody.
	 * Input:		String <requestID - the unique number in the parkingRequest table>
	 * 				String <vendorID - could be towncar1, 2, or 3, passed in through the http stream>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupMessageBody(String requestID, String vendorID) {
		DatabaseConnectivity db = new DatabaseConnectivity();
		ResultSet rs = db.submitQuery("SELECT * FROM parkingRequests WHERE uniqueID ='" + requestID + "'");
		return (assembleMessageBody(rs, requestID));
	} // end setupMessageBody

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public assembleMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for pulling data from the ResultSet and formatting it in a clean
	 * 				manner so it's easily readable.
	 * Input:		ResultSet <rs>
	 * 				String <quoteNumber - identifies which quote to pull, either quote1, 2, or 3>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String assembleMessageBody(ResultSet rs, String requestID) {
		String s = null;
		try {
			boolean crap = rs.next();
				s = "Your Parking Request Submission is detailed below:  \n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Event Title:\t" + rs.getString("eventTitle") + "\n" +
				"Event Location:\t" + rs.getString("eventLocation") + "\n" +
				"Event Date:\t" + rs.getString("eventDate") + "\n" +
				"Contact First Name:\t" + rs.getString("contactFirstName") + "\n" +
				"Contact Last Name:\t" + rs.getString("contactLastName") + "\n" +
				"Contact Phone:\t" + rs.getString("contactPhone") + "\n" +
				"Contact Email:\t" + rs.getString("contactEmail") + "\n" +
				"Number of Spaces:\t" + rs.getString("numParkingSpaces") + "\n" +
				"Parking Location:\t" + rs.getString("parkingLocation") + "\n" +
			  	"Validation Passes:\t" + rs.getString("validationPasses") + "\n" +
				"Number of validation passes:\t" + rs.getString("numValidationPasses") + "\n" +
				"Traffic Guard:\t" + rs.getString("trafficGuard") + "\n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Quote Total:\t$" + rs.getString("calculatedQuote") + "\n\n" +
				"Click the link below to review, modify, or cancel your Parking Request:\n\n" +
				"http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Parking/ParkingReviewQuote.jsp?uniqueID=" + requestID;
		} // end try
		catch(Exception e){}
		System.out.println("DEBUG: ParkingAcceptQuote:assembleMessageBody\n\t Here's the msg body: " + s);
		return s;
	} // end printTowncarRequestData()


//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end TowncarAcceptQuote.java
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
