package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 				P  A  R  K  I  N  I  N  G  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to calculate parking quotes for requests made by the
 * 			participants.  This class utilizes JDBC calls to get pricing from a MySQL table.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Mar 1, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Vector;

public class ParkingQuote {
	Vector request;
	DatabaseConnectivity db;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public SecurityQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the ParkingQuote.java class.  Initializes the request vector for use
	 * 				by class methods.  The parkingRequestVector will be passed in.
	 * Input:		Vector
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public ParkingQuote(Vector v){
		request = new Vector(v);
		db = new DatabaseConnectivity();
	} // end Constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calculateQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method calls the parkingCostStructure table and gathers necessary data to calculate
	 * 				and return the quote.  numParkingSpaces is @ position 7, validationPasses @ 9,
	 * 				numValidationPasses @ 10, trafficGuard @ 11
	 * Input:		none
	 * Output:		int <quote total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calculateQuote() {
		int numParkingSpaces = Integer.valueOf((String)request.get(7)).intValue();
		String validationPasses  = (String)request.get(9);
			System.out.println("DEBUG: ParkingQuote.calculateQuote: \n Validation Passes = " + validationPasses);
		int numValidationPasses = Integer.valueOf((String)request.get(10)).intValue();
		String trafficGuard = (String)request.get(11);
			System.out.println("DEBUG: ParkingQuote.calculateQuote: \n Traffic Guard = " + trafficGuard);
		int perSpace = 0, perValidation = 0, perTrafficGuard = 0, quote = 0;

		ResultSet rs = db.submitQuery("SELECT perSpace, perValidationPass, pertrafficGuard FROM parkingCostStructure WHERE id = '1'");
		try {
			while (rs.next()){
				perSpace = rs.getInt("perSpace");
				perValidation = rs.getInt("perValidationPass");
				perTrafficGuard = rs.getInt("perTrafficGuard");
				System.out.println("DEBUG: ParkingQuote.calculateQuote:\n Here's the prices: " + perSpace + "\t" + perValidation + "\t" + perTrafficGuard);
			}
		}
			catch (SQLException e) {
				System.out.println("EXCEPTION: ParkingQuote.calculateQuote: \n Here's the error: " + e);
		}
		if (validationPasses.equals("Yes"))
			quote += (numValidationPasses * perValidation);
		if (trafficGuard.equals("Yes"))
			quote += perTrafficGuard;
		System.out.println("DEBUG: ParkingQuote.calculateQuote:\n Here's the final quote: " + quote);
		return(quote);
	} // end calculateQuote()
//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end SecurityQuote.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
