package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  - - - - - - - -
 * 				P  L  A  N  A  M  E  E  T  I  N  G  S  E  R  V  L  E  T . J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:		PlanAMeetingServlet.java is called by CalendarResults.jsp to determine if a meeting
 * 				proposed by the user is possible
 * Functionality:	This java class gathers date, length, Vector people and Vector names from the request
 * 					stream.  This data is used to query the schedule table to gather the schedules for all
 * 					p in Vector people.  The proposed meeting time and length is then analyzed to determine
 * 					if it is open, moveable, or immoveable for p in Vector people.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Feb 4, 2005
  * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
import java.io.*;
import java.util.Calendar;
import java.util.Random;
import java.util.Vector;
import java.sql.*;

import javax.servlet.*;
import javax.servlet.http.*;


public class PlanAMeetingServlet extends HttpServlet {
	String meetingDate = null, meetingLength = null, startTime = null, moveableVisited = null, immoveableVisited = null;
	String organizerName, organizerEmail, firstDayOfWeek, twoTypeConflictVisited = null;
	Vector people, names;
	String[][]text;
	int[] calendarNumbers;
	int baseHour = 8, vendorFlag = 0;
	static sendEmail mail;
	DatabaseConnectivity db;
	static String mailserver = "ux14.sp.cs.cmu.edu";
	HttpSession session;
	String immoveableURL = "/webForms/Shared Calendar/ImmoveableMeeting.jsp";
	String moveableURL = "/webForms/Shared Calendar/MoveableMeeting.jsp";
	String rescheduleURL = "/webForms/Shared Calendar/MoveableConfirm.jsp";
	String passOffURL = "/webForms/Shared Calendar/CalendarSubmission.jsp";
	String moveableSubmissionURL = "/webForms/Shared Calendar/MoveableSubmission.jsp";
	String twoTypeURL = "/webForms/Shared Calendar/TwoTypeConflict.jsp";

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void doGet()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		standard method required for servlet functionality
	 * 				responsible for all servlet processing
	 * Input:		HttpServletRequest, HttpServletResponse
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void doGet(HttpServletRequest request, HttpServletResponse response)	throws ServletException, IOException {
		session = request.getSession(true);
		init(request);
		response.setContentType("text/html");
		//out = response.getWriter();
		processMeetingRequest();
		examineMeetingTime(request, response);
	} // end doGet()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void init()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		initialize some variables for use in processing.
	 * Input:		HttpServletRequest
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void init(HttpServletRequest request) {
		System.out.println("------------------------------------\n PAMServlet Processing Begins Here\n----------------------");
		mail = new sendEmail();
		db = new DatabaseConnectivity();
		// check for immoveableVisited flag - if yes then will need to get all of these from the session, not request
		immoveableVisited = request.getParameter("immoveableVisited");
		moveableVisited = request.getParameter("moveableVisited");
		twoTypeConflictVisited = request.getParameter("twoTypeConflictVisited");
		System.out.println("DEBUG: init() - here's the flags:\n immov: " + immoveableVisited + "\nmov: " + moveableVisited);
		if ((immoveableVisited.equals("flagged"))||(moveableVisited.equals("flagged"))||(twoTypeConflictVisited.equals("flagged")))
	    	flaggedInit();
		else
			notFlaggedInit(request);

		// initialize the text[][] arrray
		text = new String[people.size()+1][21];
		calendarNumbers = new int[people.size()];
		for (int s=0; s<people.size()+1; s++) {
			for (int t=0; t<21; t++) {
				text[s][t] = "open";
			} // end for t
		} // end for s
		for (int i=0; i<calendarNumbers.length; i++) {
			int temp = Integer.valueOf((String) people.get(i)).intValue();
			calendarNumbers[i] = temp;
			System.out.println("DEBUG: PAMServlet: just put " + temp + "into the calendarNum array");
		}
	} // end init()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void notFlaggedInit()      )																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is called when the immoveableVisited or moveableVisisted flags == "notflagged"
	 * 				This means that the user has not already visited ImmovableMeeting.jsp or MoveableMeeting.jsp
	 * 				(jsp displayed when the PAMServlet determines there is either a moveable or immoveable conflict
	 * 				in the proposed meeting). This method initializes necessary variables with the HttpServletRequest
	 * 				stream, not the Session
	 * Input:		HttpServletRequest
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void notFlaggedInit(HttpServletRequest request) {
		System.out.println("DEBUG: in notFlaggedInit()");
		meetingDate = request.getParameter("date");
		meetingLength = request.getParameter("length");
		startTime = request.getParameter("startTime");
		organizerName = request.getParameter("organizerName");
		organizerEmail = request.getParameter("organizerEmail");
		people = (Vector)session.getAttribute("people");
		names = (Vector)session.getAttribute("names");
		firstDayOfWeek = request.getParameter("firstDayOfWeek");
		System.out.println("DEBUG: in notFlaggedInit() - startTime = " + startTime);
	} // end notFlaggedInit()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void flaggedInit()											   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is called when the immoveableVisited or moveableVisisted flags == "flagged"
	 * 				This means that the user has already visited ImmovableMeeting.jsp or MoveableMeeting.jsp
	 * 				(jsp displayed when the PAMServlet determines there is a moveable or immoveable conflict
	 * 				in the proposed meeting).  This method initializes necessary variables with the Session
	 * 				variable instead of the HttpServletRequest stream
	 * Input:		none
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void flaggedInit() {
		System.out.println("DEBUG: in flaggedInit()");
		meetingDate = (String)session.getAttribute("date");
		meetingLength = (String)session.getAttribute("length");
		startTime = (String)session.getAttribute("startTime");
		organizerName = (String)session.getAttribute("organizerName");
		organizerEmail = (String)session.getAttribute("organizerEmail");
		people = (Vector)session.getAttribute("people");
		names = (Vector)session.getAttribute("names");
		System.out.println("DEBUG: in flaggedInit() - startTime = " + startTime);
	}// end flaggedInit()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processMeetingRequest()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for overall meeting processing
	 * Input:		HttpServletRequest
	 * Output:		none
	 * Calls:		Uses db object to setup and query the mysql db
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void processMeetingRequest() {
		ResultSet rs = null;
		Statement st = null;
		String query = null;
		for (int p=0; p<calendarNumbers.length; p++) {
	   		if (calendarNumbers[p] > 2) {vendorFlag =1;} // all numbers of admin cals should be known
			query = db.setupQuery(calendarNumbers[p], meetingDate);
	   		rs = db.submitQuery(query);
    		try {
    			while (rs.next()) {
    				Time t = rs.getTime("time");
					int length = rs.getInt("length");
					String status = rs.getString("status");
					Calendar cal = Calendar.getInstance();
					cal.setTimeInMillis(t.getTime());
					int startHour = cal.get(Calendar.HOUR_OF_DAY);
					int startMinutes = cal.get(Calendar.MINUTE);
					int startPosition = (startHour - baseHour)*2;
					if (startMinutes == 30) {startPosition++;}
					int endPosition = startPosition;
					for (int m=30; m<length; m+=30) {endPosition++;}

					for (int i=startPosition+1; i<=endPosition+1; i++) {
						int bump = p+1;
						text[bump][i] = status;
					} // end for
    			} // end while
    		}// end try
    		catch (SQLException e){
    			System.err.println("SQL EXCEPTION:PlanAMeetingServlet.java - " + e);
    		} // end catch
	  	} // end for
	} // end processMeetingRequest()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int examineMeetingTime()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method examines the proposed meeting date, time, and length for possible conflicts.
	 * 				Different methods are called to complete processing, depending on the outcome of analysis.
	 * 				This is based upon values in the text[][] array - "open", "moveable" or "immoveable"
	 * Input:		none
	 * Output:		returns an integer flag [0] - meeting ok [1] meeting not ok
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void examineMeetingTime(HttpServletRequest request, HttpServletResponse response) {
		System.out.println("DEBUG: examineMeetingTime - here's the start time: " + startTime);
		String[] splitTimes = startTime.split(":");
		String hour = splitTimes[0];
		String minutes = splitTimes[1];
		String mtgStatus = "open";
		String sender = "Shared Calendar Manager";
		String senderEmail = "Calendar_Manager@cmu.edu";
		String errorMessage = "The following have a conflict for the meeting time and length you've requested:\n";
		Random rng = new Random();
		int openFlag = 0, moveableFlag = 0, immoveableFlag = 0;
		int length = Integer.valueOf(meetingLength).intValue();
		int startHour = Integer.valueOf(hour).intValue();
		int startMinutes = Integer.valueOf(minutes).intValue();
			System.out.println("DEBUG: PlanAMeetingServlet:examineMeetingTime - The integer values are: Hour: " + startHour + "\nMinutes: " + startMinutes + "\nLength: " + length);

		// for each calendar, view these timeslots and determine the status for each person
		int startPosition = (startHour - baseHour)*2;
		if (minutes.equals("30"))
			startPosition++;
		int endPosition = startPosition;
		for (int m=30; m<length; m+=30) {endPosition++;}

		Vector noScheduleConflict = new Vector();
		Vector immoveableConflict = new Vector();
		Vector moveableConflict = new Vector();
		Integer temp = new Integer(0);
		for (int p=1; p<=people.size(); p++) {
			int spot = (p-1);
			for (int i=startPosition+1; i<=endPosition+1; i++) {
				mtgStatus = text[p][i];
				// This code checks to determine the status of each meeting slot for each person.  Vectors are used to
				// keep track of who is moveable, immoveable or open.  We only want the person's calendar number entered into
				// a respective vector once, so perform vector.contains() before adding the cal num
				if (mtgStatus.equals("moveable")){
					moveableFlag = 1;
					if (!moveableConflict.contains(people.get(spot)))
						moveableConflict.add(people.get(spot));
					System.out.println("DEBUG: PAMServlet:examineMeetingTime - moveableFlag set\n Added "+ people.get(spot) + " to the moveableVector");
				}
				if (mtgStatus.equals("immoveable")){
					immoveableFlag = 1;
					if (!immoveableConflict.contains(people.get(spot)))
						immoveableConflict.add(people.get(spot));
					System.out.println("DEBUG: PAMServlet:examineMeetingTime - immoveableFlag set\n Added "+ people.get(spot) + " to the immoveableVector");
				}
				if (mtgStatus.equals("open")) {
					if ((!moveableConflict.contains(people.get(spot)))&&(!immoveableConflict.contains(people.get(spot)))) {
						if (!noScheduleConflict.contains(people.get(spot)))
							noScheduleConflict.add(people.get(spot));
					}
					System.out.println("DEBUG: PAMServlet:examineMeetingTime - Meeting status was OPEN\n Added "+ people.get(spot) + " to the openVector");
				}
			} // end for i
		} // end for p

		// Determine course of action....
		if ((moveableFlag == 1)&&(immoveableFlag == 1)){
			resultTwoTypeConflict(sender, senderEmail, rng, request, response, noScheduleConflict, moveableConflict, immoveableConflict);
		}
		else if (immoveableFlag == 1) {
			resultImmoveable(sender, senderEmail, rng, request, response, noScheduleConflict, immoveableConflict);
		}
		else if (moveableFlag == 1) {
			resultMoveable(sender, senderEmail, rng, request, response, noScheduleConflict, moveableConflict);
		}
		else { // all invitees were open for proposed meeting
			resultOpen(sender, senderEmail, rng, request, response, noScheduleConflict);
		}
	} // end examineMeetingTime()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void sendEmailConfirmation()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to send an email confirmation message to the meeting organizer.
	 * 				The message will indicate that the proposed meeting has been processed and organizer should hear
	 * 				from invited partied shortly.
	 * Input:		String <sender> String <senderEmail>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void sendEmailConfirmation(String sender, String senderEmail) {
		System.out.println("DEBUG: in sendEmailConfirmation()");
		String subject = "Proposed Meeting on " + meetingDate;
		String message = organizerName + ",\nYour request for the following proposed meeting has been processed. " +
						"\n\tDate: " + meetingDate + "\n\tTime: " + startTime + "\n\tLength: " + meetingLength +
						"\nYou should hear from each of the invited parties shortly.\n\n--Shared Calendar Manager";
		//mail.sendMail(mailserver, sender, senderEmail, organizerEmail, subject, message);
	} // end sendEmailConfirmation()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertNewMeeting()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to update the schedule tables for individuals determined to be open or
	 * 				moveable for the proposed meeting.  This method is called by the result<> processing methods.
	 * Input:		Vector <v>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertNewMeeting(Vector v){
		System.out.println("DEBUG: in insertNewMeeting()");
		String status = "moveable";
		if (v.size()>0){
			for (int i=0; i<v.size(); i++){
				db.insertNewMeeting((String)v.get(i), meetingDate, startTime, meetingLength, status);
			} // end for
		} // end if
	} // end insertNewMeeting()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void updateMeeting()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to update the schedule tables for individuals with a moveable meeting.
	 * 				Instead of inserting the new meeting, the length of the moveable meeting is adjusted.
	 * Input:		Vector <v>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void updateMeeting(Vector v) {
		System.out.println("DEBUG: in insertNewMeeting()");
		String status = "moveable";
		if (v.size()>0){
			for (int i=0; i<v.size(); i++){
				db.updateMeeting((String)v.get(i), meetingDate, startTime, meetingLength, status);
			} // end for
		} // end if

	}

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void insertNewEmailMessage()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to insert new email messages from individuals to the meeting organizer.
	 * 				New messages are placed in the messageInjection table which is used by THT to deliver messages.
	 *				RADAR person table is queried to get individual names and responsivity - this is added on to
	 *				the random number of minutes generated for message delivery.  This method is called by the
	 *				result<> methods.
	 * Input:		Vector <v>, Random rng
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void insertNewEmailMessage(Random rng, Vector v) {
		System.out.println("DEBUG: in insertNeEmailMessage()");
		// this may need to have a case statement depending on how messages are used
		int minutes = 0, seconds = 0, tempMinutes = 0;
		int[]sessionTime;
		sessionTime = getSessionTime();
		minutes = sessionTime[0];
		seconds = sessionTime[1];
		tempMinutes = minutes;
		for (int i=0; i<v.size(); i++){
			// we don't want to insert a message from the organizer to him/herself, so check to see if calNum = 1
			if (Integer.valueOf((String)v.get(i)).intValue()!= 1){
				minutes = tempMinutes;
				// this offset will need adjustment based on the responsivity of character
				int offset = (rng.nextInt(15));
				// these will be messages from each person in the people vector (or noScheduleConflict vector in other cases)
				// there will need to be a db lookup here to get the characters attributes - email, name, responsivity, etc.
				// Assume that subject line is already set?
				String[] data = getUserInfo((String)v.get(i));
				minutes += (offset + Integer.valueOf(data[3]).intValue());
				db.insertNewMessage((data[0]+" "+data[1]), data[2], "test message", minutes, seconds);
			} // end if
		} // end for
	} // end insertNewEmailMessage

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processOpenInvitees()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to process meeting requests for those invitees with an open time slot.
	 * 				Accept messages from the open invitees are inserted into the db for future delivery to the organizer.
	 * 				Schedules for the open invitees are updated with the new meeting.
	 * Input:		 Random <rng> HttpServletRequest <request> HttpServletResponse <response> Vector <v>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void processOpenInvitees	(Random rng, Vector v, int flag) {
		System.out.println("DEBUG: in processOpenInvitees()");
		switch (flag) {
			case 1:
			{	insertNewMeeting(v);
				insertNewEmailMessage(rng, v);
				break;
			}
			case 2:
			{	updateMeeting(v);
				insertNewEmailMessage(rng, v);
			}
		} // end switch
	}// end processOpenInvitees()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void resultOpen()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is called to complete processing when the proposed meeting time has been identified
	 * 				as open for all parties invited.  processOpenInvitees is called - is passed in the people vector.
	 * 				passOff is called to display the final jsp.
	 * Input:		String <sender> String <senderEmail> Random <rng> HttpServletRequest <request>
	 * 				HttpServletResponse <response> Vector <v>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void resultOpen(String sender, String senderEmail, Random rng, HttpServletRequest request,
				HttpServletResponse response, Vector v) {
		System.out.println("DEBUG: in resultOpen()");
		sendEmailConfirmation(sender, senderEmail);
		processOpenInvitees(rng, v, 1);
		passOff(request, response, passOffURL);
	} // end resultOpen

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void resultMoveable()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is called to copmlete processing when the proposed meeting time has been identified
	 * 				to contain at least one moveable appointment for one or more member of the administrator group.
	 * 				processOpenInvitees is sent the noConflict vector.  When control returns to resultMoveable the
	 * 				current session time is gathered and a message from one of teh admins is created.  Processing is
	 * 				completed by calling passOff().
	 * Input:		String <sender> String <senderEmail> Random <rng> HttpServletRequest <request>
	 * 				HttpServletResponse <response> Vector <v>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void resultMoveable(String sender, String senderEmail, Random rng, HttpServletRequest request,
							HttpServletResponse response, Vector noConflict, Vector moveableConflict) {
		if (moveableVisited.equals("notflagged")) {
			passOff(request, response, moveableURL);
		}
		else {
			System.out.println("DEBUG: PAMServlet:resultMoveable - in resultMoveable method");
			sendEmailConfirmation(sender, senderEmail);
			processOpenInvitees(rng, noConflict, 1);
			processOpenInvitees(rng, moveableConflict, 2);
			//String subject = "Meeting bumped to accomodate new meeting";
			passOff(request, response, rescheduleURL);
		} // end else
	}// end resultMoveable()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void resultImmoveable()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to complete processing when the proposed meeting time has been identified
	 * 				to contain at least one immoveable appointment.  The immoveableVisited flag
	 * 				is checked to determine if the user has already visited the ImmoveableMeeting.jsp page - which alerts the
	 * 				user to an immoveable conflict with the proposed meeting.  If the flag == notflagged then the request
	 * 				is forwared to ImmoveableMeeting.jsp.  If flag == flagged then the processing is completed - a receipt message
	 * 				is sent to the organizer and schedules are updated accordingly.
	 * Input:		int <immoveableFlag> HttpServletRequest <request> HttpServletResponse <response>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void resultImmoveable(String sender, String senderEmail, Random rng,	HttpServletRequest request,
			HttpServletResponse response, Vector noConflict, Vector immoveableConflict) {
		if (immoveableVisited.equals("notflagged")) {
			passOff(request, response, immoveableURL);
		}
		else {
			sendEmailConfirmation(sender, senderEmail);
			if (people.size()>2)
				processOpenInvitees(rng, noConflict, 1);
			insertNewEmailMessage(rng, immoveableConflict);
			passOff(request,response, passOffURL);
		}// end else
	}// end resultImmoveable()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void resultTwoTypeConflict()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to complete processing when the proposed meeting time has been identified
	 * 				to contain at least one immoveable meeting AND at least on moveable appointment. TwoTypeConflictVisited flag
	 * 				is checked to determine if the user has already visited the TwoTypeConflict.jsp page - which alerts the
	 * 				user to the conflicts with the proposed meeting.  If the flag == notflagged then the request
	 * 				is forwared to TwoTypeConflict.jsp.  If flag == flagged then the processing is completed - a receipt message
	 * 				is sent to the organizer and schedules are updated accordingly.
	 * Input:		HttpServletRequest <request> HttpServletResponse <response> String <sender> String <senderEmail>
	 * 				Random <rng>, Vector <noConflict> Vector <immoveableConflict> Vector <moveableConflict>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void resultTwoTypeConflict(String sender, String senderEmail, Random rng, HttpServletRequest request,
			HttpServletResponse response, Vector noConflict, Vector moveableConflict, Vector immoveableConflict) {
		System.out.println("DEBUG: In resultTwoTypeConflict()");
		if (twoTypeConflictVisited.equals("notflagged")) {
			passOff(request, response, twoTypeURL);
		}
		else {
			processOpenInvitees(rng, noConflict, 1);
			processOpenInvitees(rng, moveableConflict, 2);
			insertNewEmailMessage(rng, immoveableConflict);
			passOff(request, response, moveableSubmissionURL);
		}
	}// end resultImmoveable()


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String createAdminMsgBody()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is called by resultMoveable() to setup the body of the msg to be sent from
	 * 				one of the admins to the meeting organizer.
	 * Input:		Vector <v> - adminVector
	 * Output:		String
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String createAdminMsgBody(Vector v){
		String m = "I have a conflicting meeting with Assistant " + v.get(0) + ".  We would gladly reschedule our meeting.  " +
					"When would you like us to meet?  You can click on the link below to see our schedules for the week:\n\n\n";
		String link = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Shared Calendar/CalendarResults.jsp?date=" + firstDayOfWeek;
		for (int i=0; i<v.size(); i++){
			String cal = "&calendar" + v.get(i) + "=" + v.get(i);
			link += cal;
		} // end for
		m += link;
		return m;
	}// end sendEmailMessage

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int[] getSessionTime()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method returns the current session time (provided by TestHarnessTimer).  Session time
	 * 				is gathered by querying the sessionTime table.
	 * Input:		none
	 * Output:		int
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int[] getSessionTime() {
		int minutes = 0, seconds = 0;
		String query = "SELECT * FROM sessionTime";
		ResultSet rs =  db.submitQuery(query);
		try {
			while (rs.next()){
				minutes = rs.getInt(1); // id is at rs(0)
				seconds = rs.getInt(2);
				System.out.println("DEBUG: PAMServlet-resultOpen: minutes: " + minutes +"\nseconds: " + seconds);
			}
		}
			catch (SQLException e) {
				System.out.println("EXECPTION: PAMServlet:resultOpen: " + e);
			}
		int[] sessionTime = new int[2];
		sessionTime[0]=minutes;
		sessionTime[1]=seconds;
		return sessionTime;
	} // end getSessionTime()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void passOff()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method forwards the HttpServlet request to CalendarSubmission.jsp.  This is the final
	 * 				page viewed by the organizer.
	 * Input:		HttpServletRequest <request> HttpServletResponse <response>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void passOff(HttpServletRequest request, HttpServletResponse response, String URL){
		try {
			RequestDispatcher dispatcher = getServletContext().getRequestDispatcher(URL);
			dispatcher.forward(request, response);
			}
		catch (Exception e) {
			System.out.println("EXCEPTION: PAMServlet - " + e);
		}

	}// end passOff()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void getUserInfo()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method querys the radarPerson table to gather first, last, email, and responsivity.
	 * Input:		int <calenderNumber>
	 * Output:		String[] <data>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String[] getUserInfo(String calendarNumber) {
		String query = "SELECT first, last, email, responsivity FROM radarPerson WHERE id='"+calendarNumber+"'";
		ResultSet rs = db.submitQuery(query);
		String[] data = new String[4];
		try {
			while(rs.next()){
				data[0]=rs.getString("first");
				data[1]=rs.getString("last");
				data[2]=rs.getString("email");
				data[3]=rs.getString("responsivity");
				System.out.println("DEBUG: PAMServlet:getUserInfo - "+ data[0]+","+data[1]+","+data[2]+","+data[3]);
			} // end while
		} // end try
		catch(SQLException e){System.out.println("EXCEPTION: PAMServlet: getUseInfo - " + e);}
		return data;
	}// end getUserInfo()
//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end PlanAMeetingServlet.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
