package edu.cmu.radar.vendor;
/*************************************************************************************************************
 *				 	Q  U  O  T  E  A  C  C  E  P  T  E  D  S  E  R  V  L  E  T  .  J  A  V  A
 *************************************************************************************************************
 * Purpose: 	This servlet processes incoming acceptance requests for quotes provided to participants from
 * 				fictious vendors.  Servlet is repsonsible for creating/formating an email with the detailed
 * 				quote in the message body, inserting that message into a messageInjection table for later
 * 				delivery and inserting an event into the log table.
 * Input:	HttpServletRequest, HttpServletResponse
 * Output:	none
 * Dependencies:	none
 * Author: 		Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created:		March 11, 2005
 ************************************************************************************************************/

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Properties;
import java.util.Random;
import java.util.ResourceBundle;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;

/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  - - - - - - - - - - - - public class QuoteAcceptedServlet  - - - - - - - - - - - - - -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
public class QuoteAcceptedServlet extends HttpServlet {
	private static Properties props = null;
    private static Logger logger = Logger.getLogger(QuoteAcceptedServlet.class);
    
	DatabaseConnectivity db;
	Random rng = new Random();
//	 for debugging
	String contactEmail;
	sendEmail pushEmail;
	String uniqueID = new String();
	String vendorID = new String();
	String mailServer = "vio.isri.cmu.edu";
	String query = new String();
	StringBuffer baseURL;
	String bURL;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void doGet()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		standard method required for servlet functionality
	 * 				responsible for all servlet processing
	 * Input:		HttpServletRequest, HttpServletResponse
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException{
		System.out.println("-----------------\nQuoteAcceptedServlet Processing Started\n-----------------");
		pushEmail = new sendEmail();
		db = new DatabaseConnectivity();
		baseURL = request.getRequestURL();
		String[] URLSplit = baseURL.toString().split("/myapp/");
		bURL = URLSplit[0];
		vendorID = request.getParameter("vendorID");
		uniqueID = request.getParameter("uniqueID");
		processRequest(vendorID, uniqueID, request, response);
	} // end doGet()


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processRequest()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is called to determine what type of request has been made and which course of
	 * 				action should be taken to complete processing.  This is determined by looking at vendorID.
	 * Input:		String <vendorID - the type of and number for that vendor, ex. towncar1, floral1, etc.>
	 * 				String <uniqueID - the unique identifier for that particular request>
	 * 				HttpServletRequest <request>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void processRequest(String vendorID, String uniqueID, HttpServletRequest request, HttpServletResponse response) {
		String[] data = getIMAPData();

		//if (vendorID.startsWith("towncar")){towncarProcessing(vendorID, data, uniqueID, request, response);}
		//if (vendorID.startsWith("parking")){parkingProcessing(vendorID, data, uniqueID, request, response);}
		if (vendorID.startsWith("security")){securityProcessing(vendorID, data, uniqueID, request, response);}
		if (vendorID.startsWith("rental")){rentalProcessing(vendorID, data, uniqueID, request, response);}
		if (vendorID.startsWith("AV")) {AVProcessing(vendorID, data, uniqueID, request, response);}
		if (vendorID.startsWith("catering")) {cateringProcessing(vendorID, data, uniqueID, request, response);}
		if (vendorID.startsWith("floral")) {floralProcessing(vendorID, data, uniqueID, request, response);}
	} // end processRequest()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String[] getIMAPData()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to gather a user's name, pass, and imapHost from vendorDB.properties
	 * 				which is used by sendEmail().
	 * Input:		none
	 * Output:		String[] 0 - userName, 1 - userPass, 2 - imapHost
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String[] getIMAPData(){
		ResourceBundle rb = null;
		try {
			rb = ResourceBundle.getBundle("properties/vendorDB");
		} catch(Exception e) {} // getBundle throws an exception if the properties file doesnt exist
		String[] data = new String[3];
	      data[0] = getValueForKey(rb, "", "radar.vendor.imap.user");
	      data[1] = getValueForKey(rb, "", "radar.vendor.imap.password");
	      data[2] = getValueForKey(rb, "", "radar.vendor.imap.host");
	      return data;
	}

    // Helper function to search for key in System properties or vendorDB.properties
    // Same function present in DatabaseConnectivity.java. 
    // Parameter list is slightly different.
    public String getValueForKey(ResourceBundle rb, String defaultValue, String key) {
    	String result = null;
    	if (props == null) {
    		props = new Properties(System.getProperties());
    		addProps(props, "radar.properties");
    		addProps(props, "user.properties");
    	}
    	
    	result = props.getProperty(key);
    	if (result == null)
    	{
    		try {
    			result = rb.getString(key);
    		}
    		catch(Exception e) {
    			//To catch MissingResourceException primarily
    			result = null;
    		}
    	}
    	if(result == null)
    		return defaultValue;
    	else
    		return result;
    }

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int[] getSessionTime()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method returns the current session time (provided by TestHarnessTimer).  Session time
	 * 				is gathered by querying the sessionTime table.
	 * Input:		none
	 * Output:		int
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int[] getSessionTime() {
		int minutes = 0, seconds = 0;
		String query = "SELECT * FROM sessionTime";
		ResultSet rs =  db.submitQuery(query);
		try {
			while (rs.next()){
				minutes = rs.getInt(1); // id is at rs(0)
				seconds = rs.getInt(2);
			}
		}
			catch (SQLException e) {
				System.out.println("EXECPTION: PAMServlet:resultOpen: " + e);
			}
		int[] sessionTime = new int[2];
		sessionTime[0]=minutes;
		sessionTime[1]=seconds;
		return sessionTime;
	} // end getSessionTime()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String checkQuoteAcceptance()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to determine the value to be inserted into the quoteAccepted field for
	 * 				a given request table.  If a vendor for the particular request has already been accepted this
	 * 				method pulls that value, creates a new String with the previous and new value and sends it
	 * 				to the caller for insertion into the DB.
	 * Input:
	 * Output:		String <quoteAcceptedValue>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String checkQuoteAcceptance(String requestTable) {
		String query = "SELECT quoteAccepted FROM " + requestTable + " WHERE uniqueID = '" + uniqueID + "'";
		String value = db.submitQASQuery(query);
		if (value == null || (value.equals(""))||(value.equals(null))){
			return vendorID;

		}
		else {
			return (value + ", " + vendorID);

		}
	} // end checkQuoteAcceptance

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void towncarProcessing()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for completing the dirty details of the towncar request acceptance.
	 * 				This includes getting the messageBody from TowcarAcceptQuote.java, forming up the email msg,
	 * 				inserting the message into messageInjection table, and inserting the event into the log table.
	 * Input:		String <vendorID>, String <uniqueID>, HttpServletRequest <request>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/*	public void towncarProcessing(String vendorID, String[] data, String uniqueID, HttpServletRequest request, HttpServletResponse response){
		String subject = "Towncar Quote Accepted", URL ="null";
		int[]sessionTime = getSessionTime();
		int minutes = sessionTime[0];

		// setup and insert the email message with detailed quote
		TowncarAcceptQuote taq = new TowncarAcceptQuote(uniqueID, vendorID);
		Vector vendorVector = db.submitQuery(db.setupQuery(vendorID), 1);	// get the results of the query for use
		String messageBody = taq.messageBody;
		int offset = (rng.nextInt(15));
		minutes += (offset + Integer.valueOf((String)vendorVector.get(3)).intValue());
		db.insertNewMessage((String)vendorVector.get(0), (String)vendorVector.get(1), messageBody, minutes, sessionTime[1]);
		pushEmail.sendMail(mailServer, (String)vendorVector.get(0), (String)vendorVector.get(1), contactEmail,
						subject, messageBody);

		// insert the event into log table
		db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"),
				request.getParameter("pageSubmit"), request.getParameter("quoteID")));
		if (vendorID.equals("towncar1"))
			URL = "/webForms/Towncar/A1LimoComplete.jsp";
		if (vendorID.equals("towncar2"))
			URL = "/webForms/Towncar/ApexComplete.jsp";
		if (vendorID.equals("towncar3"))
			URL = "/webForms/Towncar/PremierComplete.jsp";
		passOff(request, response, URL);
	} // end towncarProcessing()

*/
	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void parkingProcessing()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for completing the dirty details of the parking request acceptance.
	 * 				This includes getting the messageBody from ParkingAcceptQuote.java, forming up the email msg,
	 * 				inserting the message into messageInjection table, and inserting the event into the log table.
	 * Input:		String <vendorID>, String <uniqueID>, HttpServletRequest <request>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/*	public void parkingProcessing(String vendorID, String[] data, String uniqueID, HttpServletRequest request, HttpServletResponse response){
		String subject = "Parking Quote Accepted", URL ="null";
		int[]sessionTime = getSessionTime();
		int minutes = sessionTime[0];

		// setup and insert the email message with detailed quote
		ParkingAcceptQuote taq = new ParkingAcceptQuote(uniqueID, vendorID);
		Vector vendorVector = db.submitQuery(db.setupQuery(vendorID), 1);	// get the results of the query for use
		String messageBody = (String)vendorVector.get(2) + "\n\n" + taq.messageBody;
		int offset = (rng.nextInt(15));
		minutes += (offset + Integer.valueOf((String)vendorVector.get(3)).intValue());
		db.insertNewMessage((String)vendorVector.get(0), (String)vendorVector.get(1), messageBody, minutes, sessionTime[1]);
		pushEmail.sendMail(mailServer, (String)vendorVector.get(0), (String)vendorVector.get(1), contactEmail,
						subject, messageBody);

		// insert the event into log table
		db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"),
				request.getParameter("pageSubmit"), request.getParameter("quoteID")));
		URL = "/webForms/Parking/ParkingComplete.jsp";
		passOff(request, response, URL);
	} // end towncarProcessing()
*/
	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void securityProcessing()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for completing the dirty details of the Security request acceptance.
	 * 				This includes getting the messageBody from SecurityAcceptQuote.java, forming up the email msg,
	 * 				inserting the message into messageInjection table, and inserting the event into the log table.
	 * Input:		String <vendorID>, String <uniqueID>, HttpServletRequest <request>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void securityProcessing(String vendorID, String[]data, String uniqueID, HttpServletRequest request, HttpServletResponse response){
		String subject = "Security Quote Accepted", URL ="null";
		int[]sessionTime = getSessionTime();
		int minutes = sessionTime[0];

		// setup and insert the email message with detailed quote
		SecurityAcceptQuote saq = new SecurityAcceptQuote(uniqueID, vendorID, bURL);
		Vector vendorVector = db.submitQuery(db.setupQuery(vendorID), 1);	// get the results of the query for use
		String from = (String)vendorVector.get(0) + "<" + (String)vendorVector.get(1) + ">";
		String messageBody = (String)vendorVector.get(2) + "\n\n" + saq.messageBody;
		String contactEmail = saq.contactEmail;
		int offset = (rng.nextInt(15));
		minutes += (offset + Integer.valueOf((String)vendorVector.get(3)).intValue());

		// set the quoteAccepted field in securityRequest table to "Yes" for the specific uniqueID
		query = "UPDATE securityRequests SET quoteAccepted = 'Yes' where uniqueID = '" + uniqueID + "'";
		db.submitQuery(query, 3);
		db.insertNewMessage((String)vendorVector.get(0), (String)vendorVector.get(1), messageBody, minutes, sessionTime[1]);
		pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
		//pushEmail.sendMail(mailServer, (String)vendorVector.get(0), (String)vendorVector.get(1), contactEmail,
		//				subject, messageBody);

		// insert the event into log table
		db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"),
				request.getParameter("pageSubmit"), request.getParameter("quoteID")));
		URL = "/webForms/Security/SecurityComplete.jsp";
		passOff(request, response, URL);
	} // end towncarProcessing()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void rentalProcessing()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for completing the dirty details of the rental request acceptance.
	 * 				This includes getting the messageBody from RentalAcceptQuote.java, forming up the email msg,
	 * 				inserting the message into messageInjection table, and inserting the event into the log table.
	 * Input:		String <vendorID>, String <uniqueID>, HttpServletRequest <request>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void rentalProcessing(String vendorID, String[] data, String uniqueID, HttpServletRequest request, HttpServletResponse response){
		String subject = "Rental Quote Accepted", URL ="null";
		int[]sessionTime = getSessionTime();
		int minutes = sessionTime[0];

		// setup and insert the email message with detailed quote
		RentalAcceptQuote raq = new RentalAcceptQuote(uniqueID, vendorID, bURL);
		Vector vendorVector = db.submitQuery(db.setupQuery(vendorID), 1);	// get the results of the query for use
		String from = (String)vendorVector.get(0) + "<" + (String)vendorVector.get(1) + ">";
		String messageBody = raq.messageBody;
		String contactEmail = raq.contactEmail;
        // set the quoteAccepted field in securityRequest table to vendorID for the specific uniqueID
		query = "UPDATE rentalRequests SET quoteAccepted = '" + checkQuoteAcceptance("rentalRequests") + "' where uniqueID = '" + uniqueID + "'";
		db.submitQuery(query, 3);
		int offset = (rng.nextInt(15));
		minutes += (offset + Integer.valueOf((String)vendorVector.get(3)).intValue());
		db.insertNewMessage((String)vendorVector.get(0), (String)vendorVector.get(1), messageBody, minutes, sessionTime[1]);
		pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
		//pushEmail.sendMail(mailServer, (String)vendorVector.get(0), (String)vendorVector.get(1), contactEmail,
		//				subject, messageBody);

		// insert the event into log table
		db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"),
				request.getParameter("pageSubmit"), request.getParameter("quoteID")));
		if (vendorID.equals("rental1"))
			URL = "/webForms/Rental/SpeedyComplete.jsp";
		if (vendorID.equals("rental2"))
			URL = "/webForms/Rental/RentFromUsComplete.jsp";
		if (vendorID.equals("rental3"))
			URL = "/webForms/Rental/ClassicComplete.jsp";
		passOff(request, response, URL);
	} // end rentalProcessing()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void AVProcessing()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for completing the dirty details of the AV request acceptance.
	 * 				This includes getting the messageBody from AVAcceptQuote.java, forming up the email msg,
	 * 				inserting the message into messageInjection table, and inserting the event into the log table.
	 * Input:		String <vendorID>, String <uniqueID>, HttpServletRequest <request>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void AVProcessing(String vendorID, String[] data, String uniqueID, HttpServletRequest request, HttpServletResponse response){
		String subject = "Audio Visual Quote Accepted", URL ="null";
		int[]sessionTime = getSessionTime();
		int minutes = sessionTime[0];

		// setup and insert the email message with detailed quote
		AVAcceptQuote avq = new AVAcceptQuote(uniqueID, vendorID, bURL);
		Vector vendorVector = db.submitQuery(db.setupQuery(vendorID), 1);	// get the results of the query for use
		String from = (String)vendorVector.get(0) + "<" + (String)vendorVector.get(1) + ">";
		String messageBody = avq.messageBody;
		contactEmail = avq.contactEmail;
		// set the quoteAccepted field in securityRequest table to vendorID for the specific uniqueID
		query = "UPDATE audioVisualRequests SET quoteAccepted = '" + checkQuoteAcceptance("audioVisualRequests") + "' where uniqueID = '" + uniqueID + "'";
		db.submitQuery(query, 3);
		int offset = (rng.nextInt(15));
		minutes += (offset + Integer.valueOf((String)vendorVector.get(3)).intValue());
		db.insertNewMessage((String)vendorVector.get(0), (String)vendorVector.get(1), messageBody, minutes, sessionTime[1]);
		pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
		//pushEmail.sendMail(mailServer, (String)vendorVector.get(0), (String)vendorVector.get(1), contactEmail,
		//				subject, messageBody);

		// insert the event into log table
		db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"),
				request.getParameter("pageSubmit"), request.getParameter("quoteID")));
		if (vendorID.equals("AV1"))
			URL = "/webForms/AV/CMUAVComplete.jsp";
		if (vendorID.equals("AV2"))
			URL = "/webForms/AV/ConferComplete.jsp";
		if (vendorID.equals("AV3"))
			URL = "/webForms/AV/FlagstaffAVComplete.jsp";
		passOff(request, response, URL);
	} // end rentalProcessing()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void cateringProcessing()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for completing the dirty details of the catering request acceptance.
	 * 				This includes getting the messageBody from RentalAcceptQuote.java, forming up the email msg,
	 * 				inserting the message into messageInjection table, and inserting the event into the log table.
	 * Input:		String <vendorID>, String <uniqueID>, HttpServletRequest <request>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void cateringProcessing(String vendorID, String[] data, String uniqueID, HttpServletRequest request, HttpServletResponse response){
		String subject = "Catering Quote Accepted", URL ="null";
		int[]sessionTime = getSessionTime();
		int minutes = sessionTime[0];

		// setup and insert the email message with detailed quote
		CateringAcceptQuote raq = new CateringAcceptQuote(uniqueID, vendorID, bURL);
		Vector vendorVector = db.submitQuery(db.setupQuery(vendorID), 1);	// get the results of the query for use
		String from = (String)vendorVector.get(0) + "<" + (String)vendorVector.get(1) + ">";
		String messageBody = raq.messageBody;
		contactEmail = raq.contactEmail;
		// set the quoteAccepted field in securityRequest table to vendorID for the specific uniqueID
		query = "UPDATE cateringRequests SET quoteAccepted = '" + checkQuoteAcceptance("cateringRequests") + "' where uniqueID = '" + uniqueID + "'";
		db.submitQuery(query, 3);
		int offset = (rng.nextInt(15));
		minutes += (offset + Integer.valueOf((String)vendorVector.get(3)).intValue());
		db.insertNewMessage((String)vendorVector.get(0), (String)vendorVector.get(1), messageBody, minutes, sessionTime[1]);
		pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
		//pushEmail.sendMail(mailServer, (String)vendorVector.get(0), (String)vendorVector.get(1), contactEmail,
		//				subject, messageBody);

		// insert the event into log table
		db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"),
				request.getParameter("pageSubmit"), request.getParameter("quoteID")));
		if (vendorID.equals("catering1"))
			URL = "/webForms/Catering/MaximalComplete.jsp";
		if (vendorID.equals("catering2"))
			URL = "/webForms/Catering/PghComplete.jsp";
		if (vendorID.equals("catering3"))
			URL = "/webForms/Catering/BBreakComplete.jsp";
		passOff(request, response, URL);
	} // end rentalProcessing()


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void floralProcessing()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for completing the dirty details of the floral request acceptance.
	 * 				This includes getting the messageBody from FloralAcceptQuote.java, forming up the email msg,
	 * 				inserting the message into messageInjection table, and inserting the event into the log table.
	 * Input:		String <vendorID>, String <uniqueID>, HttpServletRequest <request>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void floralProcessing(String vendorID, String[] data, String uniqueID, HttpServletRequest request, HttpServletResponse response){
		String subject = "Floral Quote Accepted", URL ="null";
		int[]sessionTime = getSessionTime();
		int minutes = sessionTime[0];

		// setup and insert the email message with detailed quote
		FloralAcceptQuote faq = new FloralAcceptQuote(uniqueID, vendorID, bURL);
		Vector vendorVector = db.submitQuery(db.setupQuery(vendorID), 1);	// get the results of the query for use
		String from = (String)vendorVector.get(0) + "<" + (String)vendorVector.get(1) + ">";
		String messageBody = faq.messageBody;
		contactEmail = faq.contactEmail;
		// set the quoteAccepted field in securityRequest table to vendorID for the specific uniqueID
		query = "UPDATE floralRequests SET quoteAccepted = '" + checkQuoteAcceptance("floralRequests")+ "' where uniqueID = '" + uniqueID + "'";
		db.submitQuery(query, 3);
		int offset = (rng.nextInt(15));
		minutes += (offset + Integer.valueOf((String)vendorVector.get(3)).intValue());
		db.insertNewMessage((String)vendorVector.get(0), (String)vendorVector.get(1), messageBody, minutes, sessionTime[1]);
		pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
		//pushEmail.sendMail(mailServer, (String)vendorVector.get(0), (String)vendorVector.get(1), contactEmail,
		//				subject, messageBody);

		// insert the event into log table
		db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"),
				request.getParameter("pageSubmit"), request.getParameter("quoteID")));
		if (vendorID.equals("floral1"))
			URL = "/webForms/Floral/AdamsComplete.jsp";
		if (vendorID.equals("floral2"))
			URL = "/webForms/Floral/CanalComplete.jsp";
		if (vendorID.equals("floral3"))
			URL = "/webForms/Floral/LilliComplete.jsp";
		passOff(request, response, URL);
	} // end rentalProcessing()


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void passOff()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  - - - - - - - - - - - - - - - - -
	 * Purpose:		This method forwards the HttpServlet request to a jsp.  This is the final
	 * 				page viewed by the organizer.
	 * Input:		HttpServletRequest <request> HttpServletResponse <response>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void passOff(HttpServletRequest request, HttpServletResponse response, String URL){
		try {
			RequestDispatcher dispatcher = getServletContext().getRequestDispatcher(URL);
			dispatcher.forward(request, response);
			}
		catch (Exception e) {
			System.out.println("EXCEPTION: QAServlet - " + e);
		}

	}// end passOff()

    /**
     * add properties from a file to the set of System properties
     * @param ret Properties to which will be added the contents of the file specified
     * @param filename the file which contains the properties to be added to the System
     */
    // here's where we'd make radar.properties load from c:/radar/run
    // (for tomcat, e.g.)
    private void addProps(Properties ret, String filename) {
    	String home = System.getProperty("user.home");
    	logger.debug("user.home is '" + home + "'");
    	InputStream is;
    	if (null != home) {
    		File f = new File(home + File.separator + filename);
    		if (f.exists()) {
    			logger.debug("reading " + f + " first");
    			try {
    				is = new FileInputStream(f);
    				ret.load(is);
    			} catch (Exception e) {
    			logger.error(f + ": " + e);
    		}
	    } else
	    	logger.debug(f + ": is not a file");
    	}
    	File f = new File(filename);
    	if (f.exists()) {
    		logger.debug("now reading " + f);
    		try {
    			is = new FileInputStream(f);
    			ret.load(is);
    		} catch (Exception e) {
    			logger.error(filename + ": " + e);
    		}
    	} else
    		logger.debug(f + ": doesn't exist, moving on");
    }
	
//	- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end QuoteAcceptedServlet.java
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
