package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 				R  E  N  T  A  L   A  C  C  E  P  T  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to gather rental request data for a specific id and set it
 * 			up in a nice format for reading.  Calls are made to the rentalRequest table
 * 			to retrieve request data.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Mar 30, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  - - - - - - - - - - - - - public class RentalAcceptQuote  - - - - - - - - - - - - - -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
public class RentalAcceptQuote {
	public String messageBody = null;
	private String vendorName;
	public String contactEmail = null;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public RentalAcceptQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the RentalAcceptQuote.java class.  Initializes the messageBody by calling
	 * 				setupMessageBody.  The class variable messageBody is used by the QuoteAcceptedServlet to
	 * 				construct a confirmation email to the user
	 * Input:		String <requestID - the unique number in the rentalRequest table>
	 * 				String <vendorID - could be rental1, 2, or 3, passed in through the http stream>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public RentalAcceptQuote(String requestID, String vendorID, String baseURL){
		DatabaseConnectivity db = new DatabaseConnectivity();
		ResultSet rs = db.submitQuery("SELECT * FROM rentalRequests WHERE uniqueID ='" + requestID + "'");
		ResultSet descrip = db.submitQuery("SELECT * FROM rentalItemDescription where uniqueID = '1'");
		try {
			boolean crap = rs.next();
			crap = descrip.next();
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		contactEmail = assignContactEmail(rs);
		messageBody = setupMessageBody(rs, descrip, requestID, vendorID, baseURL);
	} // end constructor

	public String assignContactEmail(ResultSet rs) {
		try {
			return (rs.getString("contactEmail"));
		} catch (SQLException e) {

		}
		return "Error";
	}

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public setupMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method constructs the message body by querying the rentalRequest table and placing
	 * 				the variables in a very long String.  This method is called by the Constructor to initialize
	 * 				the messageBody class variable.  This method calls submitQuery (from DatabaseConnectivity.java),
	 * 				determineQuoteNumber, and assembleMessageBody.
	 * Input:		String <requestID - the unique number in the rentalRequest table>
	 * 				String <vendorID - could be rental1, 2, or 3, passed in through the http stream>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupMessageBody(ResultSet rs, ResultSet descrip, String requestID, String vendorID, String baseURL) {
		String quoteNumber = determineQuoteNumber(vendorID);
		String link = baseURL + determineRentalVendor(vendorID, requestID);
		if (quoteNumber.equals("error")) {
			System.err.println("EXCEPTION: RentalAcceptQuote.setupMessageBody:\n\tThere was an error determining the quoteNumber");
			System.out.println("EXCEPTION: RentalAcceptQuote.setupMessageBody:\n\tThere was an error determining the quoteNumber");
		}
		return (assembleMessageBody(rs, descrip, quoteNumber, link));
	} // end setupMessageBody

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public assembleMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for pulling data from the ResultSet and formatting it in a clean
	 * 				manner so it's easily readable.
	 * Input:		ResultSet <rs>
	 * 				String <quoteNumber - identifies which quote to pull, either quote1, 2, or 3>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String assembleMessageBody(ResultSet rs, ResultSet descrip, String quoteNumber, String link) {
		String s = null;
		String quoteId = null;
		int uniqueId = -1;
		String quotedesc = "";
		try {
		    quoteId = rs.getString("quoteid").substring(7); //number tagged to rentals
		    uniqueId = rs.getInt("uniqueid");
		    if(quoteId.equals(new Integer(uniqueId).toString()))
		    	quotedesc = "detailed ";
		    else
		    	quotedesc = "modified ";

		    s = "Request for Rental Service.  \n" + 
		        "Your "+ quotedesc +"quote from " + vendorName +
				" can be found below.\n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Order Id:\t" + quoteId + "\n" +
				"Event Title:\t" + rs.getString("eventTitle") + "\n" +
				"Event Location:\t" + rs.getString("eventLocation") + "\n" +
				determineRentalType(rs) + "\n" +
				"Setup Complete Time:\t" + rs.getString("setupComplete") + "\n" +
				"Breakdown Start Time:\t" + rs.getString("breakdownStart") + "\n" +
				"Contact First Name:\t" + rs.getString("contactFirstName") + "\n" +
				"Contact Last Name:\t" + rs.getString("contactLastName") + "\n" +
				"Contact Email:\t" + rs.getString("contactEmail") + "\n" +
				"Tent:\t" + rs.getString("tent") + "\n" +
				"\tSize:\t" + tentSizeDescrip(rs, descrip) + "\n" +
			  	"\tType:\t" + tentTypeDescrip(rs, descrip) + "\n" +
				"\tQuantity:\t" + rs.getString("tentQuantity") + "\n" +
				"Chairs:\t" + rs.getString("chairs") + "\n" +
				"\tType:\t" + chairTypeDescrip(rs, descrip) + "\n" +
				"\tColor:\t" + rs.getString("chairColor") + "\n" +
				"\tQuantity:\t" + rs.getString("chairQuantity") + "\n" +
				"Staging:\t" + rs.getString("staging") + "\n" +
				"\tSize:\t" + stagingSizeDescrip(rs, descrip) + "\n" +
				"\tQuantity:\t" + rs.getString("stagingQuantity") + "\n" +
				"Cocktail Tables:\t" + rs.getString("cocktailTables") + "\n" +
				"\tSize:\t" + cocktailSizeDescrip(rs, descrip) + "\n" +
				"\tQuantity:\t" + rs.getString("cocktailTableQuantity") + "\n" +
				"Pipe Drape:\t" + rs.getString("pipeDrape") + "\n" +
				"\tColor:\t" + rs.getString("pipeDrapeColor") + "\n" +
				"\tLength:\t" + pipeSizeDescrip(rs, descrip) + "\n" +
				"\tQuantity:\t" + rs.getString("pipeDrapeQuantity") + "\n" +
				"Banquet Tables:\t" + rs.getString("banquetTables") + "\n" +
				"\tLength:\t" + banquetSizeDescrip(rs, descrip) + "\n" +
				"\tQuantity:\t" + rs.getString("banquetTableQuantity") + "\n" +
				"Round Tables:\t" + rs.getString("roundTables") + "\n" +
				"\tSize:\t" + roundSizeDescrip(rs, descrip) + "\n" +
				"\tQuantity:\t" + rs.getString("roundTableQuantity") + "\n" +
				"Privacy Screen:\t" + rs.getString("privacyScreens") + "\n" +
				"\tQuantity:\t" + rs.getString("privacyScreensQuantity") + "\n" +
				"Coat Rack:\t" + rs.getString("coatRack") + "\n" +
				"\tQuantity:\t" + rs.getString("coatRackQuantity") + "\n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Quote Total:\t$" + rs.getString(quoteNumber) + "\n\n" +
				"Click the link below to review, modify, or cancel your Rental Request:\n\n" +
				link;

		} // end try
		catch(Exception e){
			System.out.println("EXCEPTION: RentalAcceptQuote:assembleMessageBody\n\t An error occurred while assembling message body.\n Here it is: " + e);
		}
		return s;
	} // end printRentalRequestData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineQuoteNumber()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying which quote number in the request table corresponds
	 * 				to the vendorID.
	 * Input:		String <vendorID>
	 * Output:		String <quoteNumber - either quote1, 2, or 3>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineQuoteNumber(String vendorID){
		if (vendorID.equals("rental1")) {
			vendorName = "SPEEDY DELIVERY RENTALS";
			return "quote1" ;
		}
		if (vendorID.equals("rental2")) {
			vendorName = "RENT FROM US!";
			return "quote2";
		}
		if (vendorID.equals("rental3")) {
			vendorName = "CLASSIC RENTALS";
			return "quote3";
		}
		else {
			System.out.println("EXCEPTION: AVAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return "error";
		}
	} // end determineQuoteNumber

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineRentalVendor()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying the rental vendor and returning the appropriate
	 * 				link to quote page.
	 * Input:		String <vendorID> , String <requestID>
	 * Output:		String <link>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineRentalVendor(String vendorID, String requestID){
		if (vendorID.equals("rental1"))
			return ("/myapp/webForms/Rental/SpeedyReviewQuote.jsp?uniqueID=" + requestID);
		if (vendorID.equals("rental2"))
			return ("/myapp/webForms/Rental/RentFromUsReviewQuote.jsp?uniqueID=" + requestID);
		if (vendorID.equals("rental3"))
			return ("/myapp/webForms/Rental/ClassicReviewQuote.jsp?uniqueID=" + requestID);
		else {
			System.out.println("EXCEPTION: RentalAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return "error";
		}
	} // end determineQuoteNumber

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineRentalType()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying the rental request as single or multiple day
	 * 				The corresponding message body is assembled and returned
	 * Input:		ResultSet <rs>
	 * Output:		String
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineRentalType(ResultSet rs) {
		String s = new String();
		String rentalType = new String();
		try {
			rentalType = rs.getString("rentalType");
			if (rentalType.equals("singleDay")){
				s = "Rental Type:\tSingle Day\nDate:\t" + rs.getString("singleMonth") + "/" + rs.getString("singleDay")+
						"/" + rs.getString("singleYear");

			}
			if  (rentalType.equals("multipleDays")) { // rental type was multiple days
				s = "Rental Type:\tMultiple Day\nStart Date:\t" + rs.getString("multStartMonth") +"/" + rs.getString("multStartDay") +
					"/" + rs.getString("multStartYear") + "\nEnd Date:\t" + rs.getString("multEndMonth") + "/" +
					rs.getString("multEndDay") + "/" + rs.getString("multEndYear");
			}
		}
		catch(Exception e){
			System.out.println("EXCEPTION: RentalAcceptQuote:determineRentalType\n\t Rental Type was NOT matched");
			return "error";
		}
		return s;
	} // end determineRentalType()

	public String tentSizeDescrip(ResultSet rs, ResultSet descrip) {
		try {
			String tentSize = rs.getString("tentSize");
			if (tentSize.equals("1"))
				return (descrip.getString("tentSize1"));
			if (tentSize.equals("2"))
				return (descrip.getString("tentSize2"));
			if (tentSize.equals("3"))
				return (descrip.getString("tentSize3"));
			if (tentSize.equals("4"))
				return (descrip.getString("tentSize4"));
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: RentalAcceptQuote:tentSizeDescrip - An exception occurred.\n\t Here it is: " + e);
		}
		return null;
	} // end tentSizeDescrip

	public String tentTypeDescrip(ResultSet rs, ResultSet descrip) {
		try {
			String tentType = rs.getString("tentType");
			if (tentType.equals("1"))
				return (descrip.getString("tentType1"));
			if (tentType.equals("2"))
				return (descrip.getString("tentType2"));
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: RentalAcceptQuote:tentTypeDescrip - An exception occurred.\n\t Here it is: " + e);
		}
		return null;
	}// end tentTypeDescrip

	public String chairTypeDescrip(ResultSet rs, ResultSet descrip) {
		try {
			String chairType = rs.getString("chairType");
			if (chairType.equals("1"))
				return (descrip.getString("chairType1"));
			if (chairType.equals("2"))
				return (descrip.getString("chairType2"));
			if (chairType.equals("3"))
				return (descrip.getString("chairType3"));
			if (chairType.equals("4"))
				return (descrip.getString("chairType4"));
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: RentalAcceptQuote:chairTypeDescrip - An exception occurred.\n\t Here it is: " + e);
		}
		return null;
	} // end chairTypeDescrip

	public String stagingSizeDescrip(ResultSet rs, ResultSet descrip) {
		try {
			String stagingSize = rs.getString("stagingSize");
			if (stagingSize.equals("1"))
				return (descrip.getString("staging1"));
			if (stagingSize.equals("2"))
				return (descrip.getString("staging2"));
			if (stagingSize.equals("3"))
				return (descrip.getString("staging3"));
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: RentalAcceptQuote:stagingSizeDescrip - An exception occurred.\n\t Here it is: " + e);
		}
		return null;
	} // end stagingSizeDescrip

	public String cocktailSizeDescrip(ResultSet rs, ResultSet descrip) {
		try {
			String cocktailTableSize = rs.getString("cocktailTableSize");
			if (cocktailTableSize.equals("1"))
				return (descrip.getString("cocktailSize1"));
			if (cocktailTableSize.equals("2"))
				return (descrip.getString("cocktailSize2"));
			if (cocktailTableSize.equals("3"))
				return (descrip.getString("cocktailSize3"));
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: RentalAcceptQuote:cocktailSizeDescrip - An exception occurred.\n\t Here it is: " + e);
		}
		return null;
	} // end cocktailSizeDescrip

	public String pipeSizeDescrip(ResultSet rs, ResultSet descrip) {
		try {
			String pipeSize = rs.getString("pipeDrapeLength");
			if (pipeSize.equals("1"))
				return (descrip.getString("pipeSize1"));
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: RentalAcceptQuote:pipeSizeDescrip - An exception occurred.\n\t Here it is: " + e);
		}
		return null;
	} // end pipeSizeDescrip

	public String banquetSizeDescrip(ResultSet rs, ResultSet descrip) {
		try {
			String banquetTableSize = rs.getString("banquetTableLength");
			if (banquetTableSize.equals("1"))
				return (descrip.getString("banquetSize1"));
			if (banquetTableSize.equals("2"))
				return (descrip.getString("banquetSize2"));
			if (banquetTableSize.equals("3"))
				return (descrip.getString("banquetSize3"));
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: RentalAcceptQuote:banquetSizeDescrip - An exception occurred.\n\t Here it is: " + e);
		}
		return null;
	} // end banquetTableDescrip

	public String roundSizeDescrip(ResultSet rs, ResultSet descrip) {
		try {
		String roundTableSize = rs.getString("roundTableSize");
		if (roundTableSize.equals("1"))

			return (descrip.getString("roundSize1"));
		if (roundTableSize.equals("2"))
			return (descrip.getString("roundSize2"));
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: RentalAcceptQuote:roundSizeDescrip - An exception occurred.\n\t Here it is: " + e);
		}
		return null;
	} // end roundSizeDescrip
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end RentalAcceptQuote.java
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -