package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 					R  E  N  T  A  L   Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to calculate rental service quotes for requests made by the
 * 			participants.  This class utilizes JDBC calls to get pricing from a MySQL table.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Mar 3, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Vector;

public class RentalQuote {
	Vector request;
	DatabaseConnectivity db;
	String tent = null, chairs = null, staging = null, cocktailTables = null, pipeDrape = null;
	String banquetTables = null, roundTables = null, privacyScreens = null, coatRack = null;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public RentalQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the RentalQuote.java class.  Initializes the request vector for use
	 * 				by class methods.  The rentalRequestVector will be passed in.
	 * Input:		Vector
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public RentalQuote(Vector v){
		request = new Vector(v);
		db = new DatabaseConnectivity();
	} // end Constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int[] calculateQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method calls the rentalCostStructure table and gathers necessary data to calculate
	 * 				and return the quote.  Quotes for all rental service vendors are calculated and placed in an int
	 * 				array.  Currently system is setup for 3 rental vendors.  Additions/deletions will require changes
	 * 				in the costStructure table as well as calculateQuote method.
	 * Input:		none
	 * Output:		int[] <quotes for all towncar providers - caller can use what is needed>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int[] calculateQuote() {
		int[] quoteList = {0,0,0};
		int quoteTotal = 0;
		String[] splitTimes = ((String) request.get(13)).split(":");
		int startHour = Integer.valueOf(splitTimes[0]).intValue();
		int startMinutes = Integer.valueOf(splitTimes[1]).intValue();
		splitTimes = ((String) request.get(14)).split(":");
		int endHour = Integer.valueOf(splitTimes[0]).intValue();
		int endMinutes = Integer.valueOf(splitTimes[1]).intValue();
		int length = (endHour - startHour);

		getRentalRequests();

		int id = 1;
		while (id <= 3){
			ResultSet rs = db.submitQuery("SELECT * FROM rentalCostStructure WHERE uniqueID = '" + id + "'");
			try {
				while (rs.next()){
					quoteTotal = 0;
					if (tent.equals("Yes"))
						quoteTotal += calcTentCost(rs);
					if (chairs.equals("Yes"))
						quoteTotal += calcChairCost(rs);
					if (staging.equals("Yes"))
						quoteTotal += calcStagingCost(rs);
					if (cocktailTables.equals("Yes"))
						quoteTotal += calcCocktailCost(rs);
					if (pipeDrape.equals("Yes"))
						quoteTotal += calcPipeDrapeCost(rs);
					if (banquetTables.equals("Yes"))
						quoteTotal += calcBanquetCost(rs);
					if (roundTables.equals("Yes"))
						quoteTotal += calcRoundCost(rs);
					if (privacyScreens.equals("Yes"))
						quoteTotal += calcPrivacyScreenCost(rs);
					if (coatRack.equals("Yes"))
						quoteTotal += calcCoatRackCost(rs);

				}
				quoteList[id-1] = (quoteTotal * length);
				rs.close();
			} // end try
			catch (SQLException e) {
				System.out.println("EXCEPTION: RentalQuote.calculateQuote: \n\tHere's the error: " + e);
			} // end catch
				id++;
		} // end while (id)
		return(quoteList);
	} // end calculateQuote()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public getRentalRequests()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method checks the request vector to determine what items the user has requested.  The
	 * 				string values are assigned to each particular item and used in CalculateQuote to determine
	 * 				if that items calculateCost method should be called.
	 * Input:		none
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void getRentalRequests(){
		tent = (String)request.get(21);
		chairs = (String) request.get(25);
		staging = (String)request.get(29);
		cocktailTables = (String)request.get(32);
		pipeDrape = (String)request.get(35);
		banquetTables = (String)request.get(39);
		roundTables = (String)request.get(42);
		privacyScreens = (String)request.get(45);
		coatRack = (String)request.get(47);
		} // end getRentalRequests()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcTentCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the tent(s) requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <tentCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcTentCost(ResultSet rs){
		int total = 0, size = 0, type = 0, quant = 0;
		// location of tent data in vector is as follows: size@22, type@23, quant@24
		try {
			size = Integer.valueOf((String) request.get(22)).intValue();
			type = Integer.valueOf((String) request.get(23)).intValue();
			quant = Integer.valueOf((String) request.get(24)).intValue();
			// assign the price for size to the size variable
			switch (size) {
				case 1: {size=rs.getInt("tentSize1");
						break;
				}
				case 2: {size=rs.getInt("tentSize2");
						break;
				}
				case 3: {size=rs.getInt("tentSize3");
						break;
				}
				case 4: {size=rs.getInt("tentSize4");
						break;
				}
			} // end switch size
			// assign the type multiplier to type variable
			switch (type) {
				case 1: {type=rs.getInt("tentType1");
						break;
				}
				case 2: {type=rs.getInt("tentType2");
						break;
				}
			} // end switch type

		// chair cost is quantity x sizePrice x chairType
		total = (quant * size * type);
		} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcTentCost:\n\t Tent total was not calculated.  Here's the exception: " + e);
		}
		
		return total;
	} // end calcTentCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcChairCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the chairs(s) requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <tentCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcChairCost(ResultSet rs){
		int total = 0, type = 0, quant = 0;
		// location of chair data in vector is as follows: type@27, quant@26
		try {
			type = Integer.valueOf((String) request.get(27)).intValue();
			quant = Integer.valueOf((String) request.get(26)).intValue();
			// assign the price for size to the size variable
			switch (type) {
				case 1: {type=rs.getInt("chairType1");
						break;
				}
				case 2: {type=rs.getInt("chairType2");
						break;
				}
				case 3: {type=rs.getInt("chairType3");
						break;
				}
				case 4: {type=rs.getInt("chairType4");
						break;
				}
			} // end switch size

		total = (quant * type);
		} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcChairCost:\n\t Chair total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calChairCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcStagingCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the staging requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <tentCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcStagingCost(ResultSet rs){
		int total = 0, size = 0, quant = 0;
		// location of staging data in vector is as follows: size@30, quant@31
		try {
			size = Integer.valueOf((String) request.get(30)).intValue();
			quant = Integer.valueOf((String) request.get(31)).intValue();
			// assign the price for size to the size variable
			switch (size) {
				case 1: {size=rs.getInt("staging1");
						break;
				}
				case 2: {size=rs.getInt("staging2");
						break;
				}
				case 3: {size=rs.getInt("staging3");
						break;
				}
			} // end switch size

		total = (quant * size);
		} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcStagingCost:\n\t Staging total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calStagingCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcCocktailCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the cocktail tables requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <tentCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcCocktailCost(ResultSet rs){
		int total = 0, size = 0, quant = 0;
		// location of cocktailtable data in vector is as follows: size@33, quant@34
		try {
			size = Integer.valueOf((String) request.get(33)).intValue();
			quant = Integer.valueOf((String) request.get(34)).intValue();
			// assign the price for size to the size variable
			switch (size) {
				case 1: {size=rs.getInt("cocktailSize1");
						break;
				}
				case 2: {size=rs.getInt("cocktailSize2");
						break;
				}
				case 3: {size=rs.getInt("cocktailSize3");
						break;
				}
			} // end switch size

		total = (quant * size);
		} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcCocktailCost:\n\t Cocktail total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calCocktailCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcPipeDrapeCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the pipe drapes requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <tentCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcPipeDrapeCost(ResultSet rs){
		int total = 0, length = 0, quant = 0;
		// location of pipeDrape data in vector is as follows: quant@37
		try {
			quant = Integer.valueOf((String) request.get(37)).intValue();
			// assign the price for length to the length variable
			length=rs.getInt("drapeLength1");

			total = (quant * length);
			} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcPipeDrapeCost:\n\t PipeDrape total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calPipeDrapeCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcBanquetCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the banquet tables requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <tentCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcBanquetCost(ResultSet rs){
		int total = 0, length = 0, quant = 0;
		// location of banquet table data in vector is as follows: length@40, quant@41
		try {
			length = Integer.valueOf((String) request.get(40)).intValue();
			quant = Integer.valueOf((String) request.get(41)).intValue();
			// assign the price for size to the size variable
			switch (length) {
				case 1: {length=rs.getInt("banquetSize1");
						break;
				}
				case 2: {length=rs.getInt("banquetSize2");
						break;
				}
				case 3: {length=rs.getInt("banquetSize3");
						break;
				}
			} // end switch length

		total = (quant * length);
		} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcBanquetCost:\n\t Banquet Table total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calBanquetCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcRoundCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the round tables requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <tentCost>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcRoundCost(ResultSet rs){
		int total = 0, length = 0, quant = 0;
		// location of round table data in vector is as follows: length@43, quant@44
		try {
			length = Integer.valueOf((String) request.get(43)).intValue();
			quant = Integer.valueOf((String) request.get(44)).intValue();
			// assign the price for size to the size variable
			switch (length) {
				case 1: {length=rs.getInt("roundSize1");
						break;
				}
				case 2: {length=rs.getInt("roundSize2");
						break;
				}
			} // end switch length

		total = (quant * length);
		} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcRoundCost:\n\t Round Table total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calBanquetCost()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcPrivacyScreenCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the privacy screen requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcPrivacyScreenCost(ResultSet rs){
		int total = 0, cost = 0, quant = 0;
		// location of privacy screen data in vector is as follows: quant@46
		try {
			quant = Integer.valueOf((String) request.get(46)).intValue();
			// assign the price to cost variable
			cost = rs.getInt("privacyScreen");

		total = (quant * cost);
		} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcPrivacyScreenCost:\n\t Privacy Screen total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcPrivacyScreenCost()


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calcCoatRackCost()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method uses the request vector to calculate the cost for the coatracks requested.
	 * Input:		ResultSet <rs>
	 * Output:		int <total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calcCoatRackCost(ResultSet rs){
		int total = 0, cost = 0, quant = 0;
		// location of coat rack data in vector is as follows: quant@48
		try {
			quant = Integer.valueOf((String) request.get(48)).intValue();
			// assign the price to cost variable
			cost = rs.getInt("coatRack");

		total = (quant * cost);
		} // end try

		catch(Exception e){
			System.out.println("EXCEPTION: RentalQuote.calcCoatRackCost:\n\t Coat Rack total was not calculated.  Here's the exception: " + e);
		}
		return total;
	} // end calcCoatRackCost()
//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 									// end RentalQuote.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

