/*----------------------------------------------------------------------
 * RoomMeeting.java
 * ---------------------------------------------------------------------
 * Purpose:	RoomMeetingjava is used to find meetings based on room, time
 * 			or meetingID.  The CMRadar .sharedRoomCalendar file is read
 * 			to find listings of meetings.  If the meeting detail just read
 * 			in matches criteria searched for then the meeting is stored.
 * Created: July, 2005
 * Author:	Rachael Bennet (srbennet@andrew)
 * ---------------------------------------------------------------------
 * 							Modifications 
 * ---------------------------------------------------------------------
 * 02/23/2006	kcunning	findRoom, findMeetingID, findTime() methods 
 * 							modified so that they will handle empty lines 
 * 							at the end of the input file.  
 * 							Comments added to code.
 * -------------------------------------------------------------------*/

package edu.cmu.radar.vendor.RoomRequest;

import java.util.*;
import java.io.*;

public class RoomMeeting
{
	private String roomId;
	private Meeting meeting;
	private String date;
	private String startTime;
	private String endTime;

	// Constructor
	public RoomMeeting()
	{
		roomId = new String();
		meeting = null;
		date = new String();
		startTime = new String();
		endTime = new String();
	}

	/*----------------------------------------------------------
	 * get Methods
	 * -------------------------------------------------------*/
	public String getRoomId()
	{
		return roomId;
	}

	public Meeting getMeeting()
	{
		return meeting;
	}

	public String getDate()
	{
		return date;
	}

	public String getStartTime()
	{
		return startTime;
	}

	public String getEndTime()
	{
		return endTime;
	}

	public int getArrayIndex(){
		if (startTime.equals("06:00")||(startTime.equals("6:00"))) {return 0;}
		if (startTime.equals("06:30")||(startTime.equals("6:30"))) {return 1;}
		if (startTime.equals("07:00")||(startTime.equals("7:00"))) {return 2;}
		if (startTime.equals("07:30")||(startTime.equals("7:30"))) {return 3;}
		if (startTime.equals("08:00")||(startTime.equals("8:00"))) {return 4;}
		if (startTime.equals("08:30")||(startTime.equals("8:30"))) {return 5;}
		if (startTime.equals("09:00")||(startTime.equals("9:00"))) {return 6;}
		if (startTime.equals("09:30")||(startTime.equals("9:30"))) {return 7;}
		if (startTime.equals("10:00")) {return 8;}
		if (startTime.equals("10:30")) {return 9;}
		if (startTime.equals("11:00")) {return 10;}
		if (startTime.equals("11:30")) {return 11;}
		if (startTime.equals("12:00")) {return 12;}
		if (startTime.equals("12:30")) {return 13;}
		if (startTime.equals("13:00")) {return 14;}
		if (startTime.equals("13:30")) {return 15;}
		if (startTime.equals("14:00")) {return 16;}
		if (startTime.equals("14:30")) {return 17;}
		if (startTime.equals("15:00")) {return 18;}
		if (startTime.equals("15:30")) {return 19;}
		if (startTime.equals("16:00")) {return 20;}
		if (startTime.equals("16:30")) {return 21;}
		if (startTime.equals("17:00")) {return 22;}
		if (startTime.equals("17:30")) {return 23;}
		if (startTime.equals("18:00")) {return 24;}
		if (startTime.equals("18:30")) {return 25;}
		if (startTime.equals("19:00")) {return 26;}
		if (startTime.equals("19:30")) {return 27;}
		if (startTime.equals("20:00")) {return 28;}
		if (startTime.equals("20:30")) {return 29;}
		if (startTime.equals("21:00")) {return 30;}
		if (startTime.equals("21:30")) {return 31;}
		if (startTime.equals("22:00")) {return 32;}
		if (startTime.equals("22:30")) {return 33;}
		if (startTime.equals("23:00")) {return 34;}
		if (startTime.equals("23:30")) {return 35;}
		if (startTime.equals("24:00")) {return 36;}
		if (startTime.equals("00:30")) {return 37;}
		if (startTime.equals("01:00")) {return 38;}
		if (startTime.equals("01:30")) {return 39;}
		else return 0;
	} // end getArrayIndex()

	
	/*----------------------------------------------------------
	 * set Methods
	 * -------------------------------------------------------*/
	public void setRoomId(String id)
	{
		roomId = id;
	}

	public void setMeeting(Meeting meeting)
	{
		this.meeting = meeting;
	}

	public void setDate(String date)
	{
		this.date = date;
	}

	public void setStartTime(String startTime)
	{
		this.startTime = startTime;
	}

	public void setEndTime(String endTime)
	{
		this.endTime = endTime;
	}

	
	/*----------------------------------------------------------------------
	 * findRoom()
	 * ---------------------------------------------------------------------
	 * Purpose:	Responsible for parsing the .sharedRoomCalendar file.  When a meeting 
	 * 			is found a new RoomMeeting object is created.  Meeting data is 
	 * 			gathered and and if the roomID == roomID of the meeting just read
	 * 			RoomMeeting is added to the ArrayList.
	 * Input:	String <filename>, HashMap <result of Meeting.parse()>, String <roomID>
	 * Output:	ArrayList <RoomMeetings> 
	 * 			null if the file cannot be read.
	 * Exceptions:	Use of try/catch block, does not throw exceptions.
	 * -------------------------------------------------------------------*/
	public static ArrayList findRoom(InputStream input_stream, HashMap meetings, String roomId) {
		try{
			BufferedReader file = new BufferedReader(new InputStreamReader(input_stream));
			String line = file.readLine();
			String type;
			//HashMap roomMeetingsHash = new HashMap();
			ArrayList results= new ArrayList();

			while((line != null) && (line.toCharArray().length != 0))
			{
				RoomMeeting rm = new RoomMeeting();
				while((line !=null) && (!line.equals("</room-meeting>")) && (line.toCharArray().length != 0))
				{
					//System.out.println("got a room meeting " + line);
					StringTokenizer tokens = new StringTokenizer(line);

					if (tokens.countTokens() > 1)
					{
						type = tokens.nextToken();

						if (type.compareTo("room-id:") == 0)
							rm.setRoomId((tokens.nextToken()));
						else if(type.compareTo("meeting-id:") == 0)
						{
							String meetingId = tokens.nextToken();
							rm.setMeeting((Meeting)meetings.get(meetingId));
						 }
						else if (type.compareTo("time:") == 0)
							{
								rm.setDate(tokens.nextToken());
								rm.setStartTime(tokens.nextToken());
								tokens.nextToken(); //throw away "to"
								rm.setEndTime(tokens.nextToken());
							}
						}
						line = file.readLine();
					}
				String newRoomId = rm.getRoomId();

				if (roomId.equals(newRoomId))
					results.add(rm);

				line = file.readLine();
			}
			return results;
		} // end try
		catch(Exception e) {  
			e.printStackTrace();
			return null; 
		} // end catch
	} // end findRoom()


	/*----------------------------------------------------------------------
	 * findTime()
	 * ---------------------------------------------------------------------
	 * Purpose:	Responsible for parsing the .sharedRoomCalendar file.  When a meeting 
	 * 			is found a new RoomMeeting object is created.  Meeting data is 
	 * 			gathered and and if the time == time of the meeting just read
	 * 			RoomMeeting is added to the ArrayList.
	 * Input:	String <filename>, HashMap <result of Meeting.parse()>, String <time>
	 * Output:	ArrayList <RoomMeetings> 
	 * 			null if the file cannot be read.
	 * Exceptions:	Use of try/catch block, does not throw exceptions.
	 * -------------------------------------------------------------------*/
	public static ArrayList findTime(String fileName, HashMap meetings, String time) {
		try{
			BufferedReader file = new BufferedReader(new FileReader(fileName));
			String line = file.readLine();
			String type, newTime = new String();
			//HashMap roomMeetingsHash = new HashMap();
			ArrayList results= new ArrayList();

			while((line != null) && (line.toCharArray().length != 0))
			{
				RoomMeeting rm = new RoomMeeting();
				while((line !=null) && (!line.equals("</room-meeting>")) && (line.toCharArray().length != 0))
				{
					//System.out.println("got a room meeting " + line);
					StringTokenizer tokens = new StringTokenizer(line);

					if (tokens.countTokens() > 1)
					{
						type = tokens.nextToken();

						if (type.compareTo("room-id:") == 0)
							rm.setRoomId(tokens.nextToken());
						else if(type.compareTo("meeting-id:") == 0)
						{
							Integer meetingId = (new Integer(tokens.nextToken()));
							rm.setMeeting((Meeting)meetings.get(meetingId));
						 }
						else if (type.compareTo("time:") == 0)
							{
								rm.setDate(tokens.nextToken());
								newTime = rm.getDate() + " ";
								rm.setStartTime(tokens.nextToken());
								newTime += rm.getStartTime() + " ";
								newTime += tokens.nextToken() + " "; //throw away "to"
								rm.setEndTime(tokens.nextToken());
								newTime += rm.getEndTime();
							}
						}
						line = file.readLine();
					}

				if (time.equals(newTime))
					results.add(rm);

				line = file.readLine();
			}
			return results;
		} // end try 
		catch(Exception e) {
			e.printStackTrace();
			return null; 
		} // end catch
	} // end findTime()

	/*----------------------------------------------------------------------
	 * findMeetingID()
	 * ---------------------------------------------------------------------
	 * Purpose:	Responsible for parsing the .sharedRoomCalendar file.  When a meeting 
	 * 			is found a new RoomMeeting object is created.  Meeting data is 
	 * 			gathered and and if the meetingID == meetingID of the meeting just read
	 * 			RoomMeeting is added to the ArrayList.
	 * Input:	String <filename>, HashMap <result of Meeting.parse()>, String <time>
	 * Output:	ArrayList <RoomMeetings> 
	 * 			null if the file cannot be read.
	 * Exceptions:	Use of try/catch block, does not throw exceptions.
	 * -------------------------------------------------------------------*/
	public static ArrayList findMeetingId(String fileName, HashMap meetings, int meetingId) {
		try{
			BufferedReader file = new BufferedReader(new FileReader(fileName));
			String line = file.readLine();
			String type;
			Integer newMeetingId = null;
			ArrayList results= new ArrayList();

			while((line != null) && (line.toCharArray().length != 0))
			{
				RoomMeeting rm = new RoomMeeting();
				while((line !=null) && (!line.equals("</room-meeting>")) && (line.toCharArray().length != 0))
				{
					//System.out.println("got a room meeting " + line);
					StringTokenizer tokens = new StringTokenizer(line);

					if (tokens.countTokens() > 1)
					{
						type = tokens.nextToken();

						if (type.compareTo("room-id:") == 0)
							rm.setRoomId(tokens.nextToken());
						else if(type.compareTo("meeting-id:") == 0)
						{
							newMeetingId = (new Integer(tokens.nextToken()));
							rm.setMeeting((Meeting)meetings.get(newMeetingId));
						 }
						else if (type.compareTo("time:") == 0)
							{
								rm.setDate(tokens.nextToken());
								rm.setStartTime(tokens.nextToken());
								tokens.nextToken(); //throw away "to"
								rm.setEndTime(tokens.nextToken());
							}
						}
						line = file.readLine();
					}

				if (meetingId == (newMeetingId.intValue()))
					results.add(rm);

				line = file.readLine();
			}
			return results;
		} catch(Exception e) {  
			e.printStackTrace();
			return null; 
		}
	} // end findMeetingID()


// -------------------------------------------------------------------
}						// end RoomMeeting.java
// -------------------------------------------------------------------