/*----------------------------------------------------------------------
 * RoomRequest.java
 * ---------------------------------------------------------------------
 * Purpose:	RoomRequest.java is used to find meetings based on room, time
 * 			or meetingID.  Meeting.java and RoomMeeting.java are used in
 * 			conjuction to provide this data.  Inputs used by RoomRequest
 * 			"finder" methods include a valid .meetings and .sharedRoomCalendar
 * 			file.
 * Created: July, 2005
 * Author:	Rachael Bennet (srbennet@andrew)
 * ---------------------------------------------------------------------
 * 							Modifications 
 * ---------------------------------------------------------------------
 * 02/23/2006	kcunning	Comments added to code.
 * -------------------------------------------------------------------*/
package edu.cmu.radar.vendor.RoomRequest;

import java.io.*;
import java.util.*;


public class RoomSearch
{
	private HashMap meetings = new HashMap();

	// Constructor
	public RoomSearch() {}

	public void setMeetings(HashMap meetings) {
		this.meetings = meetings;
	}
	
	public HashMap getMeetings() {
		return meetings;
	}
	
	/*----------------------------------------------------------------------
	 * getMeetingForRoom()
	 * ---------------------------------------------------------------------
	 * Purpose:	Responsible for returning an ArrayList for all meetings 
	 * 			scheduled for the provided roomID.  HashMap meetings is set by
	 * 			calling Meeting.parse and a list of RoomMeetings is returned by
	 * 			calling RoomMeeting.findRoom.
	 * Input:	String <.meetings>, String <.sharedRoomCalendar> String <roomID>
	 * Output:	ArrayList
	 * Exceptions:	None
	 * -------------------------------------------------------------------*/
	public ArrayList getMeetingsForRoom(String meetingFile, String roomMeetingFile, String roomId) {
		ArrayList result=new ArrayList();
        Class this_class = this.getClass();
        System.out.println(meetingFile);
	    ///java.io.InputStream in_stream = this_class.getResourceAsStream( meetingFile ); SUCK
		try {
			FileInputStream in_stream = new FileInputStream(meetingFile);
			this.setMeetings(Meeting.parse(in_stream));
		    in_stream.close();
		} 
		catch (Exception e) {}
		System.out.println(roomMeetingFile);
		Class again_this_class = this.getClass();
		///java.io.InputStream another_in_stream = again_this_class.getResourceAsStream( roomMeetingFile ); SUCK		
		try {
			FileInputStream another_in_stream = new FileInputStream(roomMeetingFile);
			result = RoomMeeting.findRoom(another_in_stream, this.getMeetings(), roomId);
			another_in_stream.close();
		} catch (Exception e) {}

		return (result);
	} // end getMeetingsForRoom()

	/*----------------------------------------------------------------------
	 * getMeetingForTime()
	 * ---------------------------------------------------------------------
	 * Purpose:	Responsible for returning an ArrayList for all meetings 
	 * 			scheduled at the provided time.  HashMap meetings is set by
	 * 			calling Meeting.parse and a list of RoomMeetings is returned by
	 * 			calling RoomMeeting.findTime.
	 * Input:	String <.meetings>, String <.sharedRoomCalendar> String <time>
	 * Output:	ArrayList
	 * Exceptions:	None
	 * -------------------------------------------------------------------*/
	public ArrayList getMeetingsForTime(String meetingFile, String roomMeetingFile, String time) {
		File meetFile;
		InputStream in_stream;
		try
		{
		    meetFile = new File(meetingFile);
		    in_stream = new FileInputStream(meetFile);
		    this.setMeetings(Meeting.parse(in_stream));
		    in_stream.close();
		}
		catch(Exception e)
		{
			
		}
		return (RoomMeeting.findTime(roomMeetingFile, this.getMeetings(), time));
	} // end getMeetingsForTime()

	/*----------------------------------------------------------------------
	 * getMeetingByID()
	 * ---------------------------------------------------------------------
	 * Purpose:	Responsible for returning an ArrayList for all scheduled meetings 
	 * 			matching the provided meetingID.  HasMap meetings is set by
	 * 			calling Meeting.parse and a list of RoomMeetings is returned by
	 * 			calling RoomMeeting.findMeetingID.
	 * Input:	String <.meetings>, String <.sharedRoomCalendar> String <meetingID>
	 * Output:	ArrayList
	 * Exceptions:	None
	 * -------------------------------------------------------------------*/
	public ArrayList getMeetingsByID(String meetingFile, String roomMeetingFile, int meetingId) {
		File meetFile;
		InputStream in_stream;
		try
		{
		    meetFile = new File(meetingFile);
		    in_stream = new FileInputStream(meetFile);
		    this.setMeetings(Meeting.parse(in_stream));
		    in_stream.close();
		}
		catch(Exception e)
		{
			
		}
		return (RoomMeeting.findMeetingId(roomMeetingFile, this.getMeetings(), meetingId));
	} // end getMeetingsByID


// --------------------------------------------------------------------------
}					// end RoomSearch.java
// --------------------------------------------------------------------------