package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 				S  E  C  U  R  I  T  Y   A  C  C  E  P  T  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to gather Security request data for a specific id and set it
 * 			up in a nice format for reading.  Calls are made to the securityRequest table
 * 			to retrieve request data.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Mar 16, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  - - - - - - - - - - - - - public class SecurityAcceptQuote  - - - - - - - - - - - - - -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
public class SecurityAcceptQuote {
	public String messageBody = new String();
	public String contactEmail = new String();

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public SecurityAcceptQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the SecurityAcceptQuote.java class.  Initializes the messageBody by calling
	 * 				setupMessageBody.  The class variable messageBody is used by the QuoteAcceptedServlet to
	 * 				construct a confirmation email to the user
	 * Input:		String <requestID - the unique number in the securityRequest table>
	 * 				String <vendorID - could be towncar1, 2, or 3, passed in through the http stream>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public SecurityAcceptQuote(String requestID, String vendorID, String baseURL){
		DatabaseConnectivity db = new DatabaseConnectivity();
		ResultSet rs = db.submitQuery("SELECT * FROM securityRequests WHERE uniqueID ='" + requestID + "'");
		try {
			boolean crap = rs.next();
		} catch (SQLException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		contactEmail = assignContactEmail(rs);
		messageBody = assembleMessageBody(rs, requestID, baseURL);
	} // end constructor

	public String assignContactEmail(ResultSet rs) {
		try {
			return (rs.getString("contactEmail"));
		} catch (SQLException e) {

		}
		return "Error";
	}


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public assembleMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for pulling data from the ResultSet and formatting it in a clean
	 * 				manner so it's easily readable.
	 * Input:		ResultSet <rs>
	 * 				String <requestID - used in formation of the URL to link back to this request>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String assembleMessageBody(ResultSet rs, String requestID, String baseURL) {
		String s = new String();
		String quoteId = null;
		int uniqueId = -1;
		String quotedesc = "";
		try {
		    quoteId = rs.getString("quoteid").substring(8); //number tagged to security
		    uniqueId = rs.getInt("uniqueid");
		    if(quoteId.equals(new Integer(uniqueId).toString()))
		    	quotedesc = "detailed ";
		    else
		    	quotedesc = "modified ";

		    s = "Your Security Request Submission is "+quotedesc+"below: \n"  +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Order Id:\t" + quoteId + "\n" +
				"Event Title:\t" + rs.getString("eventTitle") + "\n" +
				"Event Location:\t" + rs.getString("eventLocation") + "\n" +
				getDate(rs) +
				"Contact First Name:\t" + rs.getString("contactFirstName") + "\n" +
				"Contact Last Name:\t" + rs.getString("contactLastName") + "\n" +
				"Contact Email:\t" + rs.getString("contactEmail") + "\n" +
				"Crowd Control:\t" + rs.getString("crowdControl") + "\n"+
				"Traffic Control:\t" + rs.getString("trafficControl") + "\n" +
			  	"Parking Assistance:\t" + rs.getString("parkingAssistance") + "\n" +
				"VIP:\t" + rs.getString("vip") + "\n" +
				"Alcohol:\t" + rs.getString("alcohol") + "\n" +
				"# of Security Staff:\t" + rs.getString("numberSecurityStaff") + "\n" +
				"Type of Security Clothing:\t" + rs.getString("securityClothing") + "\n" +
				"Security Start Time:\t" + rs.getString("startTime") + "\n" +
				"Security End Time:\t" + rs.getString("endTime") + "\n" +
				"Location:\t" + rs.getString("location") + "\n" +
				"Serve Alcohol:\t" + rs.getString("funcServeAlcohol") + "\n" +
				"Guard Valuables:\t" + rs.getString("funcGuardValuables") + "\n" +
				"Maintain Perimeter:\t" + rs.getString("funcMaintainPerimeter") + "\n" +
				"Monitor Traffic:\t" + rs.getString("funcMonitorTraffic") + "\n" +
				"Open Garage:\t" + rs.getString("funcOpenGarage") + "\n" +
				"Maintain Presence:\t" + rs.getString("funcMaintainPresence") + "\n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Quote Total:\t$" + rs.getString("calculatedQuote") + "\n\n" +
				"Click the link below to review, modify, or cancel your Security Request:\n\n" +
				baseURL + "/myapp/webForms/Security/SecurityReviewQuote.jsp?uniqueID=" + requestID;
		} // end try
		catch(Exception e){}
		return s;
	} // end printSecurityRequestData()

	public String getDate(ResultSet rs) {
		try {
			String date = "Event Date:\t" + rs.getString("eventMonth") + " " + rs.getString("eventDayOfMonth") + ", " +
				rs.getString("eventYear")+ "\n";
				return date;
		}
		catch (SQLException e) {
			System.out.println("EXCEPTION: AVAcceptQuote:getDate - An exception occurred.\n\t Here it is: " + e);
		}
		return "";
	} // end

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end SecurityAcceptQuote.java
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
