package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 				S  E  C  U  R  I  T  Y  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to calculate security quotes for requests made by the
 * 			participants.  This class utilizes JDBC calls to get pricing from a MySQL table.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Mar 1, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Vector;

public class SecurityQuote {
	Vector request;
	DatabaseConnectivity db;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public SecurityQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the SecurityQuote.java class.  Initializes the request vector for use
	 * 				by class methods.  The securityRequestVector will be passed in.
	 * Input:		Vector
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public SecurityQuote(Vector v){
		request = new Vector(v);
		db = new DatabaseConnectivity();
	} // end Constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int calculateQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method calls the securityCostStructure table and gathers necessary data to calculate
	 * 				and return the quote.  numSecurityStaff is @ position 12, startTime @ 14, endTime @ 15
	 * Input:		none
	 * Output:		int <quote total>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int calculateQuote() {
		String[] splitTimes = ((String) request.get(15)).split(":");
		int startHour = Integer.valueOf(splitTimes[0]).intValue();
		int startMinutes = Integer.valueOf(splitTimes[1]).intValue();
		splitTimes = ((String) request.get(16)).split(":");
		int endHour = Integer.valueOf(splitTimes[0]).intValue();
		int endMinutes = Integer.valueOf(splitTimes[1]).intValue();

		int numGuards = Integer.valueOf((String)request.get(13)).intValue();

		int length = (endHour - startHour);
		int price = 0, quote = 0;
		String query = "SELECT perHour FROM securityCostStructure WHERE id = '1'";
		//String query = "SELECT price FROM vendor.itemprice WHERE item_id = '1'";
		ResultSet rs = db.submitQuery(query);
		try {
			while (rs.next()){
				price = rs.getInt("perHour");
				}
		}
			catch (SQLException e) {
				System.out.println("EXCEPTION: SecurityQuote.calculateQuote: \n Here's the error: " + e);
		}

		quote = (numGuards * length * price);
		return(quote);
	} // end calculateQuote()
//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end SecurityQuote.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -