package edu.cmu.radar.vendor;
/*************************************************************************************************************
 *				 	T  E  S  T  H  A  R  N  E  S  S  S  E  R  V  L  E  T  . J  A  V  A 									 *
 *************************************************************************************************************
 * Purpose: 	This Java program is a servlet that processes incoming web data from forms created for the
 * 				RADAR grand challenge
 * Functionality: Web request forms are processed and email responses are sent.  Form data can be printed to
 * 				  system.out or the web screen if necessary.
 * Input:	none
 * Output:	none
 * Dependencies:	none
 * Author: 		Kyle A Cunningham <kcunning@cs.cmu.edu>
 ************************************************************************************************************/

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Properties;
import java.util.Random;
import java.util.ResourceBundle;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.log4j.Logger;


public class TestHarnessServlet extends HttpServlet {
	private static Properties props = null;
    private static Logger logger = Logger.getLogger(TestHarnessServlet.class);
    
	public String requestType, quoteModification, modificationID;
	public int requestTypeFlag = 0, printFlag = 0;
	private PrintWriter out;
	static sendEmail pushEmail;
    DatabaseConnectivity db;
	static String mailServer = "vio.isri.cmu.edu";
	HttpSession session;
	int uniqueID = 0;
        String quoteID = null;
        StringBuffer baseURL;
	String bURL;
	String quoteIDString = new String("Order Id: ");

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void doGet()																				   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		standard method required for servlet functionality
	 * 				responsible for all servlet processing
	 * Input:		HttpServletRequest, HttpServletResponse
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void doGet(HttpServletRequest request, HttpServletResponse response)	throws ServletException, IOException {
		System.out.println("-----------------\nTHServlet Processing Started\n-----------------");
		session = request.getSession(true);
		pushEmail = new sendEmail();
		db = new DatabaseConnectivity();
		baseURL = request.getRequestURL();
		String[] URLSplit = baseURL.toString().split("/myapp/");
		bURL = URLSplit[0];

		response.setContentType("text/html");
		PrintWriter out = response.getWriter();
		requestType = request.getParameter("requestType");
		// the following 2 variables are used when a quote modification has come in
		quoteModification = request.getParameter("quoteModification");
		if (quoteModification == null)
			quoteModification = "no";
		modificationID = request.getParameter("uniqueID");
		requestTypeFlag = assignRequestType(out, request);
		printFlag = 1;
		switch (requestTypeFlag) {
			// audioVisual
			case 1: {processAudioVisualRequest(request, response);
					break;
					}
			// parking
			//case 2: {processParkingRequest(request, response, printFlag, out);
			//		break;
			//		}
			// rental
			case 3: {processRentalRequest(request, response);
					break;
					}
			// security
			case 4: {processSecurityRequest(request, response);
					break;
					}
			// towncar
			//case 5: {processTowncarRequest(request, response, printFlag, out);
			//		break;
			//		}
			// catering
			case 6: {processCateringRequest(request, response);
					break;
					}
			// floral
			case 7: {processFloralRequest(request, response);
					break;
					}
		} // end switch
	} // end doGet()


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void assignRequestType()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		determine what the request is and assign the requestFlag accordingly for use by other
	 * 				methods
	 * Input:		HttpServletRequest, String, int
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int assignRequestType(PrintWriter out, HttpServletRequest request) {
		// Determine what the request type is & assign the flag accordingly
		if (requestType.equals("audioVisual")) {
			return 1;
			}
		if (requestType.equals("parking")) {
			return 2;
			}
		if (requestType.equals("rentals")) {
			return 3;
			}
		if (requestType.equals("security")) {
			return 4;
			}
		if (requestType.equals("towncar")) {
			return 5;
			}
		if (requestType.equals("catering")) {
			return 6;
			}
		if (requestType.equals("floral")) {
			return 7;
			}
		else { // error
			out.println("I couldn't match the value to anything specifed, sorry! <p>");
			return 0;}
	} // end assignRequestType

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void setupReplyMessage()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		based on requestTypeFlag gather info from requestVector, call setupQuery, and pass input
	 * 				to sendMail()
	 * 				- Called within a form processing method
	 * Input:		requestVector
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
    protected void setupReplyMessage(Vector v, String vendorTypeID, String URL) {
		String contactName; 	// this will be prepared by combing contactFirst + contactLast
		String contactEmail;	// recipient of email
		String subject;

		Vector queryVector = db.submitQuery(db.setupQuery(vendorTypeID), 1); // vendor info 0=name, 1=address
		String from = (String)queryVector.get(0) + "<" + (String)queryVector.get(1) + ">";
		String messageBody = (String)queryVector.get(2) + "\n\n" + "Order Id: " + quoteID + "\n" + URL;

		int[]sessionTime = getSessionTime();
		String[] data = getIMAPData();
		int minutes = sessionTime[0];
		Random rng = new Random();

		switch (requestTypeFlag) {
		// audioVisual
		case 1: { 	contactName = v.get(7) + " " + v.get(8);
					contactEmail = "<" + (String) v.get(9) + ">";
					subject = "A/V Request Submission";
					int offset = (rng.nextInt(15));
					minutes += (offset + Integer.valueOf((String)queryVector.get(3)).intValue());
					db.insertNewMessage((String)queryVector.get(0), (String)queryVector.get(1), messageBody, minutes, sessionTime[1]);
					pushEmail.sendMail(data[0], data[1], data[2], contactEmail, from, subject, messageBody);
					//pushEmail.sendMail(mailServer, (String)queryVector.get(0), (String)queryVector.get(1), contactEmail,
					//				subject, messageBody);
					break;
				}
		// parking
		/*case 2: {	contactName = v.get(3) + " " + v.get(4);
					contactEmail = (String) v.get(6);
					subject = "Parking Request Submission";
					queryVector = db.submitQuery(db.setupQuery(requestType), 1);	// get the results of the query for use
					//pushEmail.sendMail(mailServer, (String)queryVector.get(0), (String)queryVector.get(1), contactEmail,
					//			subject, setupMessageBody(queryVector, contactName));
					break;
				}
		*/
		// rental
		case 3: {	contactName = v.get(15) + " " + v.get(16);
					contactEmail = (String) v.get(17);
					subject = "Rental Request Submission";
					int offset = (rng.nextInt(15));
					minutes += (offset + Integer.valueOf((String)queryVector.get(3)).intValue());
					db.insertNewMessage((String)queryVector.get(0), (String)queryVector.get(1), messageBody, minutes, sessionTime[1]);
					pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
					//pushEmail.sendMail(mailServer, (String)queryVector.get(0), (String)queryVector.get(1), contactEmail,
					//				subject, messageBody);
					break;
				}
		// security
		case 4: {	contactName = v.get(5) + " " + v.get(6);
					contactEmail = (String) v.get(7);
					subject = "Security Request Submission";
					pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
					//pushEmail.sendMail(mailServer, (String)queryVector.get(0), (String)queryVector.get(1), contactEmail,
					//				subject, messageBody);
					break;
				}
		// towncar
		/*
		case 5: {	contactName = v.get(3) + " " + v.get(4);
					contactEmail = (String) v.get(6);
					subject = "Towncar Request Submission";
					int offset = (rng.nextInt(15));
					minutes += (offset + Integer.valueOf((String)queryVector.get(3)).intValue());
					db.insertNewMessage((String)queryVector.get(0), (String)queryVector.get(1), messageBody, minutes, sessionTime[1]);
					pushEmail.sendMail(data[0], data[1], data[2], contactEmail, from, subject, messageBody);
					//pushEmail.sendMail(mailServer, (String)queryVector.get(0), (String)queryVector.get(1), contactEmail,
					//				subject, messageBody);
					break;
				}
		*/
		// catering
		case 6: {	contactName = v.get(0) + " " + v.get(1);
					contactEmail = (String) v.get(2);
					subject = "Catering Request Submission";
					int offset = (rng.nextInt(15));
					minutes += (offset + Integer.valueOf((String)queryVector.get(3)).intValue());
					db.insertNewMessage((String)queryVector.get(0), (String)queryVector.get(1), messageBody, minutes, sessionTime[1]);
					pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
					//pushEmail.sendMail(mailServer, (String)queryVector.get(0), (String)queryVector.get(1), contactEmail,
					//	subject, messageBody);
					break;
				}
		// floral
		case 7: {	contactName = v.get(0) + " " + v.get(1);
					contactEmail = (String) v.get(2);
					subject = "Floral Request Submission";
					int offset = (rng.nextInt(15));
					minutes += (offset + Integer.valueOf((String)queryVector.get(3)).intValue());
					db.insertNewMessage((String)queryVector.get(0), (String)queryVector.get(1), messageBody, minutes, sessionTime[1]);
					pushEmail.sendMail(data[0], data[1], data[2], "<" + contactEmail + ">", from, subject, messageBody);
					//pushEmail.sendMail(mailServer, (String)queryVector.get(0), (String)queryVector.get(1), contactEmail,
					//		subject, messageBody);
					break;
				}
		} // end switch
	} // end setupReplyMessage()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void passOff()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method forwards the HttpServlet request to CalendarSubmission.jsp.  This is the final
	 * 				page viewed by the organizer.
	 * Input:		HttpServletRequest <request> HttpServletResponse <response>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void passOff(HttpServletRequest request, HttpServletResponse response, String URL){
		try {
			RequestDispatcher dispatcher = getServletContext().getRequestDispatcher(URL);
			dispatcher.forward(request, response);
			}
		catch (Exception e) {
			System.out.println("EXCEPTION: THServlet - " + e);
		}

	}// end passOff()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public String[] getIMAPData()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is used to gather a user's name, pass, and imapHost from vendorDB.properties
	 * 				which is used by sendEmail().
	 * Input:		none
	 * Output:		String[] 0 - userName, 1 - userPass, 2 - imapHost
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String[] getIMAPData(){
		ResourceBundle rb = null;
		try {
			rb = ResourceBundle.getBundle("properties/vendorDB");
		} catch(Exception e) {} // getBundle throws an exception if the properties file doesnt exist
		String[] data = new String[3];
	      data[0] = getValueForKey(rb, "", "radar.vendor.imap.user");
	      data[1] = getValueForKey(rb, "", "radar.vendor.imap.password");
	      data[2] = getValueForKey(rb, "", "radar.vendor.imap.host");

	      // in case we are working from the rb rather than the system properties,
	      // this should make sure jordan's sendEmail thing doesnt call vio stuff
	      // when its been specified that we are in standalone mode
	      String foo = getValueForKey(rb, "", "radar.standalone");
	      if (foo != null && !foo.equals(""))
	    	  System.setProperty("radar.standalone", foo);
	      
	      return data;
	}

    // Helper function to search for key in System properties or vendorDB.properties
    // Same function present in DatabaseConnectivity.java. 
    // Parameter list is slightly different.
    public String getValueForKey(ResourceBundle rb, String defaultValue, String key) {
    	String result = null;
    	if (props == null) {
    		props = new Properties(System.getProperties());
    		addProps(props, "radar.properties");
    		addProps(props, "user.properties");
    	}
    	
    	result = props.getProperty(key);
    	if (result == null)
    	{
    		try {
    			result = rb.getString(key);
    		}
    		catch(Exception e) {
    			//To catch MissingResourceException primarily
    			result = null;
    		}
    	}
    	if(result == null)
    		return defaultValue;
    	else
    		return result;
    }

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int[] getSessionTime()																		   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method returns the current session time (provided by TestHarnessTimer).  Session time
	 * 				is gathered by querying the sessionTime table.
	 * Input:		none
	 * Output:		int
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int[] getSessionTime() {
		int minutes = 0, seconds = 0;
		String query = "SELECT * FROM sessionTime";
		ResultSet rs =  db.submitQuery(query);
		try {
			while (rs.next()){
				minutes = rs.getInt(1); // id is at rs(0)
				seconds = rs.getInt(2);
				}
		}
			catch (SQLException e) {
				System.out.println("EXECPTION: THServlet:getSessionTime: " + e);
			}
		int[] sessionTime = new int[2];
		sessionTime[0]=minutes;
		sessionTime[1]=seconds;
		return sessionTime;
	} // end getSessionTime()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * 							F o r m  P r o c e s s i n g  M e t h o d s
	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processAudioVisualRequest()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		pull out each form variable from the audioVisual request and process accordingly
	 * Input:		HttpServletRequest, String, int, PrintWriter
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void processAudioVisualRequest(HttpServletRequest request, HttpServletResponse response) {
		Vector audioVisualRequestVector = new Vector();
		String quoteAmount = null;
		audioVisualRequestVector.add(request.getParameter("eventTitle"));		// 0
		audioVisualRequestVector.add(request.getParameter("eventLocation"));
		audioVisualRequestVector.add(request.getParameter("eventMonth"));
		audioVisualRequestVector.add(request.getParameter("eventDayOfMonth"));
		audioVisualRequestVector.add(request.getParameter("eventYear"));
		audioVisualRequestVector.add(request.getParameter("setupComplete"));	// 5
		audioVisualRequestVector.add(request.getParameter("breakdownStart"));
		audioVisualRequestVector.add(request.getParameter("contactFirstName"));
		audioVisualRequestVector.add(request.getParameter("contactLastName"));
		audioVisualRequestVector.add(request.getParameter("contactEmail"));
		audioVisualRequestVector.add(request.getParameter("AV1")); 				//10
		audioVisualRequestVector.add(request.getParameter("AV2"));
		audioVisualRequestVector.add(request.getParameter("AV3"));
		audioVisualRequestVector.add(request.getParameter("cdPlayer"));   		//13
		audioVisualRequestVector.add(request.getParameter("wirelessMic"));
		audioVisualRequestVector.add(request.getParameter("lavalierMic"));		//15
		audioVisualRequestVector.add(request.getParameter("podiumMic"));
		audioVisualRequestVector.add(request.getParameter("panelMic"));
		audioVisualRequestVector.add(request.getParameter("podLaptopCon"));
		audioVisualRequestVector.add(request.getParameter("videoProj"));
		audioVisualRequestVector.add(request.getParameter("compProj"));  		//20
		audioVisualRequestVector.add(request.getParameter("tvVCRDVD"));
		audioVisualRequestVector.add(request.getParameter("TV"));
		audioVisualRequestVector.add(request.getParameter("slideProj"));
		audioVisualRequestVector.add(request.getParameter("overheadProj"));
		audioVisualRequestVector.add(request.getParameter("easel"));			//25
		audioVisualRequestVector.add(request.getParameter("pcLaptop"));
		audioVisualRequestVector.add(request.getParameter("appleLaptop"));
		audioVisualRequestVector.add(request.getParameter("flipCharts"));
		audioVisualRequestVector.add(request.getParameter("screen"));
		audioVisualRequestVector.add(request.getParameter("phones"));			//30
		audioVisualRequestVector.add(request.getParameter("faxMachine"));
		audioVisualRequestVector.add(request.getParameter("computerCon"));
		audioVisualRequestVector.add(request.getParameter("podium"));
		audioVisualRequestVector.add(request.getParameter("lecturn"));
		audioVisualRequestVector.add(request.getParameter("videotaping"));		//35
		audioVisualRequestVector.add(request.getParameter("laserPointer"));
		audioVisualRequestVector.add(request.getParameter("quantCDPlayer")); 	//37
		audioVisualRequestVector.add(request.getParameter("quantWirelessMic"));
		audioVisualRequestVector.add(request.getParameter("quantLavalierMic"));
		audioVisualRequestVector.add(request.getParameter("quantPodMic")); 		//40
		audioVisualRequestVector.add(request.getParameter("quantPanelMic"));
		audioVisualRequestVector.add(request.getParameter("quantPodLaptopCon"));
		audioVisualRequestVector.add(request.getParameter("quantVideoProj"));
		audioVisualRequestVector.add(request.getParameter("quantCompProj"));
		audioVisualRequestVector.add(request.getParameter("quantTVVCR"));		//45
		audioVisualRequestVector.add(request.getParameter("quantTV"));
		audioVisualRequestVector.add(request.getParameter("quantSlideProj"));
		audioVisualRequestVector.add(request.getParameter("quantOverheadProj"));
		audioVisualRequestVector.add(request.getParameter("quantEasel"));
		audioVisualRequestVector.add(request.getParameter("quantPCLaptop"));	//50
		audioVisualRequestVector.add(request.getParameter("quantAppleLaptop"));
		audioVisualRequestVector.add(request.getParameter("quantFlipCharts"));
		audioVisualRequestVector.add(request.getParameter("quantScreen"));
		audioVisualRequestVector.add(request.getParameter("quantPhones"));
		audioVisualRequestVector.add(request.getParameter("quantFax"));			//55
		audioVisualRequestVector.add(request.getParameter("quantComputerCon"));
		audioVisualRequestVector.add(request.getParameter("quantPodium"));
		audioVisualRequestVector.add(request.getParameter("quantLecturn"));
		audioVisualRequestVector.add(request.getParameter("quantVideotaping"));
		audioVisualRequestVector.add(request.getParameter("quantLaserPointer"));	//60
		audioVisualRequestVector.add(request.getParameter("externalSpeakers"));     //61
		audioVisualRequestVector.add(request.getParameter("quantExternalSpeakers"));//62
		audioVisualRequestVector.add(request.getParameter("pageLoad"));			//63
		audioVisualRequestVector.add(request.getParameter("pageSubmit")); 		//64

		AVQuote avq = new AVQuote(audioVisualRequestVector);
		int[] quote = avq.calculateQuote();
		for (int i=0; i<quote.length; i++) {
			audioVisualRequestVector.add(new Integer(quote[i]));
		}
		String AV1 = (String)request.getParameter("AV1");
		String AV2 = (String)request.getParameter("AV2");
		String AV3 = (String)request.getParameter("AV3");
		//String URL = ".hcii.cs.cmu.edu:8080/myapp/webForms/AV/";
		String URL = bURL + "/myapp/webForms/AV/";
		String passOffURL = "/webForms/VendorRequestComplete.jsp";
		String query;

		//Replacing all "quant" values with null in case they are empty
		//Postgres will not take in blank values
		for(int i=37;i<63;i++)
		{
			Object elem = audioVisualRequestVector.get(i);
			if(elem == null)
				audioVisualRequestVector.set(i, "null");
			else
			{
				if(elem.toString().length() == 0)
					audioVisualRequestVector.set(i, "null");
			}
		}

		db.insertAudioVisualData(audioVisualRequestVector);
		
		ResultSet rs = db.submitQuery("SELECT uniqueID, quoteID from audioVisualRequests WHERE pageSubmitted = '" + (String)audioVisualRequestVector.get(64)
				+ "' AND contactFirstName = '" + (String)audioVisualRequestVector.get(7) + "'");
		try {
			while (rs.next()) {
				uniqueID = rs.getInt("uniqueID");
			}
		}
		catch (Exception e) {}

		quoteID = request.getParameter("quoteID");
		if (quoteID==null)
		    quoteID = "" + uniqueID;
		else
		    quoteID = quoteID.substring(11);



		// add the quoteID to the entry in the AVRequestTable.  quoteID = "AV" + original quoteID, so if this
		// is a modification enter the quoteID of the original, not the newest insertion uniqueID
		if (quoteModification.equals("yes")){
			db.submitInsertQuery("UPDATE audioVisualRequests SET quoteID = '" + request.getParameter("quoteID") + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					request.getParameter("quoteID")));
		} // end if quoteModification
		else {
			db.submitInsertQuery("UPDATE audioVisualRequests SET quoteID = '" + requestType + uniqueID + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("AVForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					"audioVisual" + uniqueID));
		}

		//look at AV service variables and see which ones they want quote from, apppend links as necessary
		if (AV1 != null){
			quoteAmount = "Quoted price: $" + quote[0] + "\n\n";
			URL += "CMUAVQuote.jsp?eventSource=AVForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(audioVisualRequestVector, "AV1", quoteAmount + URL);
		}
		if (AV2 != null){
			quoteAmount = "Quoted price: $" + quote[1] + "\n\n";
			//URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/AV/";
			URL = bURL + "/myapp/webForms/AV/";
			URL += "ConferQuote.jsp?eventSource=AVForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(audioVisualRequestVector, "AV2", quoteAmount + URL);
		}
		if (AV3 != null){
			quoteAmount = "Quoted price: $" + quote[2] + "\n\n";
			//URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/AV/";
			URL = bURL + "/myapp/webForms/AV/";
			URL += "FlagstaffAVQuote.jsp?eventSource=AVForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(audioVisualRequestVector, "AV3", quoteAmount + URL);
		}
		if (quoteModification.equals("yes")&&(AV1 != null))
			passOff(request, response, "/webForms/AV/CMUAVModifySubmitted.jsp");
		if (quoteModification.equals("yes")&&(AV2 != null))
			passOff(request, response, "/webForms/AV/ConferModifySubmitted.jsp");
		if (quoteModification.equals("yes")&&(AV3 != null))
			passOff(request, response, "/webForms/AV/FlagstaffAVModifySubmitted.jsp");
		else
			passOff(request, response, passOffURL);

	} // end processAudioVisualRequest


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processParkingRequest()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		pull out each form variable from the parking request and process accordingly
	 * 				If printFlag == 1 then data will print to screen, otherwise data is submitted to DB,
	 * 				submission thank you message is sent to screen
	 * Input:		HttpServletRequest, String, int, PrintWriter
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/*	public void processParkingRequest(HttpServletRequest request, HttpServletResponse response, int printFlag, PrintWriter out) {
	// -- DEBUG --
		Vector parkingRequestVector = new Vector();
		parkingRequestVector.add(request.getParameter("eventTitle"));
		parkingRequestVector.add(request.getParameter("eventLocation"));
		parkingRequestVector.add(request.getParameter("eventDate"));
		parkingRequestVector.add(request.getParameter("contactFirstName"));
		parkingRequestVector.add(request.getParameter("contactLastName"));
		parkingRequestVector.add(request.getParameter("contactPhone"));
		parkingRequestVector.add(request.getParameter("contactEmail"));
		parkingRequestVector.add(request.getParameter("numParkingSpaces"));
		parkingRequestVector.add(request.getParameter("parkingLocation"));
		parkingRequestVector.add(request.getParameter("validationPasses"));
		parkingRequestVector.add(request.getParameter("numValidationPasses"));
		parkingRequestVector.add(request.getParameter("trafficGuard"));
		parkingRequestVector.add(request.getParameter("pageLoad"));
		parkingRequestVector.add(request.getParameter("pageSubmit"));

		ParkingQuote pq = new ParkingQuote(parkingRequestVector);
		int quote = pq.calculateQuote();
		parkingRequestVector.add(new Integer(quote));
		String URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Parking/ParkingQuote.jsp?eventSource=null&";
		String query;

		db.insertParkingData(parkingRequestVector);
		ResultSet rs = db.submitQuery("SELECT uniqueID from parkingRequests WHERE pageSubmitted = '" + (String)parkingRequestVector.get(13)
				+ "' AND contactFirstName = '" + (String)parkingRequestVector.get(3) + "'");
		try {
			while (rs.next()) {
				uniqueID = rs.getInt("uniqueID");
				URL += "uniqueID=" + uniqueID;
				System.out.println("DEBUG: THServlet\n Here's the uniqueID: " + uniqueID);
			}
		}
		catch (Exception e) {}

		// add the quoteID to the entry in the parkingRequestTable.  quoteID = "parking" + original quoteID, so if this
		// is a modification enter the quoteID of the original, not the newest insertion uniqueID
		System.out.println("DEBUG: THServlet:processParkingRequest\n\t Is this a Modification? " + quoteModification);
		System.out.println("DEBUG: THServlet:processParkingRequest\n\t Here's the modificationID " + modificationID);
		if (quoteModification.equals("yes")){
			db.submitInsertQuery("UPDATE parkingRequests SET quoteID = '" + request.getParameter("quoteID") + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					request.getParameter("quoteID")));
		} // end if quoteModification
		else {
			db.submitInsertQuery("UPDATE parkingRequests SET quoteID = '" + requestType + uniqueID + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("parkingForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					"parking" + uniqueID));
		}
		String passOffURL = "/webForms/Parking/ParkingQuote.jsp?eventSource=null&uniqueID=" + uniqueID;
		passOff(request, response, passOffURL);
	} // end processParkingRequest
*/
	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processRentalRequest()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		pull out each form variable from the rental request and process accordingly
	 * Input:		HttpServletRequest, String, int, PrintWriter
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void processRentalRequest(HttpServletRequest request, HttpServletResponse response) {
		Vector rentalRequestVector = new Vector();
		String quoteAmount = null;

		rentalRequestVector.add(request.getParameter("eventTitle")); 	//0
		rentalRequestVector.add(request.getParameter("eventLocation"));
		rentalRequestVector.add(request.getParameter("rentalType"));
		rentalRequestVector.add(request.getParameter("singleMonth"));
		rentalRequestVector.add(request.getParameter("singleDay"));
		rentalRequestVector.add(request.getParameter("singleYear"));	//5
		rentalRequestVector.add(request.getParameter("multStartMonth"));
		rentalRequestVector.add(request.getParameter("multStartDay"));
		rentalRequestVector.add(request.getParameter("multStartYear"));
		rentalRequestVector.add(request.getParameter("multEndMonth"));
		rentalRequestVector.add(request.getParameter("multEndDay"));	//10
		rentalRequestVector.add(request.getParameter("multEndYear"));
		rentalRequestVector.add(request.getParameter("numberOfDays"));
		rentalRequestVector.add(request.getParameter("setupComplete"));
		rentalRequestVector.add(request.getParameter("breakdownStart"));
		rentalRequestVector.add(request.getParameter("contactFirstName"));	//15
		rentalRequestVector.add(request.getParameter("contactLastName"));
		rentalRequestVector.add(request.getParameter("contactEmail"));
		rentalRequestVector.add(request.getParameter("rental1"));
		rentalRequestVector.add(request.getParameter("rental2"));
		rentalRequestVector.add(request.getParameter("rental3"));	//20
		rentalRequestVector.add(request.getParameter("tent"));		//21
		rentalRequestVector.add(request.getParameter("tentSize"));
		rentalRequestVector.add(request.getParameter("tentType"));
		rentalRequestVector.add(request.getParameter("tentQuantity"));
		rentalRequestVector.add(request.getParameter("chairs"));		//25
		rentalRequestVector.add(request.getParameter("chairQuantity"));
		rentalRequestVector.add(request.getParameter("chairType"));
		rentalRequestVector.add(request.getParameter("chairColor"));
		rentalRequestVector.add(request.getParameter("staging"));
		rentalRequestVector.add(request.getParameter("stagingSize"));	//30
		rentalRequestVector.add(request.getParameter("stagingQuantity"));
		rentalRequestVector.add(request.getParameter("cocktailTables"));
		rentalRequestVector.add(request.getParameter("cocktailTableSize"));
		rentalRequestVector.add(request.getParameter("cocktailTableQuantity"));
		rentalRequestVector.add(request.getParameter("pipeDrape"));		//35
		rentalRequestVector.add(request.getParameter("pipeDrapeColor"));
		rentalRequestVector.add(request.getParameter("pipeDrapeLength"));
		rentalRequestVector.add(request.getParameter("pipeDrapeQuantity"));
		rentalRequestVector.add(request.getParameter("banquetTables"));
		rentalRequestVector.add(request.getParameter("banquetTableLength"));	//40
		rentalRequestVector.add(request.getParameter("banquetTableQuantity"));
		rentalRequestVector.add(request.getParameter("roundTables"));
		rentalRequestVector.add(request.getParameter("roundTableSize"));
		rentalRequestVector.add(request.getParameter("roundTableQuantity"));
		rentalRequestVector.add(request.getParameter("privacyScreens"));	//45
		rentalRequestVector.add(request.getParameter("privacyScreensQuantity"));
		rentalRequestVector.add(request.getParameter("coatRack"));	//47
		rentalRequestVector.add(request.getParameter("coatRackQuantity"));
		rentalRequestVector.add(request.getParameter("pageLoad"));	//49
		rentalRequestVector.add(request.getParameter("pageSubmit"));	//50


		RentalQuote rq = new RentalQuote(rentalRequestVector);
		int[] quote = rq.calculateQuote();
		for (int i=0; i<quote.length; i++) {
			rentalRequestVector.add(new Integer(quote[i]));
		}
		String rental1 = (String)request.getParameter("rental1");
		String rental2 = (String)request.getParameter("rental2");
		String rental3 = (String)request.getParameter("rental3");
		//String URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Rental/";
		String URL = bURL + "/myapp/webForms/Rental/";
		String passOffURL = "/webForms/VendorRequestComplete.jsp";
		String query;

		// make sure either the mult dates are blank or the single date depending on the value of numberOfDays
		if (request.getParameter("rentalType").equals("singleDay")){
			for (int i=6; i<=12; i++) {
				rentalRequestVector.set(i, "");
			}
		}
		else {
			for (int i=3; i<=5; i++) {
				rentalRequestVector.set(i, "");
			}
		}
		
        //Replacing all "quantity" values with null in case they are empty
		//Postgres will not take in blank values
		for(int i=0;i<rentalRequestVector.size();i++)
		{
			Object elem = rentalRequestVector.get(i);
			if(elem == null)
				rentalRequestVector.set(i, "null");
			else
			{
				try
				{
					if(elem.toString().length() == 0)
						rentalRequestVector.set(i, "null");
				}
				catch(ClassCastException cce)
				{
					//Ignore
				}
			}
		}

		db.insertRentalData(rentalRequestVector);
		ResultSet rs = db.submitQuery("SELECT uniqueID from rentalRequests WHERE pageSubmitted = '" + (String)rentalRequestVector.get(50)
				+ "' AND contactFirstName = '" + (String)rentalRequestVector.get(15) + "'");
		try {
			while (rs.next()) {
				uniqueID = rs.getInt("uniqueID");
			}
		}
		catch (Exception e) {}

		quoteID = request.getParameter("quoteID");
		if (quoteID==null)
		    quoteID = "" + uniqueID;
		else
		    quoteID = quoteID.substring(7);


		// add the quoteID to the entry in the rentalRequestTable.  quoteID = "rental" + original quoteID, so if this
		// is a modification enter the quoteID of the original, not the newest insertion uniqueID
		if (quoteModification.equals("yes")){
			db.submitInsertQuery("UPDATE rentalRequests SET quoteID = '" + request.getParameter("quoteID") + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("RentalForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					request.getParameter("quoteID")));
		} // end if quoteModification
		else {
			db.submitInsertQuery("UPDATE rentalRequests SET quoteID = '" + requestType + uniqueID + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("RentalForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					"rental" + uniqueID));
		}

		//look at rental service variables and see which ones they want quote from, apppend links as necessary
		if (rental1 != null){
			quoteAmount = "Quoted price: $" + quote[0] + "\n\n";
			URL += "SpeedyQuote.jsp?eventSource=RentalForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(rentalRequestVector, "rental1", quoteAmount + URL);
		}
		if (rental2 != null){
			quoteAmount = "Quoted price: $" + quote[1] + "\n\n";
			//URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Rental/";
			URL = bURL + "/myapp/webForms/Rental/";
			URL += "RentFromUsQuote.jsp?eventSource=RentalForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(rentalRequestVector, "rental2", quoteAmount + URL);
		}
		if (rental3 != null){
			quoteAmount = "Quoted price: $" + quote[2] + "\n\n";
			//URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Rental/";
			URL = bURL + "/myapp/webForms/Rental/";
			URL += "ClassicQuote.jsp?eventSource=RentalForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(rentalRequestVector, "rental3", quoteAmount + URL);
		}
		if (quoteModification.equals("yes")&&(rental1 != null))
			passOff(request, response, "/webForms/Rental/SpeedyModifySubmitted.jsp");
		if (quoteModification.equals("yes")&&(rental2 != null))
			passOff(request, response, "/webForms/Rental/RentFromUsModifySubmitted.jsp");
		if (quoteModification.equals("yes")&&(rental3 != null))
			passOff(request, response, "/webForms/Rental/ClassicModifySubmitted.jsp");
		else
			passOff(request, response, passOffURL);
	} // end processRentalRequest


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processTowncarRequest()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		pull out each form variable from the towncar request and process accordingly
	 * Input:		HttpServletRequest, String, int, PrintWriter
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
/*	public void processTowncarRequest(HttpServletRequest request, HttpServletResponse response,
								int printFlag, PrintWriter out) {
		Vector towncarRequestVector = new Vector();
		int temp = 0;
		String quoteAmount;

		towncarRequestVector.add(request.getParameter("eventTitle"));  //0
		towncarRequestVector.add(request.getParameter("eventLocation"));
		towncarRequestVector.add(request.getParameter("eventDate"));
		towncarRequestVector.add(request.getParameter("contactFirstName"));
		towncarRequestVector.add(request.getParameter("contactLastName"));
		towncarRequestVector.add(request.getParameter("contactPhone")); //5
		towncarRequestVector.add(request.getParameter("contactEmail"));
		towncarRequestVector.add(request.getParameter("towncarService1"));
		towncarRequestVector.add(request.getParameter("towncarService2"));
		towncarRequestVector.add(request.getParameter("towncarService3"));
		towncarRequestVector.add(request.getParameter("passengerFirstName")); //10
		towncarRequestVector.add(request.getParameter("passengerLastName"));
		towncarRequestVector.add(request.getParameter("pickupStreet"));
		towncarRequestVector.add(request.getParameter("pickupCity"));
		towncarRequestVector.add(request.getParameter("pickupState"));
		towncarRequestVector.add(request.getParameter("pickupPhone")); //15
		towncarRequestVector.add(request.getParameter("dropoffStreet"));
		towncarRequestVector.add(request.getParameter("dropoffCity"));
		towncarRequestVector.add(request.getParameter("dropoffState"));
		towncarRequestVector.add(request.getParameter("dropoffPhone"));
		towncarRequestVector.add(request.getParameter("pickupTime")); //20
		towncarRequestVector.add(request.getParameter("arrivalTime"));
		towncarRequestVector.add(request.getParameter("airportPickup"));
		towncarRequestVector.add(request.getParameter("airline"));
		towncarRequestVector.add(request.getParameter("flightNumber"));
		towncarRequestVector.add(request.getParameter("flightArrivalTime")); //25
		towncarRequestVector.add(request.getParameter("flightDepartureCity"));
		towncarRequestVector.add(request.getParameter("pageLoad"));
		towncarRequestVector.add(request.getParameter("pageSubmit")); //28

		TowncarQuote tq = new TowncarQuote(towncarRequestVector);
		int[] quote = tq.calculateQuote();
		for (int i=0; i<quote.length; i++) {
			towncarRequestVector.add(new Integer(quote[i]));
		}
		String towncarService1 = (String)request.getParameter("towncarService1");
		String towncarService2 = (String)request.getParameter("towncarService2");
		String towncarService3 = (String)request.getParameter("towncarService3");
		String URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Towncar/";
		String passOffURL = "/webForms/VendorRequestComplete.jsp";
		String query;

		db.insertTowncarData(towncarRequestVector);
		ResultSet rs = db.submitQuery("SELECT uniqueID from towncarRequests WHERE pageSubmitted = '" + (String)towncarRequestVector.get(28)
				+ "' AND contactFirstName = '" + (String)towncarRequestVector.get(3) + "'");
		try {
			while (rs.next()) {
				uniqueID = rs.getInt("uniqueID");
				System.out.println("DEBUG: THServlet\n Here's the uniqueID: " + uniqueID);
			}
		}
		catch (Exception e) {}
		//db.submitInsertQuery(db.setupLogUpdate("towncarForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
			//			"towncar" + uniqueID));

		// add the quoteID to the entry in the towncarRequestTable.  quoteID = "towncar" + original quoteID, so if this
		// is a modification enter the quoteID of the original, not the newest insertion uniqueID
		System.out.println("DEBUG: THServlet:processTowncarRequest\n\t Is this a Modification? " + quoteModification);
		System.out.println("DEBUG: THServlet:processTowncarRequest\n\t Here's the modificationID " + modificationID);
		if (quoteModification.equals("yes")){
			System.out.println("DEBUG: THServlet:processTowncarRequest\n\t inserting a modification id");
			db.submitInsertQuery("UPDATE towncarRequests SET quoteID = '" + request.getParameter("quoteID") + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("towncarForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					request.getParameter("quoteID")));
		} // end if quoteModification
		else {
			System.out.println("DEBUG: THServlet:processTowncarRequest\n\t inserting an original uniqueID");
			db.submitInsertQuery("UPDATE towncarRequests SET quoteID = '" + requestType + uniqueID + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("towncarForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					"towncar" + uniqueID));
		}

		//look at towncar service variables and see which ones they want quote from, apppend links as necessary
		if (towncarService1 != null){
			quoteAmount = "Quoted price: $" + quote[0] + "\n\n";
			URL += "A1LimoQuote.jsp?eventSource=towncarForm.htm&uniqueID=" + uniqueID;
			System.out.println("DEBUG: THServlet:processTowncarRequest\n\t Here's the appended URL (1): " + URL);
			setupReplyMessage(towncarRequestVector, "towncar1", quoteAmount + URL);
		}
		if (towncarService2 != null){
			quoteAmount = "Quoted price: $" + quote[1] + "\n\n";
			URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Towncar/";
			URL += "ApexQuote.jsp?eventSource=towncarForm.htm&uniqueID=" + uniqueID;
			System.out.println("DEBUG: THServlet:processTowncarRequest\n\t Here's the appended URL (2): " + URL);
			setupReplyMessage(towncarRequestVector, "towncar2", quoteAmount + URL);
		}
		if (towncarService3 != null){
			quoteAmount = "Quoted price: $" + quote[2] + "\n\n";
			URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Towncar/";
			URL += "PremierQuote.jsp?eventSource=towncarForm.htm&uniqueID=" + uniqueID;
			System.out.println("DEBUG: THServlet:processTowncarRequest\n\t Here's the appended URL (3): " + URL);
			setupReplyMessage(towncarRequestVector, "towncar3", quoteAmount + URL);
		}
		if (quoteModification.equals("yes")&&(towncarService1 != null))
			passOff(request, response, "/webForms/Towncar/A1ModifySubmitted.jsp");
		if (quoteModification.equals("yes")&&(towncarService2 != null))
			passOff(request, response, "/webForms/Towncar/ApexModifySubmitted.jsp");
		if (quoteModification.equals("yes")&&(towncarService3 != null))
			passOff(request, response, "/webForms/Towncar/PremierModifySubmitted.jsp");
		else
			passOff(request, response, passOffURL);
	} // end processTowncarRequest

*/
	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processSecurityRequest()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		pull out each form variable from the security request and process accordingly
	 * Input:		HttpServletRequest, String, int, PrintWriter
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void processSecurityRequest(HttpServletRequest request, HttpServletResponse response) {
		Vector securityRequestVector = new Vector();
		int temp = 0;

		securityRequestVector.add(request.getParameter("eventTitle"));	//0
		securityRequestVector.add(request.getParameter("eventLocation"));
		securityRequestVector.add(request.getParameter("eventMonth"));
		securityRequestVector.add(request.getParameter("eventDayOfMonth"));
		securityRequestVector.add(request.getParameter("eventYear"));
		securityRequestVector.add(request.getParameter("contactFirstName"));	//5
		securityRequestVector.add(request.getParameter("contactLastName"));
		securityRequestVector.add(request.getParameter("contactEmail"));
		securityRequestVector.add(request.getParameter("crowdControl"));
		securityRequestVector.add(request.getParameter("trafficControl"));
		securityRequestVector.add(request.getParameter("parkingAssistance"));	//10
		securityRequestVector.add(request.getParameter("vip"));
		securityRequestVector.add(request.getParameter("alcohol"));
		securityRequestVector.add(request.getParameter("numberSecurityStaff"));
		securityRequestVector.add(request.getParameter("securityClothing"));
		securityRequestVector.add(request.getParameter("startTime"));		//15
		securityRequestVector.add(request.getParameter("endTime"));
		securityRequestVector.add(request.getParameter("location"));
		securityRequestVector.add(request.getParameter("funcServeAlcohol"));
		securityRequestVector.add(request.getParameter("funcGuardValuables"));
		securityRequestVector.add(request.getParameter("funcMaintainPerimeter")); //20
		securityRequestVector.add(request.getParameter("funcMonitorTraffic"));
		securityRequestVector.add(request.getParameter("funcOpenGarage"));
		securityRequestVector.add(request.getParameter("funcMaintainPresence"));
		securityRequestVector.add(request.getParameter("pageLoad"));	//24
		securityRequestVector.add(request.getParameter("pageSubmit"));	//25

		SecurityQuote sq = new SecurityQuote(securityRequestVector);
		int quote = sq.calculateQuote();
		securityRequestVector.add(new Integer(quote));
		//String URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Security/SecurityQuote.jsp?eventSource=null&";
		String URL = bURL + "/myapp/webForms/Security/SecurityQuote.jsp?eventSource=null&";
		String query;

		db.insertSecurityData(securityRequestVector);
		ResultSet rs = db.submitQuery("SELECT uniqueID from securityRequests WHERE pageSubmitted = '" + (String)securityRequestVector.get(25)
				+ "' AND contactFirstName = '" + (String)securityRequestVector.get(5) + "'");
		try {
			while (rs.next()) {
				uniqueID = rs.getInt("uniqueID");
				URL += "uniqueID=" + uniqueID;
			}
		}
		catch (Exception e) {}

		quoteID = request.getParameter("quoteID");
		if (quoteID==null)
		    quoteID = "" + uniqueID;
		else
		    quoteID = quoteID.substring(8);


		// add the quoteID to the entry in the securityRequestTable.  quoteID = "security" + original quoteID, so if this
		// is a modification enter the quoteID of the original, not the newest insertion uniqueID
		if (quoteModification.equals("yes")){
			db.submitInsertQuery("UPDATE securityRequests SET quoteID = '" + request.getParameter("quoteID") + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate(request.getParameter("eventSource"), request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					request.getParameter("quoteID")));
		} // end if quoteModification
		else {
			db.submitInsertQuery("UPDATE securityRequests SET quoteID = '" + requestType + uniqueID + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("securityForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					"security" + uniqueID));
		}
		String passOffURL = "/webForms/Security/SecurityQuote.jsp?eventSource=null&uniqueID=" + uniqueID;
		passOff(request, response, passOffURL);

	} // end processSecurityRequest

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processFloralRequest()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		pull out each form variable from quote requests for floral requests and process accordingly
	 * Input:		HttpServletRequest, String, int, PrintWriter
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void processFloralRequest(HttpServletRequest request, HttpServletResponse response) {
	// -- DEBUG --
		Vector floralRequestVector = new Vector();
		String quoteAmount = null;
		floralRequestVector.add(request.getParameter("contactFirstName"));	//0
		floralRequestVector.add(request.getParameter("contactLastName"));
		floralRequestVector.add(request.getParameter("contactEmail"));
		floralRequestVector.add(request.getParameter("eventTitle"));
		floralRequestVector.add(request.getParameter("eventLocation"));		//4
		floralRequestVector.add(request.getParameter("eventMonth"));			//5
		floralRequestVector.add(request.getParameter("eventDayOfMonth"));
		floralRequestVector.add(request.getParameter("eventYear"));
		floralRequestVector.add(request.getParameter("setupComplete"));
		floralRequestVector.add(request.getParameter("breakdownStart"));
		floralRequestVector.add(request.getParameter("item1"));				//10
		floralRequestVector.add(request.getParameter("quantItem1"));		//11
		floralRequestVector.add(request.getParameter("sizeItem1"));			//12
		floralRequestVector.add(request.getParameter("flowerTypeItem1"));
		floralRequestVector.add(request.getParameter("item2"));
		floralRequestVector.add(request.getParameter("quantItem2"));		//15
		floralRequestVector.add(request.getParameter("sizeItem2"));
		floralRequestVector.add(request.getParameter("flowerTypeItem2"));
		floralRequestVector.add(request.getParameter("item3"));
		floralRequestVector.add(request.getParameter("quantItem3"));
		floralRequestVector.add(request.getParameter("sizeItem3"));			//20
		floralRequestVector.add(request.getParameter("flowerTypeItem3"));
		floralRequestVector.add(request.getParameter("item4"));
		floralRequestVector.add(request.getParameter("quantItem4"));
		floralRequestVector.add(request.getParameter("sizeItem4"));
		floralRequestVector.add(request.getParameter("flowerTypeItem4"));	//25
		floralRequestVector.add(request.getParameter("userComments"));
		floralRequestVector.add(request.getParameter("pageLoad"));			//27
		floralRequestVector.add(request.getParameter("pageSubmit"));		//28
		String vendorID = request.getParameter("vendorID");
		floralRequestVector.add(vendorID);

		FloralQuote fq = new FloralQuote(floralRequestVector);
		int quote = fq.calculateQuote();
		floralRequestVector.add(new Integer(quote));

		//String URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Floral/";
		String URL = bURL + "/myapp/webForms/Floral/";
		String passOffURL = "/webForms/FloralRequestComplete.htm";
		String query;

		db.insertFloralData(floralRequestVector);
		ResultSet rs = db.submitQuery("SELECT uniqueID from floralRequests WHERE pageSubmit = '" + (String)floralRequestVector.get(28)
				+ "' AND contactFirstName = '" + (String)floralRequestVector.get(0) + "'");
		try {
			while (rs.next()) {
				uniqueID = rs.getInt("uniqueID");
			}
		}
		catch (Exception e) {}

		quoteID = request.getParameter("quoteID");
		if (quoteID==null)
		    quoteID = "" + uniqueID;
		else
		    quoteID = quoteID.substring(6);


		// add the quoteID to the entry in the floralRequestTable.  quoteID = "floral" + original quoteID, so if this
		// is a modification enter the quoteID of the original, not the newest insertion uniqueID
		if (quoteModification.equals("yes")){
			db.submitInsertQuery("UPDATE floralRequests SET quoteID = '" + request.getParameter("quoteID") + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("FloralForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					request.getParameter("quoteID")));
		} // end if quoteModification
		else {
			db.submitInsertQuery("UPDATE floralRequests SET quoteID = '" + requestType + uniqueID + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("FloralForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					"floral" + uniqueID));
		}

		if (vendorID.equals("floral1")){
			quoteAmount = "Quoted price: $" + quote + "\n\n";
			URL += "AdamsQuote.jsp?eventSource=FloralForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(floralRequestVector, "floral1", quoteAmount + URL);
		}
		if (vendorID.equals("floral2")){
			quoteAmount = "Quoted price: $" + quote + "\n\n";
			URL += "CanalQuote.jsp?eventSource=FloralForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(floralRequestVector, "floral2", quoteAmount + URL);
		}
		if (vendorID.equals("floral3")){
			quoteAmount = "Quoted price: $" + quote + "\n\n";
			URL += "LilliQuote.jsp?eventSource=FloralForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(floralRequestVector, "floral3", quoteAmount + URL);
		}
		if ((quoteModification.equals("yes"))&&(vendorID.equals("floral1")))
			passOff(request, response, "/webForms/Floral/AdamsModifySubmitted.jsp");
		if ((quoteModification.equals("yes"))&&(vendorID.equals("floral2")))
			passOff(request, response, "/webForms/Floral/CanalModifySubmitted.jsp");
		if ((quoteModification.equals("yes"))&&(vendorID.equals("floral3")))
			passOff(request, response, "/webForms/Floral/LilliModifySubmitted.jsp");
		else
			passOff(request, response, passOffURL);

	} // end processAdamsFloralRequest

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void processCateringRequest()																	   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		pull out each form variable from quote requests for Canal and process accordingly
	 * 				If printFlag == 1 then data will print to screen, otherwise data is submitted to DB,
	 * 				submission thank you message is sent to screen
	 * Input:		HttpServletRequest, String, int, PrintWriter
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void processCateringRequest(HttpServletRequest request, HttpServletResponse response) {
	// -- DEBUG --
		Vector cateringRequestVector = new Vector();
		String quoteAmount = null;
		cateringRequestVector.add(request.getParameter("contactFirstName"));	//0
		cateringRequestVector.add(request.getParameter("contactLastName"));
		cateringRequestVector.add(request.getParameter("contactEmail"));
		cateringRequestVector.add(request.getParameter("eventTitle"));
		cateringRequestVector.add(request.getParameter("eventLocation"));
		cateringRequestVector.add(request.getParameter("eventMonth"));			//5
		cateringRequestVector.add(request.getParameter("eventDayOfMonth"));
		cateringRequestVector.add(request.getParameter("eventYear"));
		cateringRequestVector.add(request.getParameter("setupComplete"));
		cateringRequestVector.add(request.getParameter("breakdownStart"));
		cateringRequestVector.add(request.getParameter("catering1"));			//10
		cateringRequestVector.add(request.getParameter("catering2"));
		cateringRequestVector.add(request.getParameter("catering3"));
		cateringRequestVector.add(request.getParameter("quantMeals"));			//13
		cateringRequestVector.add(request.getParameter("selection"));			//14
		cateringRequestVector.add(request.getParameter("vegan"));				//15
		cateringRequestVector.add(request.getParameter("quantVegan"));
		cateringRequestVector.add(request.getParameter("vegetarian"));
		cateringRequestVector.add(request.getParameter("quantVegetarian"));
		cateringRequestVector.add(request.getParameter("atkins"));
		cateringRequestVector.add(request.getParameter("quantAtkins"));			//20
		cateringRequestVector.add(request.getParameter("kosher"));
		cateringRequestVector.add(request.getParameter("quantKosher"));
		cateringRequestVector.add(request.getParameter("pageLoad"));			//23
		cateringRequestVector.add(request.getParameter("pageSubmit"));			//24

		CateringQuote rq = new CateringQuote(cateringRequestVector);
		int[] quote = rq.calculateQuote();
		for (int i=0; i<quote.length; i++) {
			cateringRequestVector.add(new Integer(quote[i]));
		}
		String catering1 = (String)request.getParameter("catering1");
		String catering2 = (String)request.getParameter("catering2");
		String catering3 = (String)request.getParameter("catering3");
		//String URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Catering/";
		String URL = bURL + "/myapp/webForms/Catering/";
		String passOffURL = "/webForms/VendorRequestComplete.jsp";
		String query;

		db.insertCateringData(cateringRequestVector);
		ResultSet rs = db.submitQuery("SELECT uniqueID from cateringRequests WHERE pageSubmit = '" + (String)cateringRequestVector.get(24)
				+ "' AND contactFirstName = '" + (String)cateringRequestVector.get(0) + "'");
		try {
			while (rs.next()) {
				uniqueID = rs.getInt("uniqueID");
			}
		}
		catch (Exception e) {}

		quoteID = request.getParameter("quoteID");
		if (quoteID==null)
		    quoteID = "" + uniqueID;
		else
		    quoteID = quoteID.substring(8);


		// add the quoteID to the entry in the cateringRequestTable.  quoteID = "catering" + original quoteID, so if this
		// is a modification enter the quoteID of the original, not the newest insertion uniqueID
		if (quoteModification.equals("yes")){
			db.submitInsertQuery("UPDATE cateringRequests SET quoteID = '" + request.getParameter("quoteID") + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("CateringForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					request.getParameter("quoteID")));
		} // end if quoteModification
		else {
			db.submitInsertQuery("UPDATE cateringRequests SET quoteID = '" + requestType + uniqueID + "' WHERE uniqueID=" + uniqueID);
			db.submitInsertQuery(db.setupLogUpdate("CateringForm.htm", request.getParameter("pageLoad"), request.getParameter("pageSubmit"),
					"catering" + uniqueID));
		}

		//look at catering service variables and see which ones they want quote from, apppend links as necessary
		if (catering1 != null){
			quoteAmount = "Quoted price: $" + quote[0] + "\n\n";
			URL += "MaximalQuote.jsp?eventSource=CateringForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(cateringRequestVector, "catering1", quoteAmount + URL);
		}
		if (catering2 != null){
			quoteAmount = "Quoted price: $" + quote[1] + "\n\n";
			//URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Catering/";
			URL = bURL + "/myapp/webForms/Catering/";
			URL += "PghQuote.jsp?eventSource=CateringForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(cateringRequestVector, "catering2", quoteAmount + URL);
		}
		if (catering3 != null){
			quoteAmount = "Quoted price: $" + quote[2] + "\n\n";
			//URL = "http://usl5.hcii.cs.cmu.edu:8080/myapp/webForms/Catering/";
			URL = bURL + "/myapp/webForms/Catering/";
			URL += "BBreakQuote.jsp?eventSource=CateringForm.htm&uniqueID=" + uniqueID;
			setupReplyMessage(cateringRequestVector, "catering3", quoteAmount + URL);
		}
		if (quoteModification.equals("yes")&&(catering1 != null))
			passOff(request, response, "/webForms/Catering/MaximalModifySubmitted.jsp");
		if (quoteModification.equals("yes")&&(catering2 != null))
			passOff(request, response, "/webForms/Catering/PghModifySubmitted.jsp");
		if (quoteModification.equals("yes")&&(catering3 != null))
			passOff(request, response, "/webForms/Catering/BBreakModifySubmitted.jsp");
		else
			passOff(request, response, passOffURL);
	} // end processCateringRequest

    /**
     * add properties from a file to the set of System properties
     * @param ret Properties to which will be added the contents of the file specified
     * @param filename the file which contains the properties to be added to the System
     */
    // here's where we'd make radar.properties load from c:/radar/run
    // (for tomcat, e.g.)
    private void addProps(Properties ret, String filename) {
    	String home = System.getProperty("user.home");
    	logger.debug("user.home is '" + home + "'");
    	InputStream is;
    	if (null != home) {
    		File f = new File(home + File.separator + filename);
    		if (f.exists()) {
    			logger.debug("reading " + f + " first");
    			try {
    				is = new FileInputStream(f);
    				ret.load(is);
    			} catch (Exception e) {
    			logger.error(f + ": " + e);
    		}
	    } else
	    	logger.debug(f + ": is not a file");
    	}
    	File f = new File(filename);
    	if (f.exists()) {
    		logger.debug("now reading " + f);
    		try {
    			is = new FileInputStream(f);
    			ret.load(is);
    		} catch (Exception e) {
    			logger.error(filename + ": " + e);
    		}
    	} else
    		logger.debug(f + ": doesn't exist, moving on");
    }
	
	// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end TestHarnessServlet.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
