package edu.cmu.radar.vendor;
/*************************************************************************************************************
 *				 			T  E  S  T  H  A  R  N  E  S  S  T  I  M  E  R  .  J  A  V  A  		  		     *
 *************************************************************************************************************
 * Purpose: 	This Java program implements a simple timer.  This is used by the TestHarness to determine
 * 				elapsed time of the session.  Every second the DB is queried to determine if any messages
 * 				need to be sent to the participant.  If not, timer sleeps for 1 second and repeats process.
 * Input:		Currently mailServer and recipientAddress are coming in through command line args.
 * Output:
 * Dependencies:
 * Author: 		Kyle A Cunningham <kcunning@cs.cmu.edu>
 ************************************************************************************************************/
import java.util.Vector;

public class TestHarnessTimer implements Runnable {
	DatabaseConnectivity db;
	sendEmail pushEmail;
	int minutes = 0, seconds = 0;
	String mailServer, recipient;

	// Constructor !
	public TestHarnessTimer(String args[]) {
	        mailServer = "vio.isri.cmu.edu";
	        //mailServer = "design.radar.cs.cmu.edu";
		//mailServer = "ux14.sp.cs.cmu.edu";
		Thread t = new Thread(this);
		db = new DatabaseConnectivity();
		pushEmail = new sendEmail();
		t.start();
	} // end Constructor


	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void run()					         													   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		run implements what we want our thread to accomlish - thread sleeps for 1 second, wakes up
	 * 				and increments # of seconds, adjusts # of minutes accordingly.  Then setupQuery is called
	 * 				with number of mins, secs and query is submitted.
	 * Input:		none
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void run()  {
		while (true){
			try {
				Thread.sleep(1000);
				seconds++;
				if (seconds == 60) {
					minutes++;
					seconds = 0;
				}
				String timeQuery = db.setupQuery(minutes, seconds, "update");
				String query = db.setupQuery(minutes, seconds, "select");
				Vector v = db.submitQuery(query, 2);
				db.submitQuery(timeQuery, 3);
				sendEmailMessage(v);
			}
			catch (InterruptedException ie) {}
		} // end while
	} // end run

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public void sendEmailMessage			         													   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		called by run to check the return vector provided by the call of setupQuery.
	 * 				If the vector is empty then nothing happens, otherwise data is pulled out of the vector
	 * 				and email is sent to the recipient.
	 *  *** NOTE *** When ux14.sp is used as mail server there is a lag when second email send is attempted.
	 * 				using design.radar seems to get rid of this problem
	 * Input:		Vector <returned by submitQuery>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public void sendEmailMessage(Vector v) {
		if (!v.isEmpty()) {
			//String recipient = "testaccount@design.radar.cs.cmu.edu";
			//String mailServer = "design.radar.cs.cmu.edu";
			//pushEmail.sendMail(mailServer, (String)v.get(0), (String)v.get(1), (String)v.get(2), (String)v.get(0), (String)v.get(3));
		}
	} // end sendEmailMessages()


	public static void main(String[] args){
		TestHarnessTimer t = new TestHarnessTimer(args);
	} // end main()

//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end TestHarnessTimer.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
