/**
 * 
 */
package edu.cmu.radar.vendor;

import java.util.Formatter;
import java.util.regex.Pattern;

/**
 * @author Jialiang
 * 
 * The time format class
 */
public class TimeFormat {
	/**
	 * the time expression pattern
	 */
	public final static String expr = "\\d{1,2}:\\d{2}";

	public final static Pattern pattern = Pattern.compile(expr);

	/**
	 * formats the 24 hour based time to 12 hour based time
	 */
	public static String format(String time) {
		if (time == null || time.length() == 0) {
			return "";
		}

		if (pattern.matcher(time).matches()) {
			StringBuilder builder = new StringBuilder(time.length() + 2);

			// the index of colon
			int index = time.indexOf(":");
			String hourStr = time.substring(0, index);

			// convert 24-hours based time to 12-hours based time
			int hour = Integer.parseInt(hourStr);
			String suffix;
			if (hour >= 12) {
				suffix = "pm";
				if (hour > 12) {
					hour -= 12;
				}
			} else {
				suffix = "am";
			}

                        //TODO: check this converts 00:xx/24:x times appropriately?

			if (hour < 10) {
				hourStr = "0" + hour;
			}
			builder.append(hourStr).append(":").append(
					time.substring(index + 1)).append(suffix);
			return builder.toString();
		} else {
			return time;
		}
	}

	/**
	 * @return the time_options
	 */
	public static String getTimeOptions(String startTime, String endTime,
			boolean preSelected) {
		if (startTime == null || endTime == null) {
			return null;
		}

		if (!pattern.matcher(startTime).matches()
				|| !pattern.matcher(endTime).matches()) {
			throw new IllegalArgumentException(
					"The param of startTime and endTime should be in the form of HH:mm.");
		}

		int startHour = parseHour(startTime);
		int endHour = parseHour(endTime);
		System.out.println(startHour + ": " + endHour);

		String timeOptions;
		StringBuilder buf = new StringBuilder();
		if (preSelected) {
			buf.append("<option value=\"\">---------------</option>\n");
		} else {
			buf.append("<option value=\"\">Please make a selection</option>\n");
		}
		Formatter fmt = new Formatter(buf);

		for (int i = startHour; i <= endHour; i++) {
			int hour = i / 2;
			StringBuilder timeBuf = new StringBuilder(10);
			if (hour < 10) {
				timeBuf.append("0");
			}
			timeBuf.append(hour).append(":");
			if (i % 2 == 0) {
				timeBuf.append("00");
			} else {
				timeBuf.append("30");
			}
			String time = timeBuf.toString();
			String fmtTime = format(time);

			fmt.format("<option value=\"%s\">%s</option>\n", time, fmtTime);
		}
		timeOptions = buf.toString();

		return timeOptions;
	}

	/**
	 * gets the hour number e.g. 08:00 gets 16 and 08:30 gets 17
	 */
	private static int parseHour(String time) {
		int index = time.indexOf(":");
		int hour = Integer.parseInt(time.substring(0, index));
		hour *= 2;

		if (time.endsWith("30")) {
			hour++;
		}

		return hour;
	}
}
