/*
 *               __TO_DO__
 *
 *  add a conn.rollback() to the catch(){} block of the core constructor, so we dont get partially TimeWarp'd databases?
 *  open up the String[] args in main or the constructor it calls into 2/3 String variables?
 *  find a prettier way of converting int/name for months and 0/1==jan and 11/12==dec convention in calendar objects?
 *  get DateFormat or SimpleDateFormat (w/ Calendar objects) to read input strings so we can remove deprecated Date constructors?
 *  get 'expected' number of records updated from property file or system property?
 *     - for that matter, get table names from props, too?
 *  also, search for /// for places in the code that could be updated or improved.
 *
 */



package edu.cmu.radar.vendor;

import java.sql.*;
import java.text.*;
import java.io.*;
import java.util.*;
import java.util.Vector;
import java.util.Calendar;
import java.util.Date;
import java.util.ResourceBundle;
import org.apache.log4j.Logger;

// It's astounding.
// Time is fleeting.
// Madness takes its toll.
// But listen closely.
// Not for very much longer.
// I've got to keep control.
//
// I remember doing the timewarp
// Drinking those moments when
// The blackness would hit me
// and the void would be calling
// LET'S DO THE
//   public class TimeWarp {
// AGAIN!

/**
 * Used for updating the date-related entries in the 'vendor' database by shifting them in time.
 * @author haff, mlahut
 */
public class TimeWarp {    


    /**
     * log4j logger
     */
    private static Logger logger = Logger.getLogger(TimeWarp.class);



    /**
     * add properties from a file to the set of System properties
     * @param ret Properties to which will be added the contents of the file specified
     * @param filename the file which contains the properties to be added to the System
     */
    // here's where we'd make radar.properties load from c:/radar/run
    // (for tomcat, e.g.)
    private static void addProps(Properties ret, String filename) {
    	String home = System.getProperty("user.home");
    	logger.debug("user.home is '" + home + "'");
    	InputStream is;
    	if (null != home) {
    		File f = new File(home + File.separator + filename);
    		if (f.exists()) {
    			logger.debug("reading " + f + " first");
    			try {
    				is = new FileInputStream(f);
    				ret.load(is);
    			} catch (Exception e) {
    			logger.error(f + ": " + e);
    		}
	    } else
	    	logger.debug(f + ": is not a file");
    	}
    	File f = new File(filename);
    	if (f.exists()) {
    		logger.debug("now reading " + f);
    		try {
    			is = new FileInputStream(f);
    			ret.load(is);
    		} catch (Exception e) {
    			logger.error(filename + ": " + e);
    		}
    	} else
    		logger.debug(f + ": doesn't exist, moving on");
    }


    /**
     * the 'last chance' default for database connection...
     * it can be overridden in 3 ways, highest precidence first:
     * command line, system properties values, vendorDB.properties file
     */
    private static String CONNECT_STRING="jdbc:postgresql://localhost:5432/vendor?user=postgres&password=f22f22";
    

    /**
     * set connect string (database uri) via system properties or if thats not available, a properties file.
     * declared public so one can get the default connect string from outside if using the constructor that allows an external db connection.
     * @return the connection string that has been set, though this is also stored in the class field CONNECT_STRING
     */
    public static String setConnectString() {
    	
    	Properties props = new Properties(System.getProperties());
		addProps(props, "radar.properties");
		addProps(props, "user.properties");
		
	// if possible, get connect string from external properties sources
	String propDriver, propHost, propPort, propDB, propUser, propPass;
	propDriver = props.getProperty("radar.vendor.jdbc.driver");
	propHost = props.getProperty("radar.vendor.jdbc.host");
	propPort = props.getProperty("radar.vendor.jdbc.port");
	propDB = props.getProperty("radar.vendor.jdbc.database");
	propUser = props.getProperty("radar.vendor.jdbc.username");
	propPass = props.getProperty("radar.vendor.jdbc.password");
	if ( propDriver==null || propHost==null || propPort==null || propDB==null || propUser==null || propPass==null ) {
	    ResourceBundle rb = null;
	    try {
	    	rb = ResourceBundle.getBundle("properties/vendorDB");
	    } catch(Exception e) {} // getBundle throws an exception if the properties file doesnt exist
	    if ( rb!=null ) {
		propDriver = rb.getString("radar.vendor.jdbc.driver");
		propHost = rb.getString("radar.vendor.jdbc.host");
		propPort = rb.getString("radar.vendor.jdbc.port");
		propDB = rb.getString("radar.vendor.jdbc.database");
		propUser = rb.getString("radar.vendor.jdbc.username");
		propPass = rb.getString("radar.vendor.jdbc.password");
	    }
	}
	if ( propDriver!=null && propHost!=null && propPort!=null && propDB!=null && propUser!=null && propPass!=null ) {
	    CONNECT_STRING = "" + propDriver + "://" + propHost + ":" + propPort + "/" + propDB + "?user=" + propUser + "&password=" + propPass;
	}
	return CONNECT_STRING;
    }


    /**
     * Process command line strings, including handling of date offset calculation, output of usage information, and construction of the database connection URI.
     * @param args Array of two date Strings and an optional third String specifying a database URI.  The dates should have exactly an integer number of days difference.  Less than two or greater than three arguments shows the usage dialog.
     * @return integer of the number of seconds to be shifted (may be negative).  returns 0 if the inputs were bad, there is no work to do or shift time is not an integer number of days.
     */
    private int processCommandLine(String[] args) {
	setConnectString(); // so the default connect string output below is valid, and in case db URI is _not_ set in the args

	if (args.length<2 || args.length>3) {
	    logger.info("Syntax:    TimeWarp <old_date> <new_date> [connect_string]");
	    logger.info("Example of the dates: \n    TimeWarp 'September 19 2005 00:00:00 GMT' 'May 22 2006 00:00:00 GMT'");
	    logger.info("Or: TimeWarp 'Sep 19 2005' 'May 22 2006'");
	    logger.info("Default connect string if omitted: \n" + CONNECT_STRING);
	    logger.info("The output will show numbers of records updated, with expected numbers of updates for each table.  These expected numbers correspond to the number of records in the initial state of the vendor database.");
	    return 0;
	}
	int timeShift=0;
	Date d1, d2;
	try {
	    d1 = new Date(args[0]);
	    d2 = new Date(args[1]);
	} catch(Exception e) {
	    logger.error("One or more dates specified are invalid.  Please check usage and try again.");
	    return 0;
	}
      	
	/*************************************
	/// NOTE: this section not used in lieu of the above two lines because DateFormat is a bitch and calls lots of input formats 'unparsable'.  Date(String) may be deprecated, but its useful =-o
	Date d1, d2;
	try {
	    SimpleDateFormat sdf = SimpleDateFormat.getDateTimeInstance();
	    sdf.setLenient(true);
	    d1 = sdf.parse(args[0]);
	    d2 = sdf.parse(args[1]);
	} catch (Exception e) {
	    logger.error("One or more dates specified are invalid.  Please check usage and try again.");
	    //if (sdf.getInstance().isLenient()) System.out.println("its set lenient, yo");
	    //logger.error("Error: " + e.toString(), e);
	    return;
	}
	*************************************/

	long increment = d2.getTime() - d1.getTime();
	timeShift = (int)(increment / 1000); // convert to seconds from miliseconds
	if (args.length==3)
	    CONNECT_STRING=args[2];
	if (timeShift==0) {
	    logger.error("No work to do.");
	    return 0;
	}
	//if ((timeShift > -20000) && (timeShift < 20000)) timeShift *= 86400;
	// days in 50+ years, should be sufficient, and still fits in an int
	if (timeShift % 86400 != 0) {
	    logger.error("Please enter an integral number of days.");
	    logger.error("If you really want to shift by a few hours, remove this test from the code, though this may break other things.");
	    logger.error("Attempted: " + (timeShift/86400) + " days, " + ((timeShift%86400)/3600) + " hours, " + ((timeShift%3600)/60) + " mins, " + (timeShift%60) + " secs.");
	    logger.error("If you're specifying a time zone, you must specify the same time zone for both date arguments.");
	    return 0;
	}

	return timeShift;
    }


    /**
     * Convert string representations of months from integers to words.
     * NOTE: Here, 'January'==0 and 'December'==11, to conform with Date and Calendar classes
     * @param month string containing an integer representation of a month (ie, in the interval [1,12])
     * @return the textual representation (the name) of the month
     */
    private static String intToWordMonth(int month) {
	SimpleDateFormat sdf = new SimpleDateFormat("MMMM");
	Calendar cal = Calendar.getInstance();
	cal.setTime(new Date());
	cal.set(Calendar.DAY_OF_MONTH, 1); // just in case we are on a day like 31 that doesnt exist in the target month we are casting to...  mo probs, yo!
	cal.set(Calendar.MONTH, month); // NOTE: this method complies with Calendar object convention that jan=0, dec=11
	return sdf.format(cal.getTime());
    }


    /**
     * Convert string representations of months from words to integers (case-sensitive).
     * NOTE: Here, 'January'==0 and 'December'==11, to conform with Date and Calendar classes
     * @param month string containing a textual representation (the name) of a month (ie, "January", "October", etc)
     * @return the integer representing the month (ie, 0 for january, 11 for december)
     */
    private static int wordToIntMonth(String month) {
        int m;
        if(month.equalsIgnoreCase("January") || month.equalsIgnoreCase("Jan")) {
            m=0;
        } else if(month.equalsIgnoreCase("February") || month.equalsIgnoreCase("Feb")) {
            m=1;
        } else if(month.equalsIgnoreCase("March") || month.equalsIgnoreCase("Mar")) {
            m=2;
        } else if(month.equalsIgnoreCase("April") || month.equalsIgnoreCase("Apr")) {
            m=3;
        } else if(month.equalsIgnoreCase("May")) {
            m=4;
        } else if(month.equalsIgnoreCase("June") || month.equalsIgnoreCase("Jun")) {
            m=5;
        } else if(month.equalsIgnoreCase("July") || month.equalsIgnoreCase("Jul")) {
            m=6;
        } else if(month.equalsIgnoreCase("August") || month.equalsIgnoreCase("Aug")) {
            m=7;
        } else if(month.equalsIgnoreCase("September") || month.equalsIgnoreCase("Sep")) {
            m=8;
        } else if(month.equalsIgnoreCase("October") || month.equalsIgnoreCase("Oct")) {
            m=9;
        } else if(month.equalsIgnoreCase("November") || month.equalsIgnoreCase("Nov")) {
            m=10;
        } else if(month.equalsIgnoreCase("December") || month.equalsIgnoreCase("Dec")) {
            m=11;
        } else {
            m=-1;
            /* throw exception here?? */
            throw new IllegalArgumentException("Invalid month");
        }
        return m;
	/*************************************
       /// this is a failed attempt to get this function implimented in a more elegant fashion
       SimpleDateFormat sdf = new SimpleDateFormat("M");
       DateFormat df = DateFormat.getInstance();
       Calendar cal = Calendar.getInstance();
       try{cal.setTime(df.parse(month + " 1, 2006"));}catch(Exception e){System.out.println("zomg this still sucks");}
       return ("" + (Integer.parseInt(sdf.format(cal.getTime())) + 1));
	*************************************/
    }


    /**
     * Do updates for a database table with this particular date schema.
     *  these tuples are like:
     *  (id, date) VALUES (1, '2005-01-01')
     *  [ie, real SQL date types]
     * @param stmt An already prepared Statement from an open Connection.
     * @param shift time shift interval length, in seconds
     * @param tableName name of the table to perform this operation on.
     * @param expectedRecords records expected to be updated in this operation.
     */
    private static void updateTableTypeDate(Statement stmt, int shift, String tableName, int expectedRecords) {
	try {
	    logger.info("  Updating " + tableName + " table...");
	    int numUpdates = stmt.executeUpdate("UPDATE " + tableName + " SET date=date + interval '" + shift + " seconds';");
	    logger.info("    Records updated: " + numUpdates + ".");
	    logger.info("    Record updates expected: " + expectedRecords + ".");
	} catch(Exception e){
	    logger.error("Error updating table " + tableName, e);
	    return;
	}
    }


    /**
     * Do updates for a database table with this particular date schema.
     *  these tuples are like:
     *  (uniqueID, eventYear, eventMonth, eventDayOfMonth) VALUES (1, '2006', 'February', '3')
     * @param stmt An already prepared Statement from an open Connection.
     * @param shift time shift interval length, in seconds
     * @param tableName name of the table to perform this operation on.
     * @param expectedRecords records expected to be updated in this operation.
     */
    private static void updateTableTypeYMD(Statement stmt, int shift, String tableName, int expectedRecords) {
	try {
	    Vector ids = new Vector();
	    Vector dates = new Vector();
	    Calendar cal;
	    
	    logger.info("  Reading " + tableName + " table...");
	    
	    ResultSet rs = stmt.executeQuery("SELECT uniqueID, eventYear, eventMonth, eventDayOfMonth FROM " + tableName + ";");
	    while (rs.next()) {
		ids.add(rs.getString(1)); // store id
		cal = Calendar.getInstance();
		cal.set(Integer.parseInt(rs.getString(2)), wordToIntMonth(rs.getString(3)), Integer.parseInt(rs.getString(4))); // populate calendar object (while converting month)
		cal.add(Calendar.SECOND, shift); // the calendar does the dirty work for us ;)
		dates.add(cal); // store date
	    }
	    rs.close();
	    
	    logger.info("  Writing " + tableName + " table...");
	    int numUpdates = 0;
	    for (int i=0; i<ids.size(); i++) {
		cal = (Calendar) dates.elementAt(i);
		numUpdates += stmt.executeUpdate("UPDATE " + tableName + " SET " +
						 " eventYear='" + cal.get(Calendar.YEAR) + "', " +
						 " eventMonth='" + intToWordMonth(cal.get(Calendar.MONTH)) + "', " + // month needs to be converted
						 " eventDayOfMonth='" + cal.get(Calendar.DAY_OF_MONTH) + "' " +
						 " WHERE uniqueID=" + ids.elementAt(i) + ";");
	    }
	    logger.info("    Records updated: " + numUpdates + ".");
	    logger.info("    Record updates expected: " + expectedRecords + ".");
	    
	} catch(Exception e) {
	    logger.error("Error updating table " + tableName, e);
	    return;
	}
    }


    /**
     * Do updates for a database table with this particular date schema.
     *  these tuples are like:
     *  (uniqueID, singleYear, singleMonth, singleDay, multStartYear, multStartMonth, multStartDay, multEndYear, multEndMonth, multEndDay)
     *  VALUES (1, '2012', '12', '21', 'null', 'null', 'null', 'null', 'null', 'null')
     *  OR
     *  VALUES (2, 'null', 'null', 'null', '1978', '10', '14', '2012', '12', '21')
     * @param stmt An already prepared Statement from an open Connection.
     * @param shift time shift interval length, in seconds
     * @param tableName name of the table to perform this operation on.
     * @param expectedRecords records expected to be updated in this operation.
     */
    private static void updateTableTypeMultiYMD(Statement stmt, int shift, String tableName, int expectedRecords) {
	try {
	    Vector ids = new Vector();
	    Vector dates = new Vector();
	    Calendar cal;
	    String year, month, day;
	    
	    logger.info("  Reading " + tableName + " table...");
	    ResultSet rs = stmt.executeQuery("SELECT uniqueID, " +
					     " singleYear,    singleMonth,    singleDay, " +
					     " multStartYear, multStartMonth, multStartDay, " +
					     " multEndYear,   multEndMonth,   multEndDay " +
					     " FROM " + tableName + ";");
	    while (rs.next()) {
		ids.add(rs.getString(1)); // store id
		for (int i=0; i<3; i++) {
		    year  = rs.getString(i*3 + 2);
		    month = rs.getString(i*3 + 3);
		    day   = rs.getString(i*3 + 4);
		    if ( year.equalsIgnoreCase("null") || month.equalsIgnoreCase("null") || day.equalsIgnoreCase("null") ) {
			dates.add(null); // if any of them are set to the string 'null', store a null as we cant create a valid date
		    } else {
			cal = Calendar.getInstance();
			cal.set(Integer.parseInt(year), Integer.parseInt(month) - 1, Integer.parseInt(day)); // populate calendar object
			// NOTE: the "month - 1" in the above line is done to make this method comply with Calendar object convention that jan=0, dec=11
			cal.add(Calendar.SECOND, shift); // the calendar does the dirty work for us ;)
			dates.add(cal); // store date
		    }
		}
	    }
	    rs.close();
	
	    String query;
	    int numUpdates = 0;
	    logger.info("  Writing " + tableName + " table...");
	    for (int i=0; i<ids.size(); i++) {
		query = "UPDATE " + tableName + " SET ";
		cal = (Calendar) dates.elementAt(i*3);
		if (cal==null) {
		    query = query + " singleYear='null', " +
			            " singleMonth='null', " + 
			            " singleDay='null', ";
		} else {
		    query = query + " singleYear='" + cal.get(Calendar.YEAR) + "', " +
		                    " singleMonth='" + (cal.get(Calendar.MONTH) + 1) + "', " +  // NOTE: the "+1" is done here to adjust for with Calendar object convention that jan=0, dec=11.  see above for "-1" when setting calendar object
		                    " singleDay='" + cal.get(Calendar.DAY_OF_MONTH) + "', ";
		}
		cal = (Calendar) dates.elementAt(i*3 + 1);
		if (cal==null) {
		    query = query + " multStartYear='null', " +
		                    " multStartMonth='null', " + 
    			            " multStartDay='null', ";
		} else {
		    query = query + " multStartYear='" + cal.get(Calendar.YEAR) + "', " +
			            " multStartMonth='" + (cal.get(Calendar.MONTH) + 1) + "', " +  // NOTE: the "+1" is done here to adjust for with Calendar object convention that jan=0, dec=11.  see above for "-1" when setting calendar object
			            " multStartDay='" + cal.get(Calendar.DAY_OF_MONTH) + "', ";
		}
		cal = (Calendar) dates.elementAt(i*3 + 2);
		if (cal==null) {
		    query = query + " multEndYear='null', " +
			            " multEndMonth='null', " + 
			            " multEndDay='null' "; // NOTE: no comma here
		} else {
		    query = query + " multEndYear='" + cal.get(Calendar.YEAR) + "', " +
		                    " multEndMonth='" + (cal.get(Calendar.MONTH) + 1) + "', " +  // NOTE: the "+1" is done here to adjust for with Calendar object convention that jan=0, dec=11.  see above for "-1" when setting calendar object
			            " multEndDay='" + cal.get(Calendar.DAY_OF_MONTH) + "' "; // NOTE: no comma here
		}
		query = query + " WHERE uniqueID=" + ids.elementAt(i) + ";";
		numUpdates += stmt.executeUpdate(query);
	    }
	    logger.info("    Records updated: " + numUpdates + ".");
	    logger.info("    Record updates expected: " + expectedRecords + ".");
	} catch(Exception e) {
	    logger.error("Error updating table " + tableName, e);
	    return;
	}
    }


    /**
     * Default constructor.  Simply calls more complicated constructor with empty array argument, which will print usage info.
     */
    public TimeWarp() {
	this(new String[] {});
    }


    /**
     * Basic constructor. Sets up database connection and calls more complicated constructor.
     * @param args array of two date strings and an optional string specifying a database uri.  the dates should have exactly an integer number of days difference.  less than two or greater than three arguements shows the usage dialog.
     */
    public TimeWarp(String[] args) {
	if (processCommandLine(args) != 0) { // this also calls setConnectString, so the connection made below is appropriate
	    Connection conn;
	    try {
		// establish communications with database
		Class.forName("org.postgresql.Driver").newInstance();
		conn = DriverManager.getConnection(CONNECT_STRING);
		
		new TimeWarp(args, conn);

		// clean up!
		conn.close();

	    } catch(Exception e) {
		logger.error("Something horrible happened!", e);
		return;
	    }
	}
    }


    /**
     * Constructor for using an already open database connection and the method that does the core of the work for this class.
     * @param args array of two date strings and an optional string specifying a database uri.  the dates should have exactly an integer number of days difference.  less than two or greater than three arguements shows the usage dialog.
     * @param conn already opened connection to a database.
     */
    public TimeWarp(String[] args, Connection conn){
	int timeShiftConst = processCommandLine(args); /// UNCLEAN!  second call to this method if more basic constructor is used...  its inefficient, but no side-effects should result.
	if (timeShiftConst != 0) {
	    Statement stmt = null;
	    ResultSet rs;
	    int numUpdates;
	    try {
		// establish statement for communications with database
		stmt = conn.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);

		// update tables
		logger.info("Shifting by " + (timeShiftConst/86400) + " days.");

		/*** change this section when changing schema or default db state ***/
		updateTableTypeDate(stmt, timeShiftConst, "schedule", 405);

		updateTableTypeYMD(stmt, timeShiftConst, "floralRequests", 3);
		updateTableTypeYMD(stmt, timeShiftConst, "cateringRequests", 16);
		updateTableTypeYMD(stmt, timeShiftConst, "securityRequests", 4);
		updateTableTypeYMD(stmt, timeShiftConst, "audioVisualRequests", 19);

		updateTableTypeMultiYMD(stmt, timeShiftConst, "rentalRequests", 0);
		/*** end of section ***/


		// clean up!
		stmt.close();

	    } catch(Exception e) {
		logger.error("Something horrible happened!", e);
		return;
	    }	
	    
	    logger.info("Done.");
	}

    }


    public static void main(final String[] args) {
	new TimeWarp(args);
    }


};
