package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 				T  O  W  N  C  A  R  A  C  C  E  P  T  Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to gather towncar request data for a specific id and set it
 * 			up in a nice format for reading.  Calls are made to the towncarRequest table
 * 			to retrieve request data.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Mar 11, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
/*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 *  - - - - - - - - - - - - - public class TowncarAcceptQuote  - - - - - - - - - - - - - -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
public class TowncarAcceptQuote {
	public String messageBody = null;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public TowncarAcceptQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the TowncarAcceptQuote.java class.  Initializes the messageBody by calling
	 * 				setupMessageBody.  The class variable messageBody is used by the QuoteAcceptedServlet to
	 * 				construct a confirmation email to the user
	 * Input:		String <requestID - the unique number in the towncarRequest table>
	 * 				String <vendorID - could be towncar1, 2, or 3, passed in through the http stream>
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public TowncarAcceptQuote(String requestID, String vendorID){
		messageBody = setupMessageBody(requestID, vendorID);
	} // end constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public setupMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method constructs the message body by querying the towncarRequest table and placing
	 * 				the variables in a very long String.  This method is called by the Constructor to initialize
	 * 				the messageBody class variable.  This method calls submitQuery (from DatabaseConnectivity.java),
	 * 				determineQuoteNumber, and assembleMessageBody.
	 * Input:		String <requestID - the unique number in the towncarRequest table>
	 * 				String <vendorID - could be towncar1, 2, or 3, passed in through the http stream>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String setupMessageBody(String requestID, String vendorID) {
		DatabaseConnectivity db = new DatabaseConnectivity();
		ResultSet rs = db.submitQuery("SELECT * FROM towncarRequests WHERE uniqueID ='" + requestID + "'");
		String quoteNumber = determineQuoteNumber(vendorID);
		if (quoteNumber.equals("error")) {
			System.err.println("EXCEPTION: TowncarAcceptQuote.setupMessageBody:\n\t There was an error determining the quoteNumber");
			System.out.println("EXCEPTION: TowncarAcceptQuote.setupMessageBody:\n\t There was an error determining the quoteNumber");
		}
		return (assembleMessageBody(rs, quoteNumber));
	} // end setupMessageBody

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public assembleMessageBody()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for pulling data from the ResultSet and formatting it in a clean
	 * 				manner so it's easily readable.
	 * Input:		ResultSet <rs>
	 * 				String <quoteNumber - identifies which quote to pull, either quote1, 2, or 3>
	 * Output:		String <messageBody>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String assembleMessageBody(ResultSet rs, String quoteNumber) {
		String s = null;
		try {
			boolean crap = rs.next();
				s = "Request for Towncar Service.  \n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Event Title:\t" + rs.getString("eventTitle") + "\n" +
				"Event Location:\t" + rs.getString("eventLocation") + "\n" +
				"Event Date:\t" + rs.getString("eventDate") + "\n" +
				"Contact First Name:\t" + rs.getString("contactFirstName") + "\n" +
				"Contact Last Name:\t" + rs.getString("contactLastName") + "\n" +
				"Contact Phone:\t" + rs.getString("contactPhone") + "\n" +
				"Contact Email:\t" + rs.getString("contactEmail") + "\n" +
				"Passenger First Name:\t" + rs.getString("passengerFirstName") + "\n" +
				"Passenger Last Name:\t" + rs.getString("passengerLastName") + "\n" +
			  	"Pick-up Street:\t" + rs.getString("pickupStreet") + "\n" +
				"Pick-up City:\t" + rs.getString("pickupCity") + "\n" +
				"Pick-up State:\t" + rs.getString("pickupState") + "\n" +
				"Pick-up Phone:\t" + rs.getString("pickupPhone") + "\n" +
				"Drop-off Street:\t" + rs.getString("dropoffStreet") + "\n" +
				"Drop-off City:\t" + rs.getString("dropoffCity") + "\n" +
				"Drop-off State:\t" + rs.getString("dropoffState") + "\n" +
				"Drop-off Phone:\t" + rs.getString("dropoffPhone") + "\n" +
				"Pick-up Time:\t" + rs.getString("pickupTime") + "\n" +
				"Arrival Time:\t" + rs.getString("arrivalTime") + "\n" +
				"Airport Pick-up:\t" + rs.getString("airportPickup") + "\n" +
				"Airline:\t" + rs.getString("airline") + "\n" +
				"Flight Number:\t" + rs.getString("flightNumber") + "\n" +
				"Arrival Time:\t" + rs.getString("flightArrivalTime") + "\n" +
				"Departure City:\t" + rs.getString("flightDepartureCity") + "\n" +
				"- - - - - - - - - - - - - - - - - - - - -" + "\n" +
				"Quote Total:\t$" + rs.getString(quoteNumber) + "\n";
		} // end try
		catch(Exception e){}
		System.out.println("DEBUG: TowncarAcceptQuote:assembleMessageBody\n\t Here's the msg body: " + s);
		return s;
	} // end printTowncarRequestData()

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public determineQuoteNumber()      																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method is responsible for identifying which quote number in the request table corresponds
	 * 				to the vendorID.
	 * Input:		String <vendorID>
	 * Output:		String <quoteNumber - either quote1, 2, or 3>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public String determineQuoteNumber(String vendorID){
		System.out.println("DEBUG: TowncarAcceptQuote:determineQuoteNum\n\t Here's the vendorID: "  + vendorID);
		if (vendorID.equals("towncar1")){
			System.out.println("DEBUG: TowncarAcceptQuote:determineQuoteNum\n\t vendorID was matched to towncar1");
			return "quote1" ;
		}
		if (vendorID.equals("towncar2"))
			return "quote2";
		if (vendorID.equals("towncar3"))
			return "quote3";
		else {
			System.out.println("EXCEPTION: TowncarAcceptQuote:determineQuoteNum\n\t vendorID was NOT matched");
			return "error";
		}
	} // end determineQuoteNumber

//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end TowncarAcceptQuote.java
//- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -