package edu.cmu.radar.vendor;
/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * 				T  O  W  N  C  A  R   Q  U  O  T  E  .  J  A  V  A
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 * Purpose:	This class is used to calculate towncar service quotes for requests made by the
 * 			participants.  This class utilizes JDBC calls to get pricing from a MySQL table.
 * Author:	Kyle A Cunningham <kcunning@cs.cmu.edu>
 * Created: Mar 3, 2005
 *
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Vector;

public class TowncarQuote {
	Vector request;
	DatabaseConnectivity db;

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public TowncarQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		Constructor for the TowncarQuote.java class.  Initializes the request vector for use
	 * 				by class methods.  The towncarRequestVector will be passed in.
	 * Input:		Vector
	 * Output:		none
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public TowncarQuote(Vector v){
		request = new Vector(v);
		db = new DatabaseConnectivity();
	} // end Constructor

	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * public int[] calculateQuote()       																   *
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
	 * Purpose:		This method calls the towncarCostStructure table and gathers necessary data to calculate
	 * 				and return the quote.  Quotes for all towncar service vendors are calculated and placed in an int
	 * 				array.  Currently system is setup for 3 towncar vendors.  Additions/deletions will require changes
	 * 				in the costStructure table as well as calculateQuote method.
	 * 				pickupTime @ position 20, arrivalTime @ 21
	 * Input:		none
	 * Output:		int[] <quotes for all towncar providers - caller can use what is needed>
	 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
	public int[] calculateQuote() {
		int duration = 0;
		String[] splitTimes = ((String) request.get(20)).split(":");
		int startHour = Integer.valueOf(splitTimes[0]).intValue();
		int startMinutes = Integer.valueOf(splitTimes[1]).intValue();
		splitTimes = ((String) request.get(21)).split(":");
		int endHour = Integer.valueOf(splitTimes[0]).intValue();
		int endMinutes = Integer.valueOf(splitTimes[1]).intValue();
		duration = (endHour - startHour);
			System.out.println("DEBUG: TowncarQuote.calculateQuote: \n Duration is = " + duration);
		int[] quoteList = {0,0,0};
		int v1perHour = 0, v2perHour = 0, v3perHour = 0, v1minHours = 0, v2minHours = 0, v3minHours = 0;

		ResultSet rs = db.submitQuery("SELECT * FROM towncarCostStructure WHERE id = '1'");
		try {
			while (rs.next()){
				v1perHour = rs.getInt("v1perHour");
				v2perHour = rs.getInt("v2perHour");
				v3perHour = rs.getInt("v3perHour");
				v1minHours = rs.getInt("v1minHours");
				v2minHours = rs.getInt("v2minHours");
				v3minHours = rs.getInt("v3minHours");
				System.out.println("DEBUG: TowncarQuote.calculateQuote:\n Here's the prices: " + v1perHour + "\t" + v2perHour + "\t" + v3perHour);
			}
		}
			catch (SQLException e) {
				System.out.println("EXCEPTION: TowncarQuote.calculateQuote: \n Here's the error: " + e);
		}
		// calculate the quotes
		if (duration < v1minHours)
			quoteList[0] = (v1minHours * v1perHour);
		else
			quoteList[0] = (duration * v1perHour);
		if (duration < v2minHours)
			quoteList[1] = (v2minHours * v2perHour);
		else
			quoteList[1] = (duration * v2perHour);
		if (duration < v3minHours)
			quoteList[2] = (v3minHours * v3perHour);
		else
			quoteList[2] = (duration * v3perHour);
		System.out.println("DEBUG: TowncarQuote.calculateQuote:\n Here's the final quotes: " +
						quoteList[0] + "\t" + quoteList[1] + "\t" + quoteList[2]);
		return(quoteList);
	} // end calculateQuote()
//	 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
} 										// end TowncarQuote.java
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

