/*
 *               __TO_DO__
 *
 *  add more than one test per table?
 *  make dates used in test randomly generated?
 *  make it so table names arent hard coded in each sql statement?
 *  do one test for each table by comparing composited strings of tuples returned?
 *  also, search for /// for places in the code that could be updated or improved.
 *
 */

package edu.cmu.radar.vendor.tests;

import edu.cmu.radar.vendor.*;
import java.sql.*;
import junit.framework.TestCase;
import junit.runner.BaseTestRunner;
import java.lang.reflect.*;

/**
 * Used for updating the date-related entries in the 'vendor' database by shifting them in time.
 * @author haff
 */
public class TimeWarpTest extends TestCase {

    /**
     * Method for doing JUnit tests on TimeWarp class.
     */
    public void testTimeWarp(){
	try {
		
		/*
		 * 
		 * echo notice to user
		 * 
		 */
		
		System.out.println("Please note that this test will change some of the expected values in the TimeWarp output.");
		
		

	    /*
	     *
	     * set dates for TimeWarp
	     *
	     */

	    String initialDate = "Sep 19 2005 GMT";
	    String testDate = "May 22 2006 GMT";



	    /*
	     *
	     * set up database connection
	     *
	     */

	    Class.forName("org.postgresql.Driver").newInstance();
	    Connection conn = DriverManager.getConnection(TimeWarp.setConnectString()); // takes connection string from TimeWarp
	    conn.setAutoCommit(false); // so we can roll back later
	    Statement stmt = conn.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
	    ResultSet rs = null;



	    /*
	     *
	     * insert test values (save id's for later lookup & removal)
	     *
	     */
	

	    // test for updateTableTypeDate tables
	    /// below: "date" is the only value we really care about, the rest are provided as they are specified 'not null' in the table with no default values
	    stmt.executeUpdate("INSERT INTO schedule (date " +
			                           " , person_id, time, status, length " + /// 'not null' variables
			       ") VALUES ('2005-09-19' " +
			                           " , 0, '12:00', '', 0 " + /// 'not null' values
			       ");");
	    rs = stmt.executeQuery("SELECT currval('schedule_id_seq');"); /// this second sql statement included because getGeneratedKeys() is not implimented.
	    ///rs = stmt.getGeneratedKeys(); // commented out because unimplimented, solution is to include query of sequence in update statement;
	    rs.next();
	    String updateTableTypeDateID = rs.getString(1);
	    rs.close();

	    // test for updateTableTypeYMD tables (also could test cateringRequests, floralRequests, audioVisualRequests)
	    /// below: the 3 values related to date are the only ones we really care about, the rest are provided as they are specified 'not null' in the table with no default values
	    stmt.executeUpdate("INSERT INTO securityRequests (eventYear, eventMonth, eventDayOfMonth " +
			                           " , pageLoaded, pageSubmitted, eventTitle, eventLocation, contactFirstName, contactLastName, contactEmail, crowdControl, trafficControl, parkingAssistance, vip, alcohol, numberSecurityStaff, securityClothing, startTime, endTime, location, funcServeAlcohol, funcGuardValuables, funcMaintainPerimeter, funcMonitorTraffic, funcOpenGarage, funcMaintainPresence, calculatedQuote " + /// 'not null' variables
			       ") VALUES ('2005', 'September', '19' " + 
       			                           " , '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '' " + /// 'not null' values
			       ");");
	    rs = stmt.executeQuery("SELECT currval('vendor_order_seq');"); /// this second sql statement included because getGeneratedKeys() is not implimented.  NOTE: all tables except schedule share 'vendor_order_sequence' for primary keys.
	    ///rs = stmt.getGeneratedKeys(); // commented out because unimplimented, solution is to include query of sequence in update statement;
	    rs.next();
	    String updateTableTypeYMDID = rs.getString(1);
	    rs.close();


	    // test for two date form of updateTableTypeMultiYMD
	    // NOTE: two day span between start/end dates
	    /// below: the 9 values related to date are the only ones we really care about, the rest are provided as they are specified 'not null' in the table with no default values
	    stmt.executeUpdate("INSERT INTO rentalRequests (singleYear, singleMonth, singleDay, multStartYear, multStartMonth, multStartDay, multEndYear, multEndMonth, multEndDay " +
			                           " , pageLoaded, pageSubmitted, eventTitle, eventLocation, rentalType, contactFirstName, contactLastName, contactEmail, tent, tentSize, chairs, chairType, chairColor, staging, stagingSize, cocktailTables, cocktailTableSize, pipeDrape, pipeDrapeColor, pipeDrapeLength, banquetTables, banquetTableLength, roundTables, roundTableSize, privacyScreens, coatRack, rental1, rental2, rental3, quote1, quote2, quote3, tentType, setupComplete, breakdownStart " + /// 'not null' variables
			       ") VALUES ('null', 'null', 'null', '2005', '9', '19', '2005', '9', '21' " +
			                           " , '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '' " + /// 'not null' values
			       ");");
	    rs = stmt.executeQuery("SELECT currval('vendor_order_seq');"); /// this second sql statement included because getGeneratedKeys() is not implimented.  NOTE: all tables except schedule share 'vendor_order_sequence' for primary keys.
	    ///rs = stmt.getGeneratedKeys(); // commented out because unimplimented, solution is to include query of sequence in update statement;
	    rs.next();
	    String updateTableTypeMultiYMDTwoID = rs.getString(1);
	    rs.close();


	    // test for one date form of updateTableTypeMultiYMD
	    /// below: the 9 values related to date are the only ones we really care about, the rest are provided as they are specified 'not null' in the table with no default values
	    stmt.executeUpdate("INSERT INTO rentalRequests (singleYear, singleMonth, singleDay, multStartYear, multStartMonth, multStartDay, multEndYear, multEndMonth, multEndDay " + 
			                           " , pageLoaded, pageSubmitted, eventTitle, eventLocation, rentalType, contactFirstName, contactLastName, contactEmail, tent, tentSize, chairs, chairType, chairColor, staging, stagingSize, cocktailTables, cocktailTableSize, pipeDrape, pipeDrapeColor, pipeDrapeLength, banquetTables, banquetTableLength, roundTables, roundTableSize, privacyScreens, coatRack, rental1, rental2, rental3, quote1, quote2, quote3, tentType, setupComplete, breakdownStart " + /// 'not null' variables
			       ") VALUES ('2005', '9', '19', 'null', 'null', 'null', 'null', 'null', 'null' " +
			                           " , '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '' " + /// 'not null' values
			       ");");
	    rs = stmt.executeQuery("SELECT currval('vendor_order_seq');"); /// this second sql statement included because getGeneratedKeys() is not implimented.  NOTE: all tables except schedule share 'vendor_order_sequence' for primary keys.
	    ///rs = stmt.getGeneratedKeys(); // commented out because unimplimented, solution is to include query of sequence in update statement;
	    rs.next();
	    String updateTableTypeMultiYMDOneID = rs.getString(1);
	    rs.close();



	    /*
	     *
	     * shift time
	     *
	     */

	    new TimeWarp(new String[] {initialDate, testDate}, conn);


	
	    /*
	     *
	     * test that times have been updated
	     *
	     */

	    rs = stmt.executeQuery("SELECT date FROM schedule WHERE id = '" + updateTableTypeDateID + "';");
	    rs.next();
	    assertEquals("failure on updateTableTypeDate", "2006-05-22", rs.getString(1));
	    rs.close();

	    rs = stmt.executeQuery("SELECT eventYear, eventMonth, eventDayOfMonth " +
				   " FROM securityRequests WHERE uniqueID = '" + updateTableTypeYMDID + "';");
	    rs.next();
	    assertEquals("failure on updateTableTypeYMD (eventYear)", "2006", rs.getString(1));
	    assertEquals("failure on updateTableTypeYMD (eventMonth)", "May", rs.getString(2));
	    assertEquals("failure on updateTableTypeYMD (eventDayOfMonth)", "22", rs.getString(3));
	    rs.close();

	    rs = stmt.executeQuery("SELECT singleYear, singleMonth, singleDay, multStartYear, multStartMonth, multStartDay, multEndYear, multEndMonth, multEndDay " +
				   " FROM rentalRequests WHERE uniqueID = '" + updateTableTypeMultiYMDTwoID + "';");
	    rs.next();
	    assertEquals("failure on updateTableTypeMultiYMD multi(singleYear)", "null", rs.getString(1));
	    assertEquals("failure on updateTableTypeMultiYMD multi(singleMonth)", "null", rs.getString(2));
	    assertEquals("failure on updateTableTypeMultiYMD multi(singleDay)", "null", rs.getString(3));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multStartYear)", "2006", rs.getString(4));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multStartMonth)", "5", rs.getString(5));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multStartDay)", "22", rs.getString(6));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multEndYear)", "2006", rs.getString(7));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multEndMonth)", "5", rs.getString(8));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multEndDay)", "24", rs.getString(9));
	    rs.close();
	    
	    rs = stmt.executeQuery("SELECT singleYear, singleMonth, singleDay, multStartYear, multStartMonth, multStartDay, multEndYear, multEndMonth, multEndDay " +
				   " FROM rentalRequests WHERE uniqueID = '" + updateTableTypeMultiYMDOneID + "';");
	    rs.next();
	    assertEquals("failure on updateTableTypeMultiYMD single(singleYear)", "2006", rs.getString(1));
	    assertEquals("failure on updateTableTypeMultiYMD single(singleMonth)", "5", rs.getString(2));
	    assertEquals("failure on updateTableTypeMultiYMD single(singleDay)", "22", rs.getString(3));
	    assertEquals("failure on updateTableTypeMultiYMD single(multStartYear)", "null", rs.getString(4));
	    assertEquals("failure on updateTableTypeMultiYMD single(multStartMonth)", "null", rs.getString(5));
	    assertEquals("failure on updateTableTypeMultiYMD single(multStartDay)", "null", rs.getString(6));
	    assertEquals("failure on updateTableTypeMultiYMD single(multEndYear)", "null", rs.getString(7));
	    assertEquals("failure on updateTableTypeMultiYMD single(multEndMonth)", "null", rs.getString(8));
	    assertEquals("failure on updateTableTypeMultiYMD single(multEndDay)", "null", rs.getString(9));
	    rs.close();
	    
	

	    /*
	     *
	     * shift time back
	     *
	     */

	    new TimeWarp(new String[] {testDate, initialDate}, conn);



	    /*
	     *
	     * test that times are back to original
	     *
	     */

	    rs = stmt.executeQuery("SELECT date FROM schedule WHERE id = '" + updateTableTypeDateID + "';");
	    rs.next();
	    assertEquals("failure on updateTableTypeDate", "2005-09-19", rs.getString(1));

	    rs = stmt.executeQuery("SELECT eventYear, eventMonth, eventDayOfMonth " +
				   " FROM securityRequests WHERE uniqueID = '" + updateTableTypeYMDID + "';");
	    rs.next();
	    assertEquals("failure on updateTableTypeYMD (eventYear)", "2005", rs.getString(1));
	    assertEquals("failure on updateTableTypeYMD (eventMonth)", "September", rs.getString(2));
	    assertEquals("failure on updateTableTypeYMD (eventDayOfMonth)", "19", rs.getString(3));
	    
	    rs = stmt.executeQuery("SELECT singleYear, singleMonth, singleDay, multStartYear, multStartMonth, multStartDay, multEndYear, multEndMonth, multEndDay " +
				   " FROM rentalRequests WHERE uniqueID = '" + updateTableTypeMultiYMDTwoID + "';");
	    rs.next();
	    assertEquals("failure on updateTableTypeMultiYMD multi(singleYear)", "null", rs.getString(1));
	    assertEquals("failure on updateTableTypeMultiYMD multi(singleMonth)", "null", rs.getString(2));
	    assertEquals("failure on updateTableTypeMultiYMD multi(singleDay)", "null", rs.getString(3));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multStartYear)", "2005", rs.getString(4));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multStartMonth)", "9", rs.getString(5));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multStartDay)", "19", rs.getString(6));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multEndYear)", "2005", rs.getString(7));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multEndMonth)", "9", rs.getString(8));
	    assertEquals("failure on updateTableTypeMultiYMD multi(multEndDay)", "21", rs.getString(9));

	    rs = stmt.executeQuery("SELECT singleYear, singleMonth, singleDay, multStartYear, multStartMonth, multStartDay, multEndYear, multEndMonth, multEndDay " +
				   " FROM rentalRequests WHERE uniqueID = '" + updateTableTypeMultiYMDOneID + "';");
	    rs.next();
	    assertEquals("failure on updateTableTypeMultiYMD single(singleYear)", "2005", rs.getString(1));
	    assertEquals("failure on updateTableTypeMultiYMD single(singleMonth)", "9", rs.getString(2));
	    assertEquals("failure on updateTableTypeMultiYMD single(singleDay)", "19", rs.getString(3));
	    assertEquals("failure on updateTableTypeMultiYMD single(multStartYear)", "null", rs.getString(4));
	    assertEquals("failure on updateTableTypeMultiYMD single(multStartMonth)", "null", rs.getString(5));
	    assertEquals("failure on updateTableTypeMultiYMD single(multStartDay)", "null", rs.getString(6));
	    assertEquals("failure on updateTableTypeMultiYMD single(multEndYear)", "null", rs.getString(7));
	    assertEquals("failure on updateTableTypeMultiYMD single(multEndMonth)", "null", rs.getString(8));
	    assertEquals("failure on updateTableTypeMultiYMD single(multEndDay)", "null", rs.getString(9));

	    

	    /*
	     *
	     * remove test values
	     *
	     */

	    stmt.executeUpdate("DELETE FROM schedule WHERE id = '" + updateTableTypeDateID +"';");
	    stmt.executeUpdate("DELETE FROM securityRequests WHERE uniqueID = '" + updateTableTypeYMDID +"';");
	    stmt.executeUpdate("DELETE FROM rentalRequests WHERE uniqueID = '" + updateTableTypeMultiYMDOneID +"';");
	    stmt.executeUpdate("DELETE FROM rentalRequests WHERE uniqueID = '" + updateTableTypeMultiYMDTwoID +"';");

	    

	    /*
	     *
	     * clean up and rollback transaction
	     * (db should be back to initial state anyway, but this assures that we have no side effects)
	     *
	     */

	    stmt.close();
	    conn.rollback();
	    conn.close();
	    

	} catch(Exception e) {
	    e.printStackTrace();
	    return;
	}
    }
}
